*cfr_analysis_final_pt1.do
*By Jesse Rothstein
*7/28/2014
*
*Part 1 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************


********************************PREPARATORY MATERIAL***************************

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt1"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

*global datadir "`cfrdat'" /*JR orig: global datadir $root/datadir */
*JR orig: global IRSdir ${datadir}/from_IRS
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
  project, uses(`cfrdat'/final_teacher_list_linked_to_students.dta)
  project, uses(`cfrdat'/sch_grade_enrollments.dta)
  project, uses(`cfrdat'/teacher_enrollments.dta)
  project, uses(`cfrdat'/schd_work.dta)
  project, uses(`cfrdat'/NOTIRS_class_collapse.dta)
  project, uses(`cfrdat'/NOTIRS_sch_gr_year_collapse.dta)
}

***************************START OF CFR PROGRAM********************************
********************BASED ON LINES 95-355 OF ANALYSIS_FINAL.DO*****************

***********************************************
***** CREATE TEACHER-SCHOOL WEIGHT MATRIX *****
***********************************************
* Used for event studies and cross-cohort regs

*Use final teacher list created in create_schd_work.do
*Only contains teachers who show up in our class links data at some point
use teacher year sch using `cfrdat'/final_teacher_list_linked_to_students.dta, clear 
*JR orig: use teacher year sch using ${datadir}/final_teacher_list_linked_to_students.dta, clear*
tsset teacher year

* Generate indicator for whether the teacher is new to teaching in district.
* 	note: we could define this for 1989 using experience = 0, but we cannot define new to school in 1989
bysort teacher (year): gen new_to_state=_n==1 if year>1997

* Generate indicator for whether the teacher is new to the school but not to teaching in the district.
*	note: if the teacher taught previously in the school, left, and came back, we still consider them "new"
gen new_to_school=new_to_state==0 & sch~=l.sch if year>1997

* Attrition indicators (teacher-year)
*JR NOTE: THIS CAPTURES ONLY TEACHERS WHO LEAVE FOR GOOD, NOT TEMPORARY DISAPPEARANCES;
bysort teacher (year): gen switch_state=teacher~=teacher[_n+1] if year<2011

* School switch indicator (teacher-year)
gen switch_school=switch_state==0 & sch~=f.sch if year<2011


*MERGE ON ENROLLMENT DATA BY TEACHER BY SCHOOL-YEAR-GRADE-MATH
*	note that we use joinby to create every pairwise combination of sch year with teacher dataset, so each teacher in any sch and year will appear in every sch-grade-subject-year cell for that sch year
*	also note: Enrollment data was created in create_schd_work.do
 *JR orig: joinby sch year using ${datadir}/sch_grade_enrollments.dta
 *JR NOTE: the "using" dataset has sch-year-math-grade observations. Adjust code to verify no mismatches;
 joinby sch year using `cfrdat'/sch_grade_enrollments.dta , unmatched(both)
 assert _merge==3
 drop _merge
 
merge 1:1 teacher year grade math using `cfrdat'/teacher_enrollments.dta, assert(1 3)
*JR NOTE: _merge=1s are year-grade-math combinations that exist in the school but not for this teacher;
g temp = (_merge==3)
bys teacher year: egen in_class_data = max(temp)
drop _merge temp

*Set number of students to 0 in sch-grade-subject-year cells where the teacher is teaching no students but is found in the class links data in that year
replace n_students = 0 if in_class_data==1 & n_students==.

*Define n_rpool_taught as the total number of students
bys sch grade year math: egen n_rpool_taught = sum(n_students)

*Completely drop school-grade-year-subject cells where we have no info on teachers (n_rpool_taught==0)
drop if n_rpool_taught==0

*Drop teachers not linked to students in rpools where we have some info on teachers
g teach_wt = n_students/n_rpool
drop if teach_wt==0 | teach_wt==.

* GRADE SWITCH INDICATOR (NOTE: TEACHER-YEAR HERE--ANY GRADE SWITCH FOR T'S WITH MORE THAN ONE GRADE)
* LOGIC IS TO SORT EACH TEACHER WITHIN SCHOOL AND GRADE, THEN LOOK FOR ANY BREAKS IN TIME
* OR THE LAST OCCURENCE IN THE GRADE (IF THE TEACHER DOES NOT LEAVE THE SCHOOL OR DISTRICT)
bysort sch math grade: egen maxyear=max(year)
bysort sch math grade: egen minyear=min(year)
bysort teacher sch math grade (year): gen switch_grade= (year!=year[_n+1]-1 | _n==_N) & switch_school==0 & switch_state==0 & year<maxyear if year<2011
bysort teacher sch math grade (year): gen new_to_grade= (year!=year[_n-1]+1 | _n==1) & new_to_school==0 & new_to_state==0 & year>minyear if year>1997
drop maxyear minyear

sum switch_state switch_school switch_grade if year<2011

* Define an indicator for whether a rookie shows up in S-G-Y-M cell
bys sch grade year math: egen has_true_rookie = max(new_to_state)
		
* Define an indicator for whether a teacher new to the school shows up in S-G-Y-M cell
bys sch grade year math: egen has_sch_rookie = max(new_to_school)

save `cfrdat'/teacher_school_weights, replace

**********************************************
****** CREATE SCHOOL DISTRICT COLLAPSES ******
**********************************************

*** Step 1: Create SCHD class-level collapse (PRODUCES SCHD_class_year_collapse data) 
use `cfrdat'/schd_work.dta if class~=.&flag_sample==1, clear

*JR: COMMENTED OUT -- WE DON'T HAVE A LONG TIME SERIES;
*Rename leads and lags
*rename l3_z_score l3_score
*rename l4_z_score l4_score
*rename f3_z_score f3_score
*rename f4_z_score f4_score

*bys sch year math class_id: egen f_score_count = count(f_score)
*by sch year math class_id: egen f2_score_count = count(f2_score)
*by sch year math class_id: egen f3_score_count = count(f3_score)
*by sch year math class_id: egen f4_score_count = count(f4_score)
bys sch year math class_id: egen l_score_count = count(PREZl_score)
*by sch year math class_id: egen l2_score_count = count(l2_score)
*by sch year math class_id: egen l3_score_count = count(l3_score)
*by sch year math class_id: egen l4_score_count = count(l4_score)
by sch year math class_id: egen other_count = count(other)

* Add gain measures
g gain_t=(score-PREZl_score)
*g gain_t_plus1=(f_score-score)

*Class level average of remaining student-level controls
sort class
*JR ORIG: foreach vary of varlist matchable score other gain_t gain_t_plus1 f_score f2_score f3_score f4_score PREZl_score l2_score l3_score l4_score PREOl_other {
foreach vary of varlist  score other PREZl_score PREOl_other l2_score {
	by class: egen mean_`vary'=mean(`vary')
}
rename mean_PREZl_score mean_l_score

drop  score other 

*JR: Commented out;
*g l96 = (year-grade)<=1996
*bys sch year math class_id: egen any_l96 = max(l96)
*drop l96

*g l97 = (year-grade)<=1997
*bys sch year math class_id: egen any_l97 = max(l97)
*drop l97


*Because grade variable varies across students in class, use modal_grade
drop grade
rename modal_grade grade

* Drop individual-level variables from the class-level collapse 
*JR ORIG: drop sped limited_english female ethnicity combined_z_score test_grade lunch miss_lunch ///
    PREO* MPREO* repeat_grade age09 ETHN* post99_sped post99_limited_eng age_current test_district_id test_school_number school_number ///
    student_grade student_pob test_flag_switch_schools prior_test_grade enrolled-school_days_enrolled_total orig_id7 observation_to_keep prior_grade repeat_test ///
    PREZ* stuid l5_z_score l6_z_score f4_score f5_z_score f6_z_score f7_z_score absences suspensions homeroom_id homeroom_teacher_id7 homeroom_teacher_id6 future_tgrade future_repeat rpool gain_t gain_t_plus1
drop sped limited_english female ethnicity test_grade lunch miss_lunch ///
    PREO* MPREO* repeat_grade repeat_test age09 ETHN* age_current  ///
    student_grade future_repeat  ///
    PREZ* stuid rpool gain_t 
*JR NOTE: More to drop -- not in CFR code;
 drop havel MISS_* flag_* pared daysabs l?_score l?_other f?_score f?_other administ

* Collapse to a single obs per class
*CFR orig code: bys class: keep if _n==1
*JR my edit, to ensure this is replicable
 duplicates drop
 isid class
sort class

save `cfrdat'/SCHD_class_year_collapse.dta, replace

*** Step 2: Create School-Grade-Year-level collapse
use `cfrdat'/schd_work.dta if sch~=.&grade~=.&flag_sample==1, clear

*JR: COMMENTED OUT
*Rename leads and lags
*rename l3_z_score l3_score
*rename l4_z_score l4_score
*rename f3_z_score f3_score

replace CLass_size=. if CLass_size>50
*JR orig: drop teacher teacher_id6 class class_id homeroom_id homeroom_teacher_id7 homeroom_teacher_id6 hon rem enrich mod foreign flag_homeroom flag_sped t_exp_reg TEXP* sample_to_keep
drop teacher class class_id classroom flag_sped flag_sample 

*School-grade-cohort-subject level average of remaining student-level controls
*JR ORIG: foreach vary of varlist matchable score other f_score f2_score f3_score PREZl_score l2_score l3_score l4_score lunch sped repeat_grade PREOl_other CLass_size {
foreach vary of varlist score other PREZl_score lunch sped repeat_grade PREOl_other CLass_size {
	bys sch grade year math: egen mean_`vary'=mean(`vary')
}
*JR orig: drop matchable stuid f_score f2_score f3_score PREZl_score l2_score l3_score l4_score score other lunch sped repeat_grade CLass_size
drop stuid PREZl_score score other lunch sped repeat_grade CLass_size

rename mean_PREZl_score mean_l_score

*g l96 = (year-grade)<=1996
*g l97 = (year-grade)<=1997

*School size
bys sch grade year math: g SGYsize=_N
keep if SGYsize>=10

* Drop variables that are not constant in this collapse 
*drop PREO* MPREO* ETHN* SGPO* SGPZ* CL* PREZ* ///
     test_district_id district_id test_school_number school_number limited_english student_grade female ethnicity student_pob combined_z_score l5_z_score l6_z_score f4_z_score f5_z_score f6_z_score f7_z_score test_grade test_flag_switch_schools prior_test_grade absences suspensions enrolled start end test_date discharged tested_school late_enrollment early_discharge class_days_enrolled_total school_days_enrolled_total evercourse orig_id7 prior_grade repeat_test future_tgrade future_repeat miss_lunch post99_sped post99_limited_eng age_current age09 orig_class_size modal_grade t_exp_reg_full
drop PREO* MPREO* ETHN* SGPO* SGPZ* CL* PREZ* ///
     limited_english student_grade female ethnicity test_grade repeat_test miss_lunch age_current age09 orig_class_size modal_grade 
*JR extras
 drop pared daysabs teachid future_repeat havel l?_score l?_other f?_score f?_other MISS_* administ

* Collapse
*CFR original code, replaced to ensure replicability:  bys sch grade year math: keep if _n==1
 duplicates drop
 isid sch grade year math
sort sch grade year math
save `cfrdat'/SCHD_sch_gr_year_collapse, replace

*******************************
***** IMPORT IRS COLLAPSE *****
*******************************

***Step 1: merge IRS class-level data onto SCHD class-level data
*JR orig: *First import and clean up IRS class-level data
*JR orig: tempfile class_collapse
*JR orig: set more off
*JR orig: !${root}/code/odyssey_stata_call_stattransfer.sh ${IRSdir}/class_collapse_masked_${IRSdate}.sas7bdat `class_collapse'.dta -y
*JR orig: use `class_collapse'.dta, clear
*JR orig: 
*JR orig: rename score IRS_score
*JR orig: rename count IRS_count
*JR orig: cap drop grade
*JR orig: 
*JR orig: *Now merge onto SCHD collapsed data
*JR orig: merge 1:1 sch year class_id math using ${datadir}/SCHD_class_year_collapse_${SCHDclasscollapsedate}.dta
*JR orig: compress female
*JR orig: 
*JR orig: keep if _merge==3
*JR orig: drop _merge
*JR orig: 
*JR orig: * Perform trimming on the outside
*JR orig: set more off
*JR orig: do ${root}/code/irs/irs_clean_final.do
*JR orig: drop if class_id==""
*JR orig: 
*JR orig: order sch year class_id math
*JR orig: sort sch year class_id math
*JR orig: 
*JR orig: *Test if IRS and SCHD collapses match (if they don't, there's a problem, don't save the file)
*JR orig: assert IRS_count==CLass_size
*JR orig: assert abs(IRS_score-mean_score)<10^-6 | ( missing(IRS_score) & missing(mean_score) )
*JR orig: 
*JR orig: * Check that pred not missing iff actual not missing
*JR orig: assert predcoll20_nocontrols==. if college20==.
*JR orig: assert predcoll20_nocontrols!=. if college20!=.
*JR orig: 
*JR orig: assert predcwage20_nocontrols==. if college20==.
*JR orig: assert predcwage20_nocontrols!=. if college20!=.
*JR orig: `cfrdat'/IRS_SCHD_class_collapse.dta, replace

*JR: New code, to substitute for the above. Make a class-year file with the "NOtIRS" information;
use `cfrdat'/NOTIRS_class_collapse
drop if class_id==.
sort sch year class_id math
merge 1:1 sch year class_id math using `cfrdat'/SCHD_class_year_collapse.dta, assert(3)
drop _merge
save `cfrdat'/NOTIRS_SCHD_class_collapse, replace



***Step 2: merge IRS school-grade-level data onto SCHD school level
*JR orig: *First import and clean up IRS school-grade-year data
*JR orig: tempfile grade_collapse
*JR orig: set more off
*JR orig: !${root}/code/odyssey_stata_call_stattransfer.sh ${IRSdir}/grade_collapse_masked_${IRSdate}.sas7bdat `grade_collapse'.dta -y
*JR orig: use `grade_collapse'.dta, clear
*JR orig: 
*JR orig: rename score IRS_score
*JR orig: rename count IRS_count
*JR orig: rename grade_orig grade
*JR orig: 
*JR orig: *Now merge onto SCHD collapsed data
*JR orig: merge 1:1 sch grade year math using ${datadir}/SCHD_sch_gr_year_collapse_${SCHDgradecollapsedate}.dta
*JR orig: compress female
*JR orig: 
*JR orig: keep if _merge==3
*JR orig: drop _merge
*JR orig: 
*JR orig: set more off
*JR orig: do ${root}/code/irs/irs_clean_final.do
*JR orig: 
*JR orig: drop if sch==.|grade==.
*JR orig: order sch grade year math
*JR orig: sort sch grade year math
*JR orig: 
*JR orig: *Test if IRS and SCHD collapses match (if they don't, there's a problem, don't save the file)
*JR orig: assert IRS_count==SGYsize
*JR orig: assert abs(IRS_score-mean_score)<10^-6 | ( missing(IRS_score) & missing(mean_score) )
*JR orig: 
*JR orig: * Check that pred not missing iff actual not missing
*JR orig: assert pred_score_nocontrols==. if mean_score==.
*JR orig: assert pred_score_nocontrols!=. if mean_score!=.
*JR orig: 
*JR orig: assert predcoll20_nocontrols==. if college20==.
*JR orig: assert predcoll20_nocontrols!=. if college20!=.
*JR orig: 
*JR orig: assert predcwage20_nocontrols==. if college20==.
*JR orig: assert predcwage20_nocontrols!=. if college20!=.
*save ${datadir}/IRS_SCHD_sch_gr_yr_collapse.dta, replace

*JR: New code, to substitute for the above;
 use `cfrdat'/NOTIRS_sch_gr_year_collapse
 merge 1:1 sch grade year math using `cfrdat'/SCHD_sch_gr_year_collapse.dta
 keep if _merge==3
 drop _merge
 drop if sch==. | grade==.
 save `cfrdat'/NOTIRS_SCHD_sch_gr_year_collapse.dta, replace
 

if `doasproject'==1 {
  project, creates(`cfrdat'/teacher_school_weights.dta)
  project, creates(`cfrdat'/SCHD_class_year_collapse.dta)
  project, creates(`cfrdat'/SCHD_sch_gr_year_collapse.dta)
  *project, creates(`cfrdat'/SCHD_class_collapse.dta)
  project, creates(`cfrdat'/NOTIRS_SCHD_sch_gr_year_collapse.dta)
  project, creates(`cfrdat'/NOTIRS_SCHD_class_collapse.dta)
}

