*cfr_analysis_final_pt10.do
*By Jesse Rothstein
*7/12/2015
*
*Part 10 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************


********************************PREPARATORY MATERIAL***************************
*This program makes *large* temporary datasets. On my system, the regular TMPDIR
*isn't big enough for this. This code ensures that I've remembered to re-set
*TMPDIR before starting Stata to a directory that can handle this program.;
*Simple code to make sure tmpvar is set right;
 *tempfile test
 *di "`test'"
 *assert strpos("`test'", "/var/tmp/scratch")==1
 *If this fails, before running Stata type:
  * TMPDIR=/var/tmp/scratch
  * export TMPDIR
 *(This assumes bash shell -- may need other commands for other shells/OSes. 
 *Type "echo $0" to learn which you have.

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt10"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 project, uses("`cfrdat'/analysis.dta")

*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~
*~*~*~*~*~* PAPER 2 *~*~*~*~*~*~*
*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~

*******************
***** Table 1 *****
*******************

* Table 1 is generated at the IRS, except for the t_exp_reg & CLass_size rows.
* --> note: data from IRS log is read into Stata in the Paper 1, Table 1 code block.


***** Output csv for Paper 2

** Compute summary stats for t_exp_reg and CLass_size on the outside
*use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear
*
*sum t_exp_reg [w=CLass_size] if any_l97==1
*scalar __texp_mean=r(mean)
*scalar __texp_sd=r(sd)
*scalar __texp_n=r(sum_w)
*
*sum CLass_size if any_l97==1
*scalar __classsize_mean=r(mean)
*scalar __classsize_sd=r(sd)
*scalar __classsize_n=r(N)
*
** Store the computed summary stats as data in a new dataset
*clear
*set obs 2
*
*gen str20 var=""
*gen float mean=.
*gen float sd=.
*gen long n=.
*gen byte paper=2
*
*replace var="t_exp_reg" in 1
*replace mean=__texp_mean in 1
*replace sd=__texp_sd in 1
*replace n=__texp_n in 1
*
*replace var="CLass_size_classweighted" in 2
*replace mean=__classsize_mean in 2
*replace sd=__classsize_sd in 2
*replace n=__classsize_n in 2
*
** Append IRS summary stats data
*append using ${datadir}/summary_stats_from_IRS_${summstats_date}.dta
*keep if paper==2
*
** Rename the "blockN" summary stats
*drop if inlist(var,"lunch_block2","miss_lunch_block2")
*replace var=subinstr(var,"_block3","_subsample",.)
*replace var=subinstr(var,"_block4","_subsample",.)
*replace var=subinstr(var,"_block5","_subsample",.)
*
*outsheet using ${tab}/paper2/table1_summstatsdate${summstats_date}.csv, comma replace



*******************
***** Table 2 *****
*******************

* Cross-Class, Impacts of Teacher Value-Added on College Attendance

use `cfrdat'/analysis, clear
estimates clear

***CFRs programs -- I will rerun with my outcomes
** Col 1: college at age20 with baseline controls
*longterm_crossclass_table college20, ///
*	controls(${controls}) replace r_suffix(_bl) ///
*	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
*scalar __coeff=_b[tv_sd]
*scalar __se=_se[tv_sd]
*
** Figure 1a
*sum college20 [w=college20_count] if !missing(college20_r_bl)
*gen college20_r_bl_percent=(college20_r_bl+r(mean))*100
*
*local coeff=string(__coeff*100,"%9.2f")
*local se=string(__se*100,"%9.2f")
*binscatter college20_r_bl_percent tv_sd [aw=college20_count], controls(middle math middle_math)  ///
*	title("College Attendance at Age 20") ///
*	xtitle("Teacher Value Added") ///
*	ytitle("Percent in College at Age 20") ///
*	xlab(-1.5(.5)1.5) ///
*	note("Coefficient = `coeff'%" "(`se')", position(5) ring(0) size(medsmall))
*multi_graph_export using ${figdir}/paper2/fig1a_college20_scatter_irsdate${IRSdate}_tfxdate${tfxdate}
*
*
** Col 2: college at age20 with baseline controls + parent controls
*longterm_crossclass_table college20, ///
*	controls(${controls} ${par_controls}) r_suffix(_par) append ///
*	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
*	
** Col 3: college at age20 with baseline controls + l2_z_score
*longterm_crossclass_table college20 if grade>4, ///
*	controls(${controls} l2_z_score) r_suffix(_l2) append ///
*	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
*	
** Text only: Col 1 re-run on sample of Col 3
*longterm_crossclass_table college20 if !missing(college20_r_l2), ///
*	controls(${controls}) r_suffix(_bl_l2sample) replace ///
*	output(${tab}/paper2/paperonly_col1table2_rerun_col3sample_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
*
** Col 4: cwage20 with baseline controls
*longterm_crossclass_table cwage20, ///
*	controls(${controls}) r_suffix(_bl) append ///
*	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
*scalar __coeff=_b[tv_sd]
*scalar __se=_se[tv_sd]
*
** Figure 1b
*sum cwage20 [w=cwage20_count] if !missing(cwage20_r_bl)
*gen cwage20_r_bl_binsc=(cwage20_r_bl+r(mean))
*
*local coeff=string(__coeff,"%9.0f")
*local se=string(__se,"%9.0f")
*binscatter cwage20_r_bl_binsc tv_sd [aw=cwage20_count], controls(middle math middle_math)  ///
*	title("College Quality at Age 20") ///
*	xtitle("Teacher Value Added") ///
*	ytitle("Projected Earnings from College at Age 20") ///
*	xlab(-1.5(.5)1.5) ///
*	note("Coefficient = $`coeff'" "(`se')", position(5) ring(0) size(medsmall))
*multi_graph_export using ${figdir}/paper2/fig1b_cwage20_scatter_irsdate${IRSdate}_tfxdate${tfxdate}
*
** Col 5: cwage20 with baseline controls + parent controls
*longterm_crossclass_table cwage20, ///
*	controls(${controls} ${par_controls}) r_suffix(_par) append ///
*	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
*	
** Col 6: cwage20 with baseline controls + l2_z_score
*longterm_crossclass_table cwage20 if grade>4, ///
*	controls(${controls} l2_z_score) r_suffix(_l2) append ///
*	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
*
** Col 7: High Quality College with baseline controls
*longterm_crossclass_table high_cwage20, ///
*	controls(${controls}) append ///
*	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
*	
** Col 8: Indicator for four or more years in college, with baseline controls
*longterm_crossclass_table coll1822_more4yrs, ///
*	controls(${controls}) append ///
*	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

*CFR, line 79
 *global controls CL* SG* SY* hon-foreign YEAR* GRDE*
local classcontrols CL* SG* SY* YEAR* GRDE*
longterm_crossclass_table lr_grad, ///
  controls(`classcontrols') replace r_suffix(_va) ///
  output(`tabdir'/paper2/table2.csv)
longterm_crossclass_table lr_collbound, ///
  controls(`classcontrols') append r_suffix(_va) ///
  output(`tabdir'/paper2/table2.csv)
longterm_crossclass_table lr_coll4bound, ///
  controls(`classcontrols') append r_suffix(_va) ///
  output(`tabdir'/paper2/table2.csv)
longterm_crossclass_table lr_gpa, ///
  controls(`classcontrols') append r_suffix(_va) ///
  output(`tabdir'/paper2/table2.csv)
longterm_crossclass_table lr_rank, ///
  controls(`classcontrols') append r_suffix(_va) ///
  output(`tabdir'/paper2/table2.csv)

*Now redo with twice lagged test score
longterm_crossclass_table lr_grad, ///
  controls(`classcontrols' mean_l2_score) append r_suffix(_val2) ///
  output(`tabdir'/paper2/table2.csv)
longterm_crossclass_table lr_collbound, ///
  controls(`classcontrols' mean_l2_score) append r_suffix(_val2) ///
  output(`tabdir'/paper2/table2.csv)
longterm_crossclass_table lr_coll4bound, ///
  controls(`classcontrols' mean_l2_score) append r_suffix(_val2) ///
  output(`tabdir'/paper2/table2.csv)
longterm_crossclass_table lr_gpa, ///
  controls(`classcontrols' mean_l2_score) append r_suffix(_val2) ///
  output(`tabdir'/paper2/table2.csv)
longterm_crossclass_table lr_rank, ///
  controls(`classcontrols' mean_l2_score) append r_suffix(_val2) ///
  output(`tabdir'/paper2/table2.csv)
  
  
isid teacher year math
keep teacher year math lr_*_r_*
save `cfrdat'/longterm_crossclass, replace

if `doasproject'==1 project, creates(`tabdir'/paper2/table2.csv)
if `doasproject'==1 project, creates(`cfrdat'/longterm_crossclass.dta)
  