*cfr_analysis_final_pt11.do
*By Jesse Rothstein
*7/12/2015
*
*Part 11 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************


********************************PREPARATORY MATERIAL***************************
*This program makes *large* temporary datasets. On my system, the regular TMPDIR
*isn't big enough for this. This code ensures that I've remembered to re-set
*TMPDIR before starting Stata to a directory that can handle this program.;
*Simple code to make sure tmpvar is set right;
 *tempfile test
 *di "`test'"
 *assert strpos("`test'", "/var/tmp/scratch")==1
 *If this fails, before running Stata type:
  * TMPDIR=/var/tmp/scratch
  * export TMPDIR
 *(This assumes bash shell -- may need other commands for other shells/OSes. 
 *Type "echo $0" to learn which you have.

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt11"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
	project, uses(`cfrdat'/tfx/tfx_tym.dta)
	project, uses(`cfrdat'/teacher_school_weights.dta)
	project, uses(`cfrdat'/NOTIRS_SCHD_sch_gr_year_collapse.dta)
}

*******************
***** Table 5 *****
*******************

*Long Term Impact (college) Results: Cross-Cohort

*CFR original for Table 5;
*prepare_quasi, tfxfile(${datadir}/tfx/tfx_${tfxdate}) ///
*	tch_sch_weights(${datadir}/teacher_school_weights) ///
*	sch_gr_yr_collapse(${datadir}/IRS_SCHD_sch_gr_yr_collapse_${IRSdate}) ///
*	trim_threshold(99) ///
*	tv_sd

prepare_quasi, tfxfile(`cfrdat'/tfx/tfx_tym) ///
	tch_sch_weights(`cfrdat'/teacher_school_weights) ///
	sch_gr_yr_collapse(`cfrdat'/NOTIRS_SCHD_sch_gr_year_collapse) ///
	trim_threshold(99) ///
	tv_sd(`cfrdat'/tfx/sd_tfx)
	
egen sch_yr = group(sch year)

g d_mean_l_other = d.mean_PREOl_other
g d_mean_l_other2 = d_mean_l_other^2
g d_mean_l_other3 = d_mean_l_other^3
g d_mean_l_score = d.mean_l_score
g d_mean_l_score3 = d_mean_l_score^3
g d_mean_l_score2 = d_mean_l_score^2

*** Panel A: college20
*** Panel B: cwage20
estimates clear
set more off

file open meancovered using `tabdir'/paper2/paperonly_cross_cohort_meancovered.csv, write text replace

*foreach var of varlist college20 cwage20 {
*	if ("`var'"=="college20") local predvar="predcoll20_nocontrols"
*	if ("`var'"=="cwage20") local predvar="predcwage20_nocontrols"
foreach var of varlist lr_grad lr_collbound lr_coll4bound lr_gpa lr_rank {
		
	* Col 1: Baseline
	areg d.`var' d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(year)
	estimates store tab1`var'
	scalar __`var'_coeff=_b[d_tv_sgm_1]
	scalar __`var'_se=_se[d_tv_sgm_1]
	
	sum mean_covered_tv if e(sample) [w=`var'_count], meanonly
	scalar __mean_cur=r(mean)
	sum l.mean_covered_tv if e(sample) [w=`var'_count], meanonly
	scalar __mean_lag=r(mean)
	file write meancovered "`var' Baseline mean_covered," ((__mean_cur+__mean_lag)/2) _n
	
	sum cohort if e(sample) [w=`var'_count], meanonly
	file write meancovered "`var' Baseline mean cohort," (r(mean)) _n

	* Col 2: Add sch*yr fixed effects
	areg d.`var' d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(sch_yr)
	estimates store tab2`var'

	* Col 3: Add control for lagged scores, and lead & lag change in VA
	areg d.`var' d_tv_sgm_1 d_mean_l_score* d_mean_l_other* f.d_tv_sgm_1 l.d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(sch_yr)
	estimates store tab3`var'

	* PAPER ONLY: same spec as col 2 on identical sample to col 3
	areg d.`var' d_tv_sgm_1 [w=`var'_count] if e(sample), cluster(sch_cohort) a(sch_yr)
	estimates store paper1`var'

	* Col 4: no imputation, baseline spec
	areg d.`var' d_tv_sgm_1 [w=`var'_count] if mean_covered_tv==1&l.mean_covered_tv==1, cluster(sch_cohort) a(sch_yr)
	estimates store tab4`var'

	* Col 5: Predicted college with sch*yr fixed effects
	*areg d.`predvar' d_tv_sgm_1 [w=`predvar'_count], cluster(sch_cohort) a(sch_yr)
	*estimates store tab5`var'
}

file close meancovered



* Output
esttab tab* using `tabdir'/paper2/table5_cross_cohort_college.csv, replace keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g)) p(fmt(%12.0g))) obslast
esttab paper* using `tabdir'/paper2/paperonly_cross_cohort_college.csv, replace keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))  p(fmt(%12.0g))) obslast
estimates clear

if `doasproject'==1 {
  project, creates(`tabdir'/paper2/paperonly_cross_cohort_meancovered.csv)
	project, creates(`tabdir'/paper2/table5_cross_cohort_college.csv)
	project, creates(`tabdir'/paper2/paperonly_cross_cohort_college.csv)
}
