*cfr_analysis_final_pt2.do
*By Jesse Rothstein
*7/28/2014
*
*Modified 3/23/15: Keep a couple of extra variables to add to VAM controls
*
*Part 2 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
*
***********************************************************************

********************************PREPARATORY MATERIAL***************************

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt2"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"
   
*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
  project, uses(`cfrdat'/schd_work.dta)
}

***************************START OF CFR PROGRAM********************************
*******************BASED ON LINES 361-513 OF ANALYSIS_FINAL.DO*****************

**************************************************************************************
***********************  VALUE-ADDED ESTIMATION **************************************
**************************************************************************************

*** Generate schd_work_trim dataset
*	--> subset of schd_work dataset that contains obs that have test scores and have other conditions needed for value-added model estimation
*JR: Modify this to not load the following vars specified by CFR: hon, rem, enrich, mod, foreign, flag_homeroom, TEXP* 
*JR orig: global base_vars stuid year sch modal_grade grade test_grade math teacher teacher_id6 t_exp_reg t_exp_reg_full class class_id score f_score f2_score f3_z_score f4_z_score l2_score l3_z_score l4_z_score flag_homeroom flag_sped observation_to_keep sample_to_keep CLass_size rpool middle
*JR orig: global controls_to_load PREZ* PREO* MPREO* CL* SG* SY* female age_current lunch miss_lunch ETHN* sped limited_english repeat_grade repeat_test absences suspensions post99* hon rem enrich mod foreign TEXP* 
global base_vars stuid year sch modal_grade grade test_grade math teacher class ///
                 class_id score flag_sped flag_sample CLass_size rpool l2_score MISS_*
global controls_to_load PREZ* PREO* MPREO* CL* SG* SY* female age_current lunch ///
                        miss_lunch ETHN* sped limited_english repeat_grade repeat_test 

****TEMPORARY -- REMOVE WHEN DONE DEBUGGING
*use ${base_vars} ${controls_to_load} using `cfrdat'/schd_work ///
    if sch<=1000&score~=.&class~=.&teacher~=.&flag_sample==1, clear
use ${base_vars} ${controls_to_load} using `cfrdat'/schd_work ///
    if score~=.&class~=.&teacher~=.&flag_sample==1, clear


*rename l4_z_score l4_score
*rename l3_z_score l3_score
*rename f3_z_score f3_score
*rename f4_z_score f4_score

*Restrict to grades with lag score data
keep if inrange(grade,3,5)

*Require at least 7 kids with non-missing scores and lagged scores
egen miss = rowmiss(score PREZl* PREOl*)
g nomiss = miss==0
bys class: egen n_tested = sum(nomiss)

count if n_tested < 7
scalar __numerator=r(N)
count
scalar __denominator=r(N)

file open lt7 using `tabdir'/paper1/paperonly_counts_VAobsdropped_lt7.csv, write text replace
file write lt7 "Fraction of student-subject-year observations dropped from VA sample because fewer than 7 students in class had score & lagged score data:" _n
file write lt7 (__numerator/__denominator)
file close lt7


keep if n_tested>=7
keep if miss==0
drop miss nomiss n_tested

*Year and grade dummies
char year[omit] 2009
xi, prefix(YEAR) i.year
char grade[omit] 4
xi, prefix(GRDE) i.grade

egen sch_yr = group(sch year)

g cohort=year-grade
egen sch_cohort = group(sch cohort)

* Label middle and math
*label define middle 0 elementary 1 middle
label define math 0 reading 1 math
*label values middle middle
label values math math

save `cfrdat'/schd_work_trim.dta, replace



***** CONSTRUCT BASELINE TFX ESTIMATES TO USE IN WHOLE PAPER
use `cfrdat'/schd_work_trim.dta, clear

vam score, teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
	controls(${baseline_VAM_controls}) output(`cfrdat'/tfx/tfx) ///
	tfx_resid(teacher) by(math) driftlimit(7) quasi ///
	data(merge tv score_r)

       
* save score_r data
keep stuid year class_id teacher sch math score_r tv sch_cohort
save `cfrdat'/tfx/score_r, replace


** Construct teacher-year-math version of tfx for quasi-experiments
use `cfrdat'/tfx/tfx, clear

collapse (mean) tv*, by (teacher year math)
sort teacher year math
order teacher year math

save `cfrdat'/tfx/tfx_tym, replace

** Paper only: output correlation between English and math VA for elem teachers
use `cfrdat'/tfx/tfx, clear
collapse (mean) tv*, by (teacher year math)

egen grp=group(teacher year)
tsset grp math

corr tv l.tv 

file open subjectcorr using `tabdir'/paper1/paperonly_readmathVAcorr_elem_tv_tfxdate.csv, write text replace
file write subjectcorr "Correlation between English and math VA for elementary school teachers:" _n
file write subjectcorr (r(rho))
file close subjectcorr

** Paper only: output fraction of student-subject-year obs with controls but without tv
use `cfrdat'/tfx/score_r, clear

* Drop if missing controls
drop if missing(score_r)

* Compute fraction
count if missing(tv)
scalar __numerator=r(N)

count
scalar __denominator=r(N)

* Check that all are due to having only one year of teacher obs
bys teacher math : egen min_year=min(year)
bys teacher math : egen max_year=max(year)
gen oneyear=(min_year==max_year)
assert missing(tv) if oneyear==1
assert oneyear==1 if missing(tv)

* Output to file
file open no_tv using `tabdir'/paper1/paperonly_fraction_without_leaveout_tv.csv, write text replace
file write no_tv "Fraction of student-subject-year observations with full control vector but with no leave-out tv measure because teacher only observed for one year:" _n
file write no_tv (__numerator/__denominator)
file close no_tv



** Paper only: output first year test scores of teachers who leave after 1 year vs. whole sample of teachers
use `cfrdat'/schd_work_trim.dta, clear

* Merge on score_r and tv
merge 1:1 stuid year class_id teacher math using `cfrdat'/tfx/score_r, keep(2 3) assert(3) keepusing(score_r tv) nogen

* Drop if not in VA sample
drop if missing(score_r)

* Keep first year 
bys teacher math : egen min_year=min(year)
bys teacher math : egen max_year=max(year)
keep if year==min_year

collapse score score_r tv, by(teacher  math)

* Output first year scores to csv
file open firstyear using `tabdir'/paper1/paperonly_scores_firstyear_teaching.csv, write text replace

sum score_r if missing(tv)
file write firstyear "Average test scores in the first year for teachers who leave after one year:" _n (r(mean)) _n _n

sum score_r
file write firstyear "Average test scores in the first year for all teachers:" _n (r(mean)) _n _n

file close firstyear



if `doasproject'==1 {
  project, creates(`tabdir'/paper1/paperonly_counts_VAobsdropped_lt7.csv)
  project, creates(`cfrdat'/schd_work_trim.dta)
  project, creates(`cfrdat'/tfx/tfx_log.smcl)
  project, creates(`cfrdat'/tfx/score_r.dta)
  project, creates(`cfrdat'/tfx/tfx.dta)
  project, creates(`cfrdat'/tfx/tfx_tym.dta)
  project, creates(`cfrdat'/tfx/tfx_variance.csv)
  project, creates(`tabdir'/paper1/paperonly_readmathVAcorr_elem_tv_tfxdate.csv)
  project, creates(`tabdir'/paper1/paperonly_fraction_without_leaveout_tv.csv)
  project, creates(`tabdir'/paper1/paperonly_scores_firstyear_teaching.csv)
}
