*cfr_analysis_final_pt3.do
*By Jesse Rothstein
*7/28/2014
*
*Part 3 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************


version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt3"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

*global datadir "`cfrdat'" /*JR orig: global datadir $root/datadir */
*JR orig: global IRSdir ${datadir}/from_IRS
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
	project, uses(`cfrdat'/tfx/tfx_variance.csv)
	project, uses(`cfrdat'/schd_work_trim.dta)
}

	
***************************START OF CFR PROGRAM********************************
*******************BASED ON LINES 517-599 OF ANALYSIS_FINAL.DO*****************

***** PAPER 1, TABLE 2
* Code is up here because the results of the quadratic fit are used for the generation of tv_sd in the "CROSS-CLASS ANALYSIS DATA SETUP" section.

insheet using `cfrdat'/tfx/tfx_variance.csv, comma clear

outsheet using `tabdir'/paper1/table2_panelA.csv, comma replace

*** Estimate cov_sameyear for elementary and output to a csv
gen lag2=lag^2

assert lag[1]==1
assert lag[_N]==.

file open elem_cov_sameyear using `tabdir'/paper1/table2_panelB_SD_sameyear_estimate.csv, write text replace
file write elem_cov_sameyear ",lower bound,quad exp fit,true value" _n

set more off
*JR orig: foreach level in elementary middle {   
	foreach subject in reading math {
		* Label
		file write elem_cov_sameyear "`subject',"
		
		* Lower bound
		file write elem_cov_sameyear (sqrt(cov_lag_`subject'[1]))
		file write elem_cov_sameyear ","
		
		* Quadratic fit
		gen log_cov_lag_`subject'=log(cov_lag_`subject')
		reg log_cov_lag_`subject' lag lag2 if inrange(lag,1,7) [aw=obs_lag_`subject']
		file write elem_cov_sameyear (sqrt(exp(_b[_cons])))
		file write elem_cov_sameyear ","
		
		* True value
		*if ("`level'"=="middle") file write elem_cov_sameyear (sqrt(cov_sameyear_`level'_`subject'[_N]))
		
		file write elem_cov_sameyear _n
	}
*}

file close elem_cov_sameyear

***** CONSTRUCT TV ESTIMATES WITH NON-MISSING L2_SCORE
use `cfrdat'/schd_work_trim.dta, clear

*Restrict to obs with non-missing l2_score to have appropriate sample for l2_score regs comparison
keep if l2_score~=.

vam score, teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
	controls(${baseline_VAM_controls}) output(`cfrdat'/tfx/tfx_l2_score_notmiss) ///
	tfx_resid(teacher) by(math) driftlimit(7) ///
	data(merge tv score_r)

* save score_r data
*postvam_save_l2score, controls(${baseline_VAM_controls}) output(${datadir}/tfx/score_r_l2_score_notmiss_tfxdate${tfxdate}) score_r_l2 l2_score_r
postvam_save_l2score, controls(${baseline_VAM_controls}) output(`cfrdat'/tfx/score_r_l2_score_notmiss) score_r_l2 l2_score_r


***** Paper only: Construct baseline model with driftlimit(10) as a robustness check
use `cfrdat'/schd_work_trim.dta, clear
vam score, teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
	controls(${baseline_VAM_controls}) output(`cfrdat'/tfx/tfx_driftlimit10) ///
	tfx_resid(teacher) by(math) driftlimit(10)
	
* Construct teacher-year-math version
use `cfrdat'/tfx/tfx_driftlimit10, clear
collapse tv*, by (teacher year math)
sort teacher year math
order teacher year math
	
rename tv tv_drift10

* Merge in baseline VA estimates
merge 1:1 teacher year math using `cfrdat'/tfx/tfx_tym, assert(3) nogen keepusing(tv)

corr tv tv_drift10

* Output corr to csv
file open corr using `tabdir'/paper1/paperonly_driftlimit10_robustness.csv, write text replace
file write corr "Correlation between driftlimit(7) and driftlimit(10) VA estimates:" _n
file write corr (r(rho))
file close corr

 if `doasproject'==1 {
 		project, creates(`tabdir'/paper1/table2_panelA.csv)
    project, creates(`tabdir'/paper1/table2_panelB_SD_sameyear_estimate.csv)
    project, creates(`cfrdat'/tfx/tfx_driftlimit10_log.smcl)
    project, creates(`cfrdat'/tfx/tfx_driftlimit10.dta)
    project, creates(`cfrdat'/tfx/tfx_driftlimit10_variance.csv)
    project, creates(`cfrdat'/tfx/tfx_l2_score_notmiss_log.smcl)
    project, creates(`cfrdat'/tfx/tfx_l2_score_notmiss.dta)
    project, creates(`cfrdat'/tfx/tfx_l2_score_notmiss_variance.csv)
    project, creates(`cfrdat'/tfx/score_r_l2_score_notmiss.dta)
    project, creates(`tabdir'/paper1/paperonly_driftlimit10_robustness.csv)
 }
 