*cfr_analysis_final_pt4.do
*By Jesse Rothstein
*7/28/2014
*
*Part 4 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************


version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt4"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

*global datadir "`cfrdat'" /*JR orig: global datadir $root/datadir */
*JR orig: global IRSdir ${datadir}/from_IRS
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
  project, uses(`tabdir'/paper1/table2_panelB_SD_sameyear_estimate.csv)
	project, uses(`cfrdat'/tfx/score_r.dta)
	project, uses(`cfrdat'/NOTIRS_SCHD_class_collapse.dta)
  project, uses(`cfrdat'/tfx/tfx_tym.dta)
  project, uses(`cfrdat'/schd_work.dta)
}

***************************START OF CFR PROGRAM********************************
********************BASED ON LINES 601-812 OF ANALYSIS_FINAL.DO*****************

***************************************************************************************
****************** CROSS-CLASS ANALYSIS DATA SETUP ************************************
***************************************************************************************

set more off

*** Get SD of teacher value added
insheet using `tabdir'/paper1/table2_panelB_SD_sameyear_estimate.csv, clear
*gen byte middle=(_n>2)
g byte middle=0
gen byte math=(mod(_n,2)==0)

gen sd_tfx=truevalue
replace sd_tfx=quadexpfit if middle==0

keep v1 sd_tfx math
list
drop v1
save `cfrdat'/tfx/sd_tfx, replace


*Collapse score_r at the class level
use `cfrdat'/tfx/score_r, clear
collapse (mean) score_r (count) score_r_count=score_r, by(sch year class_id math)

*Load collapsed dataset (only keep grades 4-8 for cross-class analysis b/c we have no lag scores in grade 3)
*JR orig: merge 1:1 sch year class_id math using ${datadir}/IRS_SCHD_class_collapse, assert(2 3) nogen
merge 1:1 sch year class_id math using `cfrdat'/NOTIRS_SCHD_class_collapse
*JR added -- only have IRS sample for some years
  assert _merge>1 if year<2007
  drop _merge
  
keep if grade>2
order score_r score_r_count, last

*JR orig: foreach var of varlist score_r_count diff_score_rminuspar diff_score_rminuspar_count score_r_withpar score_r_withpar_count { 
foreach var of varlist score_r_count { 
	replace `var' = . if score_r == .
}

*Merge on teacher effects, constructed above in VAM section 
merge m:1 teacher year math using `cfrdat'/tfx/tfx_tym.dta, keep(1 3) nogen
compress math

*Generate middle school dummy
*JR orig: g middle = inlist(substr(class_id,1,1),"M","E")==1
gen byte middle=0
*gen middle_math=middle*math

*Generate year and grade dummies
char year[omit] 2009
xi, prefix(YEAR) i.year
char grade[omit] 4
xi, prefix(GRDE) i.grade
g cohort=year-grade
egen sch_cohort=group(sch cohort)

ren mean_score score
*ren mean_f_score f_z_score
*ren mean_f2_score f2_z_score
*ren mean_f3_score f3_z_score
*ren mean_f4_score f4_z_score
g l_z_score = CLPZl_score
*ren mean_l2_score l2_z_score
*ren mean_l3_score l3_z_score
*ren mean_l4_score l4_z_score
ren mean_other other

forval i=2/4 {
*	rename l`i'_score_count l`i'_z_score_count
*	rename f`i'_score_count f`i'_z_score_count
}
*rename f_score_count f_z_score_count

*Define college attendance rate by school
*JR orig: g temp = college20_count*college20
*JR orig: bys sch: egen temp1 = sum(temp)
*JR orig: bys sch: egen temp2 = sum(college20_count)
*JR orig: g sch_college = temp1/temp2
*JR orig: drop temp temp1 temp2
*JR orig: 
*JR orig: sum sch_college [w=CLass_size],d
*JR orig: 
*JR orig: file open median_sch_college using ${tab}/paper2/paperonly_median_sch_college_irsdate${IRSdate}.csv, write text replace
*JR orig: file write median_sch_college "Median sch_college," (r(p50))
*JR orig: file close median_sch_college

*JR orig: gen high_sch_college=(sch_college>r(p50)) if !missing(sch_college)

*Generate Jacob-Levitt (2003) proxy for teacher cheating
*JR orig: bysort math grade year: egen rank_t=rank(mean_gain_t)
*JR orig: bysort math grade year: egen maxrank_t=max(rank_t)
*JR orig: replace rank_t=rank_t/maxrank_t
*JR orig: 
*JR orig: bysort math grade year: egen rank_t_plus1=rank(mean_gain_t_plus1)
*JR orig: bysort math grade year: egen maxrank_t_plus1=max(rank_t_plus1)
*JR orig: replace rank_t_plus1=rank_t_plus1/maxrank_t_plus1
*JR orig: 
*JR orig: gen levitt_score = rank_t^2 + (1 - rank_t_plus1)^2
*JR orig: drop rank_t maxrank_t rank_t_plus1 maxrank_t_plus1
*JR orig: 
*JR orig: sum levitt_score if tv~=. & teacher~=. & class~=., d
*JR orig: g outlier=levitt_score>=r(p95) & levitt_score<. if teacher~=. & class~=. & tv~=.
*JR orig: 
*JR orig: bys teacher: egen count_outlier=sum(outlier)
*JR orig: g flag_levitt = count_outlier>1 if count_outlier<.
*JR orig: 
*JR orig: * Output stats on Jacob-Levitt proxy
*JR orig: file open levitt_gains using ${tab}/paper2/paperonly_levittproxy_gain_loss_irsdate${IRSdate}.csv, write text replace
*JR orig: 
*JR orig: sum mean_gain_t if outlier==1
*JR orig: file write levitt_gains "Gain in year t," (r(mean)) _n
*JR orig: 
*JR orig: sum mean_gain_t_plus1 if outlier==1
*JR orig: file write levitt_gains "Loss in year t+1," (r(mean)) _n
*JR orig: 
*JR orig: file close levitt_gains

* Generate standardized tv
merge m:1 math using `cfrdat'/tfx/sd_tfx, assert(3) nogen
gen tv_sd=tv/sd_tfx

* Generate percentile of tv by middle-math, and output 99% cutoffs
gen matched_size=score_r_count
*JR orig: g matched_size = matched*matched_count 
g int percent_tv=.

file open tv_insample_cutoffs using `tabdir'/paper2/paperonly_tv_insample_cutoffs.csv, write text replace
file write tv_insample_cutoffs "middle,math,tv_sd p99" _n

*JR orig: forvalues middle=0/1 { 
forvalues middle=0/0 { 
	forvalues math=0/1 {
		fastxtile percent_tv_temp=tv_sd if middle==`middle' & math==`math' [w=matched_size], nq(100)
		file write tv_insample_cutoffs "`middle',`math',`r(r99)'" _n
		replace percent_tv=percent_tv_temp if middle==`middle' & math==`math'
		drop percent_tv_temp
	}
}

file close tv_insample_cutoffs

* Outlier trimming for baseline sample
g tv_insample = percent_tv<=99

* Test diff_scorer_minuspar non-missing iff score_r non-missing
*JR orig: assert diff_score_rminuspar==. if score_r==.
*JR orig: assert diff_score_rminuspar!=. if score_r!=.

* Save analysis dataset
save `cfrdat'/analysis.dta, replace


*** Paper only: Correlate match rates with tv
*JR orig: use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear
*JR orig: qui areg matched tv_sd ${controls} middle math middle_math [w=CLass_size], cluster(sch_cohort) a(cohort)
*JR orig: estimates store match_corr

*JR orig: esttab match_corr using ${tab}/paper2/paperonly_corr_tv_matchrate_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(tv_sd) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g)) p(fmt(%12.0g))) obslast
*JR orig: estimates clear

*** Construct middle school indicator from cross-class analysis file for use in cross-cohort analyses
use `cfrdat'/analysis.dta, clear
*bys sch grade year: egen max_middle = max(middle)
gen byte max_middle=0
bys sch grade year: keep if _n==1
keep sch grade year max_middle
save `cfrdat'/sch_middle.dta, replace

***************************************
***** SCHOOL DISTRICT DATA COUNTS *****
***************************************

use `cfrdat'/schd_work.dta, clear

file open counts using "`tabdir'/paper1/paperonly_school_district_data_counts.csv", write text replace


* Number of students
tempfile codebooklog
log using `codebooklog', text
codebook stuid
log close

file open num_unique using `codebooklog', read text
file read num_unique line
while ("`1'"!="unique" & "`2'"!="values:") & (r(eof)==0) {
	file read num_unique line
	tokenize `"`line'"'
}
file close num_unique

*JR addition: Stata was choking on comments in the observation count.
local num3=real(subinstr("`3'",",","",.))
file write counts "Number of students," (`num3') _n

* Span of years
sum year
file write counts "Minimum year," (r(min)) _n
file write counts "Maximum year," (r(max)) _n

* Number of tests
*orig: keep stuid year math score PREZl_score l2_score l3_z_score l4_z_score l5_z_score l6_z_score f_score f2_score f3_z_score f4_z_score f5_z_score f6_z_score f7_z_score
keep stuid year math score PREZl_score 

rename score score10
*orig: rename (PREZl_score ) (score9 score8 score7 score6 score5 score4)
*orig: rename (f_score f2_score f3_z_score f4_z_score f5_z_score f6_z_score f7_z_score) (score11 score12 score13 score14 score15 score16 score17)
rename PREZl_score score9

reshape long score, i(stuid year math) j(shiftyear)
replace shiftyear=shiftyear-10

gen testyear=year+shiftyear

bys stuid math testyear: egen error=sd(score)
sum error
assert r(mean)==0

collapse score, by(stuid math testyear)
count if !missing(score)

file write counts "Number of test scores," (r(N)) _n


file close counts

 
if `doasproject'==1 {
	project, creates(`cfrdat'/tfx/sd_tfx.dta)
  project, creates(`tabdir'/paper2/paperonly_tv_insample_cutoffs.csv)
  project, creates(`cfrdat'/analysis.dta)
  project, creates(`cfrdat'/sch_middle.dta)
  project, creates(`tabdir'/paper1/paperonly_school_district_data_counts.csv)
}
 