*cfr_analysis_final_pt6.do
*By Jesse Rothstein
*7/28/2014
*
*Part 6 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************

*This program makes *large* temporary datasets. On my system, the regular TMPDIR
*isn't big enough for this. This code ensures that I've remembered to re-set
*TMPDIR before starting Stata to a directory that can handle this program.;
*Simple code to make sure tmpvar is set right;
 *tempfile test
 *di "`test'"
 *assert strpos("`test'", "/var/tmp/scratch")==1
 *If this fails, before running Stata type:
  * TMPDIR=/var/tmp/scratch
  * export TMPDIR
 *(This assumes bash shell -- may need other commands for other shells/OSes. 
 *Type "echo $0" to learn which you have.

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt6"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

*global datadir "`cfrdat'" /*JR orig: global datadir $root/datadir */
*JR orig: global IRSdir ${datadir}/from_IRS
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
	project, uses(`cfrdat'/SCHD_class_year_collapse.dta)
	project, uses(`cfrdat'/teacher_school_weights.dta)
	project, uses(`cfrdat'/tfx/tfx_tym.dta)
}

***************************START OF CFR PROGRAM********************************
*****************BASED ON LINES 1203-1393 OF ANALYSIS_FINAL.DO*****************


***************
*** Table 4 ***
***************
*** Generate the "teacher weights" and "SCHD_sch_gr_yr" with non-missing TV

** First construct teacher school weights using the class collapse with only those teachers who have non-missing tv
use `cfrdat'/SCHD_class_year_collapse, clear
keep sch year grade math teacher CLass_size

merge m:1 teacher year math sch grade using `cfrdat'/teacher_school_weights, keepusing(new_to_* switch_*)
compress
keep if _merge==3
drop _merge

merge m:1 teacher year math using 	`cfrdat'/tfx/tfx_tym
keep if _merge==3
drop _merge

keep if tv~=.
drop tv*

bys sch year grade math: egen n_rpool = sum(CLass_size)
g teach_wt = CLass_size/n_rpool
save `cfrdat'/table4_teacher_school_weights_with_tv_only, replace


** Second, construct school-grade collapse from class collapse, so we include only those with non-missing tv

*Only include classes where the modal grade is above 3
use `cfrdat'/SCHD_class_year_collapse if grade>=3, clear

* Merge in pred_score_nocontrols
merge 1:1 sch year class_id math using `cfrdat'/NOTIRS_SCHD_class_collapse, keepusing(predscore_pared)
drop if _merge==2
drop _merge

* Merge in tv measure
cap drop _merge
merge m:1 teacher year math using `cfrdat'/tfx/tfx_tym
drop if _merge==2
drop _merge

g covered_tv = tv~=.
drop tv*

*NOTE: Install gwtmean package if command below does not work (ssc inst _gwtmean, replace)
bys sch grade year math: egen mean_covered=wtmean(covered_tv), weight(CLass_size)
sum mean_covered,d
sum mean_covered if mean_covered>0,d

*Keep only those classes for which we have tv data - if we don't do this, we are effectively imputing other teachers' tv to the students who are not linked
keep if covered_tv

rename mean_score CLscore
bys sch grade year math: egen mean_score=wtmean(CLscore), weight(CLass_size)

rename mean_other CLother
bys sch grade year math: egen mean_other=wtmean(CLother), weight(CLass_size)

*JR orig: rename pred_score_nocontrols CLpred_score_nocontrols
rename predscore_pared CLpred_score_pared
*JR orig: bys sch grade year math: egen pred_score_nocontrols=wtmean(CLpred_score_nocontrols), weight(CLass_size) 
bys sch grade year math: egen pred_score_pared=wtmean(CLpred_score_pared), weight(CLass_size) 

drop mean_l_score
bys sch grade year math: egen mean_l_score=wtmean(CLPZl_score), weight(CLass_size)
bys sch grade year math: egen mean_l_other=wtmean(CLPOl_other), weight(CLass_size)
*bys sch grade year math: egen mean_t_exp_reg=wtmean(t_exp_reg), weight(CLass_size)
*bys sch grade year math: egen mean_t_exp_full=wtmean(t_exp_reg_full), weight(CLass_size)
bys sch grade year math: egen SGYsize=sum(CLass_size)
*keep sch grade year math mean_score mean_other pred_score_nocontrols SGYsize mean_t_exp* mean_l*
keep sch grade year math mean_score mean_other pred_score_pared SGYsize mean_l*
bys sch grade year math: keep if _n==1

* Merge in middle school indicator
*merge m:1 sch grade year using ${datadir}/sch_middle_irsdate${IRSdate}.dta
*assert _merge!=1
*drop if _merge==2
*drop _merge

save `cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only, replace

*** Analysis

prepare_quasi, tfxfile(`cfrdat'/tfx/tfx_tym) ///
	tch_sch_weights(`cfrdat'/table4_teacher_school_weights_with_tv_only) ///
	sch_gr_yr_collapse(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only) ///
	drop_empty_tv_cells

estimates clear
* Col 1
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
estimates store score_a_year
local coef=string(_b[d_tv_sgm_1],"%9.3f")
local se=string(_se[d_tv_sgm_1],"%9.3f")

* Figure 4a
binscatter d_mean_score d_tv_sgm_1 [aw=SGYsize], legend(off) ///
	ylabel(-0.1(0.05)0.1) ///
	noaddmean absorb(year) ///
	title("Changes in Actual Scores Across Cohorts", size(medium)) ///
	ytitle("Changes in Scores") ///
	xtitle("Changes in Mean Teacher Value-Added") ///
	note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall)) ///
	xlabel(-0.1(0.05)0.1)
multi_graph_export using `figdir'/paper1/fig4a


* Col 2
egen sch_yr = group(sch year)
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store score_a_sch_yr

* Col 3
tsset sgm_id year
g d_mean_l_other = d.mean_l_other
g d_mean_l_other2 = d_mean_l_other^2
g d_mean_l_other3 = d_mean_l_other^3
g d_mean_l_score = d.mean_l_score
g d_mean_l_score3 = d_mean_l_score^3
g d_mean_l_score2 = d_mean_l_score^2
 
areg d_mean_score d_tv_sgm_1 d_mean_l_score* d_mean_l_other* f.d_tv_sgm_1 l.d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store score_a_sch_yr_lags


* Col 4
g d_pred_score_pared = d.pred_score_pared
*JR orig: areg d_pred_score_nocontrols d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
*JR orig: estimates store predscore
*JR orig: local coef=string(_b[d_tv_sgm_1],"%9.3f")
*JR orig: local se=string(_se[d_tv_sgm_1],"%9.3f")
areg d_pred_score_pared d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store predscore
local coef=string(_b[d_tv_sgm_1],"%9.3f")
local se=string(_se[d_tv_sgm_1],"%9.3f")

* Figure 4b
*JR orig: binscatter d_pred_score_nocontrols d_tv_sgm_1 [aw=SGYsize], legend(off) 
binscatter d_pred_score_pared d_tv_sgm_1 [aw=SGYsize], legend(off) ///
 	ylabel(-0.1(0.05)0.1) ///
 	noaddmean absorb(sch_yr) ///
 	title("Changes in Predicted Scores Across Cohorts", size(medium)) ///
 	xtitle("Changes in Mean Teacher Value-Added") ///
 	ytitle("Changes in Predicted Scores") ///
 	note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall)) ///
 	xlabel(-0.1(0.05)0.1)
multi_graph_export using `figdir'/paper1/fig4b


esttab * using `tabdir'/paper1/table4.csv, replace keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear

* Col 5
*JR orig: areg d_mean_score d_tv_sgm_1 d_tv_sgm_other [w=SGYsize] if max_middle==1, cluster(sch_cohort) a(year)
*JR orig: estimates store other_mid
*JR orig: local coef=string(_b[d_tv_sgm_other],"%9.3f")
*JR orig: local se=string(_se[d_tv_sgm_other],"%9.3f")
*JR orig: 
*JR orig: file open pval using ${tab}/paper1/paperonly_table4_col56_pvals_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
*JR orig: file write pval "Table 4 Col 5 p-val," (2 * ttail(e(df_r), abs(_b[d_tv_sgm_other]/_se[d_tv_sgm_other]))) _n
*JR orig: file close pval

* Figure 5a
*JR orig: binscatter d_mean_score d_tv_sgm_other if max_middle==1 [aw=SGYsize], controls(d_tv_sgm_1) absorb(year) ///
*JR orig: 	reportreg legend(off) ///
*JR orig: 	ylabel(-0.1(0.05)0.1) ///
*JR orig: 	noaddmean ///
*JR orig: 	title("Changes in Other-Subject Scores Across Cohorts" "Middle Schools Only", size(medium)) ///
*JR orig: 	xtitle("Changes in Mean Teacher Value-Added") ///
*JR orig: 	ytitle("Changes in Other-Subject Scores") ///
*JR orig: 	note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall)) ///
*JR orig: 	xlabel(-0.1(0.05)0.1)
*JR orig: multi_graph_export using ${figdir}/paper1/fig5a_irsdate${IRSdate}_tfxdate${tfxdate}

* Col 6
*areg d_mean_score d_tv_sgm_1 d_tv_sgm_other [w=SGYsize] if max_middle==0, cluster(sch_cohort) a(year)
areg d_mean_score d_tv_sgm_1 d_tv_sgm_other [w=SGYsize] , cluster(sch_cohort) a(year)
estimates store other_elem
local coef=string(_b[d_tv_sgm_other],"%9.3f")
local se=string(_se[d_tv_sgm_other],"%9.3f")

file open pval using `tabdir'/paper1/paperonly_table4_col56_pvals.csv, write text append
file write pval "Table 4 Col 6 p-val," (2 * ttail(e(df_r), abs(_b[d_tv_sgm_other]/_se[d_tv_sgm_other]))) _n
file close pval

* Figure 5b
*binscatter d_mean_score d_tv_sgm_other if max_middle==0 [aw=SGYsize], controls(d_tv_sgm_1) absorb(year) 
binscatter d_mean_score d_tv_sgm_other [aw=SGYsize], controls(d_tv_sgm_1) absorb(year) ///
	reportreg legend(off) ///
	ylabel(-0.1(0.05)0.1) ///
	noaddmean ///
	title("Changes in Other-Subject Scores Across Cohorts" "Elementary Schools Only", size(medium)) ///
	xtitle("Changes in Mean Teacher Value-Added") ///
	ytitle("Changes in Other-Subject Scores") ///
	note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall)) ///
	xlabel(-0.1(0.05)0.1)
multi_graph_export using `figdir'/paper1/fig5b


esttab * using `tabdir'/paper1/table4.csv, append keep(d_tv_sgm_other) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear 

if `doasproject'==1 {
  project, creates(`cfrdat'/table4_teacher_school_weights_with_tv_only.dta)
  project, creates(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only.dta)
  project, creates(`figdir'/paper1/fig4a.gph)
  project, creates(`figdir'/paper1/fig4b.gph)
  project, creates(`tabdir'/paper1/table4.csv)
  project, creates(`tabdir'/paper1/paperonly_table4_col56_pvals.csv)
  project, creates(`figdir'/paper1/fig5b.gph)
}
