*cfr_analysis_final_pt7A.do
*By Jesse Rothstein
*March 23, 2015
*
*Part 7A of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************

*This program makes *large* temporary datasets. On my system, the regular TMPDIR
*isn't big enough for this. This code ensures that I've remembered to re-set
*TMPDIR before starting Stata to a directory that can handle this program.;
*Simple code to make sure tmpvar is set right;
 *tempfile test
 *di "`test'"
 *assert strpos("`test'", "/var/tmp/scratch")==1
 *If this fails, before running Stata type:
  * TMPDIR=/var/tmp/scratch
  * export TMPDIR
 *(This assumes bash shell -- may need other commands for other shells/OSes. 
 *Type "echo $0" to learn which you have.

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt7A"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

*global datadir "`cfrdat'" /*JR orig: global datadir $root/datadir */
*JR orig: global IRSdir ${datadir}/from_IRS
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
	project, uses(`cfrdat'/tfx/tfx_tym.dta)
	project, uses(`cfrdat'/table4_teacher_school_weights_with_tv_only.dta)
	project, uses(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only.dta)
	project, uses(`cfrdat'/teacher_school_weights.dta) 
	project, uses(`cfrdat'/SCHD_sch_gr_year_collapse.dta)
}

***************************START OF CFR PROGRAM********************************
*****************BASED ON LINES 1396-1495 OF ANALYSIS_FINAL.DO*****************

***************
*** Table 5 ***
***************

prepare_quasi, tfxfile(`cfrdat'/tfx/tfx_tym) ///
	tch_sch_weights(`cfrdat'/table4_teacher_school_weights_with_tv_only) ///
	sch_gr_yr_collapse(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only) ///
	drop_empty_tv_cells ///
	entry_exit
	
* Open file to store mean_covered csv
file open meancovered using `tabdir'/paper1/table5_bottomrow_meancovered.csv, write text replace
file write meancovered "Fraction with non-missing VA,"

* Double check that OLS reg matches Table 4, Col 1
set more off
xi: reg d_mean_score d_tv_sgm_1 i.year [w=SGYsize], cluster(sch_cohort)

* Col 1: IV with teacher exiters from district or school
*gen mean_tv_2yr_f_ds = mean_tv_2yr_f_d + mean_tv_2yr_f_s
gen mean_tv_2yr_f_stateschool = mean_tv_2yr_f_state + mean_tv_2yr_f_school
set more off
*xi: ivreg2 d_mean_score i.year (d_tv_sgm_1 = l.mean_tv_2yr_f_ds) [w=SGYsize], cluster(sch_cohort) first ffirst savefirst
xi: ivreg2 d_mean_score i.year (d_tv_sgm_1 = l.mean_tv_2yr_f_stateschool) [w=SGYsize], cluster(sch_cohort) first ffirst savefirst
estimates store col1

sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
file write meancovered ((__mean_cur+__mean_lag)/2) ","

esttab col* using `tabdir'/paper1/table5.csv, replace keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast

* Paper Only: first stage coeff
estimates restore _ivreg2_d_tv_sgm_1

file open firststage using `tabdir'/paper1/paperonly_table5iv_firststage.csv, write text replace
file write firststage "var,coef,se,t" _n
*file write firststage "l.mean_tv_2yr_f_ds," (_b[l.mean_tv_2yr_f_ds]) "," (_se[l.mean_tv_2yr_f_ds]) "," (_b[l.mean_tv_2yr_f_ds]/_se[l.mean_tv_2yr_f_ds])
file write firststage "l.mean_tv_2yr_f_states," (_b[l.mean_tv_2yr_f_stateschool]) "," (_se[l.mean_tv_2yr_f_stateschool]) "," (_b[l.mean_tv_2yr_f_stateschool]/_se[l.mean_tv_2yr_f_stateschool])
file close firststage


*** Cols 2-4: Cut sample by amount of imputed data
estimates clear
prepare_quasi, tfxfile(`cfrdat'/tfx/tfx_tym) ///
	tch_sch_weights(`cfrdat'/teacher_school_weights) ///
	sch_gr_yr_collapse(`cfrdat'/SCHD_sch_gr_year_collapse)


*Correlation between actual and mean-tv-based VA to report in paper
corr d_tv_sgm_1 d_tv_sgm_mean [w=SGYsize]

file open corr_actual_meantv using `tabdir'/paper1/paperonly_corr_actual_meantv_va.csv, write text replace
file write corr_actual_meantv "Correlation between actual and mean-tv-based VA to report in paper:" _n (r(rho)) _n

scalar __drift_var_ub=1-r(rho)^2
file write corr_actual_meantv "Drift accounts for less than (1-corr^2) of the variance in Q_sgt:" _n (__drift_var_ub) _n
file close corr_actual_meantv


* Col 2: Full sample reg
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
estimates store col2

sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
file write meancovered ((__mean_cur+__mean_lag)/2) ","

file open meancohort using `tabdir'/paper1/paperonly_table5_col2_meancohort.csv, write text replace
sum cohort if e(sample) [w=SGYsize], meanonly
file write meancohort (r(mean))
file close meancohort

* Col 3: Cut to sample with <25% imputed data
areg d_mean_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv>0.75 & l.mean_covered_tv>0.75, cluster(sch_cohort) a(year)
estimates store col3

sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
file write meancovered ((__mean_cur+__mean_lag)/2) ","

* Col 4: Cut to sample with no imputed data
areg d_mean_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv==1 & l.mean_covered_tv==1, cluster(sch_cohort) a(year)
estimates store col4

sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
file write meancovered ((__mean_cur+__mean_lag)/2) ","


* Output
file close meancovered

esttab * using `tabdir'/paper1/table5.csv, append keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear


 
 if `doasproject'==1 {
	project, creates(`tabdir'/paper1/table5_bottomrow_meancovered.csv)
	project, creates(`tabdir'/paper1/table5.csv)
	project, creates(`tabdir'/paper1/paperonly_table5iv_firststage.csv)
	project, creates(`tabdir'/paper1/paperonly_corr_actual_meantv_va.csv)
	project, creates(`tabdir'/paper1/paperonly_table5_col2_meancohort.csv)
}
