*cfr_analysis_final_pt7B.do
*By Jesse Rothstein
*March 23, 2015
*
*Part 7B of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************

*This program makes *large* temporary datasets. On my system, the regular TMPDIR
*isn't big enough for this. This code ensures that I've remembered to re-set
*TMPDIR before starting Stata to a directory that can handle this program.;
*Simple code to make sure tmpvar is set right;
 *tempfile test
 *di "`test'"
 *assert strpos("`test'", "/var/tmp/scratch")==1
 *If this fails, before running Stata type:
  * TMPDIR=/var/tmp/scratch
  * export TMPDIR
 *(This assumes bash shell -- may need other commands for other shells/OSes. 
 *Type "echo $0" to learn which you have.

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt7"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

*global datadir "`cfrdat'" /*JR orig: global datadir $root/datadir */
*JR orig: global IRSdir ${datadir}/from_IRS
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
	project, uses(`cfrdat'/schd_work_trim.dta)
*	project, uses(`cfrdat'/tfx/tfx_tym.dta)
*	project, uses(`cfrdat'/table4_teacher_school_weights_with_tv_only.dta)
*	project, uses(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only.dta)
*	project, uses(`cfrdat'/teacher_school_weights.dta) 
*	project, uses(`cfrdat'/SCHD_sch_gr_year_collapse.dta)
}

***************************START OF CFR PROGRAM********************************
*****************BASED ON LINES 1498-1721 OF ANALYSIS_FINAL.DO*****************


***************
*** Table 6 ***
***************

 use `cfrdat'/schd_work_trim.dta, clear
 
 ***** PREPARATION *****
 
 *** Define list of specifications that are run
 
 *global table6filelist "nofe febinter lagscoreonly lagscoreonly_noschcl_nointer lagscoreonly_own_nointer justdemo nocontrols"
 local table6filelist "nofe lagscoreonly lagscoreonly_noschcl_nointer lagscoreonly_own_nointer justdemo nocontrols"
 
 *** Define globals for different groups of baseline control vars
 
 local VAM_score_ind_samesubject "PREZ*"
 local VAM_score_ind_othersubject "PREO* MPREO*"
 
 *global VAM_demog_ind "ETHN* sped female age_current miss_lunch lunch limited_english repeat_grade repeat_test absences suspensions post99_sped post99_limited_eng"
 local VAM_demog_ind "ETHN* sped female age_current miss_lunch lunch limited_english repeat_grade repeat_test MISS_sped MISS_age_current MISS_limited_english"
 
 local VAM_score_class_samesubject "CLPZ*"
 local VAM_score_class_othersubject "CLPO* CLMPREO*"
 
 *global VAM_demog_class "CLETHN* CLsped CLfemale CLage_current CLmiss_lunch CLlunch CLlimited_english CLrepeat_grade CLrepeat_test CLabsences CLsuspensions CLpost99_sped CLpost99_limited_eng CLass_size hon rem enrich mod foreign"
 local VAM_demog_class "CLETHN* CLsped CLfemale CLage_current CLmiss_lunch CLlunch CLlimited_english CLrepeat_grade CLrepeat_test CLMISS_* CLass_size "
 
 local VAM_score_schgr_samesubject "SGPZ*"
 local VAM_score_schgr_othersubject "SGPO* SYMPREO"
 
 *global VAM_demog_schgr "SYETHN* SYsped SYfemale SYage_current SYmiss_lunch SYlunch SYlimited_english SYrepeat_grade SYrepeat_test SYabsences SYsuspensions SYpost99_sped SYpost99_limited_eng"
 local VAM_demog_schgr "SYETHN* SYsped SYfemale SYage_current SYmiss_lunch SYlunch SYlimited_english SYrepeat_grade SYMISS_* SYrepeat_test"
 
 local VAM_year_grade_fe "YEAR* GRDE*"
 
 
 * Check that the sum of the grouped control vars equals the number of baseline vars
 local count_group=0
 foreach group in VAM_score_ind_samesubject VAM_score_ind_othersubject VAM_demog_ind VAM_score_class_samesubject VAM_score_class_othersubject VAM_demog_class VAM_score_schgr_samesubject VAM_score_schgr_othersubject VAM_demog_schgr VAM_year_grade_fe {
 	foreach var of varlist ``group'' {
 		local ++count_group
 	}
 }
 
 local count_baseline=0
 foreach var of varlist $baseline_VAM_controls {
 	local ++count_baseline
 }
 
 di "Number of vars in baseline VAM control vector: `count_baseline'"
 di "Number of vars in VAM control vector groups: `count_group'"
 
 
 assert `count_baseline'==`count_group'
 
 di "got to here"
 
 /*
 *** Add Feburary test interactions
 
 merge m:1 year grade math using ${datadir}/high_stakes_and_early_test_indicators_1989_2009_g0_g8_withother.dta, assert(2 3) keep(3) nogen keepusing(lag_early_test lag_early_test_other)
 
 foreach var of varlist $VAM_score_ind_samesubject {
 	gen FEB`var' =`var'*lag_early_test
 }
 
 foreach var of varlist $VAM_score_ind_othersubject {
 	gen FEB`var' =`var'*lag_early_test_other
 }
 
 global VAM_score_febinter_ind "FEB* lag_early_test lag_early_test_other"
 */ 
 
 *** Calculate TV measures
 
 * Use same sample for each tv measure
 mark VAsample
 *markout VAsample teacher year middle math score ${baseline_VAM_controls}
 markout VAsample teacher year math score ${baseline_VAM_controls}
 replace score=. if VAsample==0
 
 * 1: "baseline". Just use the generated baseline files rather than recomputing.
 *JR Note: This is row 1 of Table 6
 *Original command, for reference:
   *vam score, teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
	 * controls(${baseline_VAM_controls}) output(`cfrdat'/tfx/tfx) ///
	 * tfx_resid(teacher) by(math) driftlimit(7) quasi ///
	 * data(merge tv score_r)


 * 2: "nofe".  Remove teacher FE but leave baseline controls
 *JR Note: This is row 2 of Table 6
 vam score,  teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
 			output(`cfrdat'/tfx/table6/table6_tfx_nofe) ///
 			by(math) driftlimit(7) quasi data(merge tv score_r) ///
 			controls(${baseline_VAM_controls})
 *JR: Drop the "postvam_save_l2score" commands -- slow, create big data sets, and not
 *JR: used again.
 *postvam_save_l2score, output(`cfrdat'/tfx/table6/table6_l2bias_nofe) score_r_l2 l2_score_r ///
 *			controls(${baseline_VAM_controls})
 drop tv* score_r

 * 3: "febinter". Add interaction of my prior scores with indicator for prior test is from feburary
 *JR Note: This is not included in the published Table 6
 *vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
 *			output(`cfrdat'/tfx/table6_tfx_febinter_${tfxdate}) ///
 *			tfx_resid(teacher) by(middle math) driftlimit(7) quasi data(merge tv score_r) ///
 *			controls(${baseline_VAM_controls} ${VAM_score_febinter_ind})
 *			
 *postvam_save_l2score, output(${datadir}/tfx/table6_l2bias_febinter_tfxdate${tfxdate}) score_r_l2 l2_score_r ///
 *			controls(${baseline_VAM_controls} ${VAM_score_febinter_ind})

 * 4: "lagscoreonly". Remove all non test controls except grade/year FE
 *JR Note: This is row 4 of Table 6
 vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
 			output(`cfrdat'/tfx/table6/table6_tfx_lagscoreonly) ///
 			tfx_resid(teacher) by(math) driftlimit(7) quasi data(merge tv score_r) ///
 			controls(`VAM_score_ind_samesubject' `VAM_score_ind_othersubject' ///
 					 `VAM_score_class_samesubject' `VAM_score_class_othersubject' ///
 					 `VAM_score_schgr_samesubject' `VAM_score_schgr_othersubject' ///
 					 `VAM_year_grade_fe' ///
 					)
 *JR: Drop the "postvam_save_l2score" commands -- slow, create big data sets, and not
 *JR: used again.
 *postvam_save_l2score, output(`cfrdat'/tfx/table6/table6_l2bias_lagscoreonly) score_r_l2 l2_score_r ///
 *			controls(`VAM_score_ind_samesubject' `VAM_score_ind_othersubject' ///
 *					 `VAM_score_class_samesubject' `VAM_score_class_othersubject' ///
 *					 `VAM_score_schgr_samesubject' `VAM_score_schgr_othersubject' ///
 *					 `VAM_year_grade_fe' ///
 *					)
 drop tv* score_r
 
 
 * 5: "lagscoreonly_noschcl_nointer" drop class/school lagged scores AND drop grade interactions of own score --> six prior score variables + missing prior other score cubic + grade/year FE
 *JR Note: This is row 5 of Table 6
 vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
 			output(`cfrdat'/tfx/table6/table6_tfx_lagscoreonly_noschcl_nointer) ///
 			tfx_resid(teacher) by(math) driftlimit(7) quasi data(merge tv score_r) ///
 			controls(PREZl_score PREZl_score2 PREZl_score3 ///
 					 PREOl_other PREOl_other2 PREOl_other3 ///
 					 MPREO MPREOPREZl_score MPREOPREZl_score2 MPREOPREZl_score3 ///
 					 `VAM_year_grade_fe' ///
 					)
 *JR: Drop the "postvam_save_l2score" commands -- slow, create big data sets, and not
 *JR: used again.
 *postvam_save_l2score, output(`cfrdat'/tfx/table6/table6_l2bias_lagscoreonly_noschcl_nointer) score_r_l2 l2_score_r ///
 *			controls(PREZl_score PREZl_score2 PREZl_score3 ///
 *					 PREOl_other PREOl_other2 PREOl_other3 ///
 *					 MPREO MPREOPREZl_score MPREOPREZl_score2 MPREOPREZl_score3 ///
 *					 `VAM_year_grade_fe' ///
 *					)
 drop tv* score_r
 
 
 * 6: "lagscoreonly_own_nointer"
 *JR Note: This is row 6 of Table 6
 vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
 			output(`cfrdat'/tfx/table6/table6_tfx_lagscoreonly_own_nointer) ///
 			tfx_resid(teacher) by(math) driftlimit(7) quasi data(merge tv score_r) ///
 			controls(PREZl_score PREZl_score2 PREZl_score3 ///
 					 `VAM_year_grade_fe' ///
 					)
 *JR: Drop the "postvam_save_l2score" commands -- slow, create big data sets, and not
 *JR: used again.
 *postvam_save_l2score, output(`cfrdat'/tfx/table6/table6_l2bias_lagscoreonly_own_nointer) score_r_l2 l2_score_r ///
 *			controls(PREZl_score PREZl_score2 PREZl_score3 ///
 *					 `VAM_year_grade_fe' ///
 *					)
 drop tv* score_r
 
 * 7: "justdemo". Remove all test controls but include non-test controls + grade/year FE
 *JR Note: This is row 7 of Table 6
 vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
 			output(`cfrdat'/tfx/table6/table6_tfx_justdemo) ///
 			tfx_resid(teacher) by(math) driftlimit(7) quasi data(merge tv score_r) ///
 			controls(`VAM_demog_ind' `VAM_demog_class' `VAM_demog_schgr' ///
 					 `VAM_year_grade_fe' ///
 					)
 *JR: Drop the "postvam_save_l2score" commands -- slow, create big data sets, and not
 *JR: used again.
 *postvam_save_l2score, output(`cfrdat'/tfx/table6/table6_l2bias_justdemo) score_r_l2 l2_score_r ///
 *			controls(`VAM_demog_ind' `VAM_demog_class' `VAM_demog_schgr' ///
 *					 `VAM_year_grade_fe' ///
 *					)
 drop tv* score_r
 
 
 * 8: "nocontrols". Remove all controls except grade and year FE
 *JR Note: This is row 8 of Table 6
 vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
 			output(`cfrdat'/tfx/table6/table6_tfx_nocontrols) ///
 			by(math) driftlimit(7) quasi data(merge tv score_r) ///
 			controls(`VAM_year_grade_fe')
 *JR: Drop the "postvam_save_l2score" commands -- slow, create big data sets, and not
 *JR: used again.
 *postvam_save_l2score, output(`cfrdat'/tfx/table6/table6_l2bias_nocontrols) score_r_l2 l2_score_r ///
 *			controls(`VAM_year_grade_fe') 
 drop tv* score_r
 
 *** Generate teacher-year-math versions of TV estimates
 foreach file in `table6filelist' {	
 	use `cfrdat'/tfx/table6/table6_tfx_`file', clear
 	collapse (mean) tv*, by (teacher year math)
 	save `cfrdat'/tfx/table6/table6_tfx_`file'_tym, replace
 }
 
 
 ***** ANALYSIS *****
 
 * Merge all the measures together by teacher year and subject
 
 use `cfrdat'/tfx/tfx_tym, clear
 drop tv_*
 rename tv tv_1
 
 local i=2
 set more off
 
  
 foreach file in `table6filelist' {
 	merge 1:1 teacher year math using `cfrdat'/tfx/table6/table6_tfx_`file'_tym, assert(3) nogen keepusing(tv)
 	rename tv tv_`i'
 	local i=`i'+1
 }
 
 
 *** Column 1: correlation of different VA specifications with baseline VA specification
 	
 * Produce and save correlation matrix
 correlate tv_*
 matrix corr=r(C)
 scalar corr_N=r(N)
 local dim=rowsof(corr)
 
 file open corr_output using `tabdir'/paper1/table6_col1.csv, write text replace
 file write corr_output ",baseline" _n
 
 forvalues i=1/`dim' {
 	if (`i'==1) file write corr_output "baseline,"
 	else file write corr_output (word("`table6filelist'",`i'-1)) ","
 
 	file write corr_output (corr[1,`i']) _n
 }
 file write corr_output _n "N tv obs,"
 file write corr_output (corr_N) 
 file close corr_output
 
 
 *** Column 2: Cross-cohort quasi-experimental bias estimates
 
 capture erase `tabdir'/paper1/table6_col2.csv
 
 set more off
 foreach file in baseline `table6filelist' {
 
 		if ("`file'"=="baseline") local tfxfile `cfrdat'/tfx/tfx_tym
 		else local tfxfile `cfrdat'/tfx/table6/table6_tfx_`file'_tym
 
 		* Note that the required teacher_school_weights are computed in Table 4 above.
 		prepare_quasi, tfxfile(`tfxfile') ///
 			tch_sch_weights(`cfrdat'/table4_teacher_school_weights_with_tv_only) ///
 			sch_gr_yr_collapse(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only) ///
 			drop_empty_tv_cells

 		 estimates clear
 		 * Note: the number reported in the table is 1 minus this reg coeff.
 		 areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
 		 estimates store score_a_year
 	
 		 esttab score_a_year using `tabdir'/paper1/table6_col2.csv, append keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
 		 estimates clear

 }
 
 
  
 
 if `doasproject'==1 {
 	
 	 foreach file in `table6filelist' {
 		 project, creates(`cfrdat'/tfx/table6/table6_tfx_`file'.dta)
 		 project, creates(`cfrdat'/tfx/table6/table6_tfx_`file'_log.smcl)
 		 project, creates(`cfrdat'/tfx/table6/table6_tfx_`file'_variance.csv)
 		 project, creates(`cfrdat'/tfx/table6/table6_tfx_`file'_tym.dta)
 	 	 *project, creates(`cfrdat'/tfx/table6/table6_l2bias_`file'.dta)
 	 }
 	 *project, creates(`cfrdat'/tfx/table6/table6_quasi_baseline.dta)
 	 project, creates(`tabdir'/paper1/table6_col1.csv)
 	 project, creates(`tabdir'/paper1/table6_col2.csv)
 }
