*cfr_analysis_final_pt8.do
*By Jesse Rothstein
*7/28/2014
*
*Part 8 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************



*This program makes *large* temporary datasets. On my system, the regular TMPDIR
*isn't big enough for this. This code ensures that I've remembered to re-set
*TMPDIR before starting Stata to a directory that can handle this program.;
*Simple code to make sure tmpvar is set right;
 *tempfile test
 *di "`test'"
 *assert strpos("`test'", "/var/tmp/scratch")==1
 *If this fails, before running Stata type:
  * TMPDIR=/var/tmp/scratch
  * export TMPDIR
 *(This assumes bash shell -- may need other commands for other shells/OSes. 
 *Type "echo $0" to learn which you have.

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt8"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

*global datadir "`cfrdat'" /*JR orig: global datadir $root/datadir */
*JR orig: global IRSdir ${datadir}/from_IRS
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
  project, uses(`cfrdat'/schd_work_trim.dta)
  project, uses(`cfrdat'/tfx/score_r.dta)
  project, uses(`cfrdat'/tfx/tfx_tym.dta)
}

***************************START OF CFR PROGRAM********************************
*****************BASED ON LINES 1724-1838 OF ANALYSIS_FINAL.DO*****************

***************
*** Table 7 ***
*** JR NOTE: This is now appendix table 2 ***
***************

* True Tracking.  Note: Cols 3,4,6 use individual-level parent characteristics and are therefore produced at the IRS.

use `cfrdat'/schd_work_trim.dta, clear

* Merge in score_r
merge 1:1 stuid teacher year class_id math using `cfrdat'/tfx/score_r, assert(3) nogen keepusing(score_r)
*gen middle_math=middle*math

* Merge in tv from the _tym file so that the sample matches correctly
merge m:1 teacher year math using `cfrdat'/tfx/tfx_tym.dta, assert(3) nogen

* Restrict to obs with score_r non-missing, as is done on the inside
drop if missing(score_r)

* Generate minority indicator: hispanic or black
*g minority = ETHNethnici_3+ETHNethnici_4
g minority = ETHNethnici_1+ETHNethnici_2
bys sch: egen mean_sch_minority = mean(minority)

* Generate grade 8 scores
*gen gr8_score=score if grade==8
gen gr5_score=score if grade==5

estimates clear

* Col 1: Lagged Scores
reg tv PREZl_score, cluster(teacher)
estimates store col1

* CALCULATE MULTIPLICATION FACTOR FOR TABLE 7 - multiply in excel after
merge m:1 math using `cfrdat'/tfx/sd_tfx, assert(3) nogen
gen tv_sd = tv/sd_tfx
sum tv_sd if e(sample)
di "Scaling Factor for True VA on LHS = " 1/r(sd)

* Col 2: Special Education
reg tv sped, cluster(teacher)
estimates store col2

* Paper only: Special education conditional on lagged scores
reg tv sped PREZl_score, cluster(teacher)
estimates store paperonly

* Col 5: Race (minority dummy)
reg tv minority, cluster(teacher)
estimates store col5

* Col 7: School-level race (sch_minority fraction)
reg tv mean_sch_minority, cluster(teacher)
estimates store col7

*esttab col* using ${tab}/paper1/table7_col1257.csv, replace keep(PREZl_score sped minority mean_sch_minority) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) r2(%12.0g) obslast
*esttab paperonly* using ${tab}/paper1/paperonly_table7_specialed_lagscore.csv, replace keep(PREZl_score sped) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) r2(%12.0g) obslast
esttab col1 col2 paperonly col5 col7 using `tabdir'/paper1/table7_col1257.csv, replace keep(PREZl_score sped minority mean_sch_minority) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) r2(%12.0g) obslast

estimates clear


*** For text only: decompose the SD of tv and grade 8 scores

file open sd_decomp using `tabdir'/paper1/paperonly_SD_decomposition_tv_gr5score.csv, write text replace
file write sd_decomp ",total,between sch,within sch,N,N_sch" _n

** Unadjusted

* Output SDs
xtset sch

xtsum tv
file write sd_decomp "tv,`r(sd)',`r(sd_b)',`r(sd_w)',`r(N)',`r(n)'" _n

xtsum gr5_score
file write sd_decomp "gr5_score,`r(sd)',`r(sd_b)',`r(sd_w)',`r(N)',`r(n)'" _n

** Adjusted for accumulation of TV impacts

* Generate vars
egen student_subject=group(stuid math)
tsset student_subject year

gen tv_gr5=l.tv if grade==5
gen tv_gr4=l2.tv if grade==5
gen tv_gr3=l3.tv if grade==5

egen tv_career=rowmean(tv tv_gr5 tv_gr4 tv_gr3) if grade==5

*preserve
*insheet using ${tab}/paper2/appxtable10.csv, clear comma
*assert abs((coeff[4]+coeff[5])/2 - 0.25)<.015
*scalar __allgrades_raise_score = coeff[1]+coeff[2]+coeff[3]+0.25*6
*restore

*gen gr5_score_corrected=gr5_score - __allgrades_raise_score * tv_career

* Output SDs
xtset sch

xtsum tv_career
file write sd_decomp "tv_career,`r(sd)',`r(sd_b)',`r(sd_w)',`r(N)',`r(n)'" _n

*xtsum gr8_score_corrected
*file write sd_decomp "gr5_score_corrected,`r(sd)',`r(sd_b)',`r(sd_w)',`r(N)',`r(n)'" _n

*file write sd_decomp _n _n "Estimated effect of a 1 unit improvement in teacher quality in all grades K-8 on grade 8 test scores:," _n (__allgrades_raise_score)

file close sd_decomp



************************
*** Appendix Table 1 ***
************************

* Appendix Table 1 is just an illustration of the data structure; it does not contain any results.
* It is made in Excel.

if `doasproject'==1 {
  project, creates(`tabdir'/paper1/table7_col1257.csv)
  project, creates(`tabdir'/paper1/paperonly_SD_decomposition_tv_gr5score.csv)
}
 