*cfr_analysis_final_pt9.do
*By Jesse Rothstein
*7/28/2014
*
*Part 9 of a series of programs, based on CFRs analysis_final.do 
*(April 2014 version).
*
***********************************************************************

*This program makes *large* temporary datasets. On my system, the regular TMPDIR
*isn't big enough for this. This code ensures that I've remembered to re-set
*TMPDIR before starting Stata to a directory that can handle this program.;
*Simple code to make sure tmpvar is set right;
 *tempfile test
 *di "`test'"
 *assert strpos("`test'", "/var/tmp/scratch")==1
 *If this fails, before running Stata type:
  * TMPDIR=/var/tmp/scratch
  * export TMPDIR
 *(This assumes bash shell -- may need other commands for other shells/OSes. 
 *Type "echo $0" to learn which you have.

version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr_analysis_final_pt9"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/cfr"

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

*global datadir "`cfrdat'" /*JR orig: global datadir $root/datadir */
*JR orig: global IRSdir ${datadir}/from_IRS
if `doasproject'==1 project, relies_on(`thisdir'/cfr_analysis_final_setup.do)
include `thisdir'/cfr_analysis_final_setup.do

if `doasproject'==1 {
	project, uses(`cfrdat'/tfx/tfx_variance.csv)
	project, uses(`cfrdat'/teacher_school_weights.dta)
	project, uses(`cfrdat'/tfx/tfx_tym.dta)
	project, uses(`cfrdat'/SCHD_sch_gr_year_collapse.dta)
  project, uses(`cfrdat'/analysis.dta)
}
	
***************************START OF CFR PROGRAM********************************
*****************BASED ON LINES 1841-2671 OF ANALYSIS_FINAL.DO*****************
	
****************
*** Figure 1 ***
****************

*** Figure 1, Panel A: Elementary school autocorrelation vector
insheet using `cfrdat'/tfx/tfx_variance.csv, comma clear
rename corr_lag_reading corr_lag_elementary_reading
rename corr_lag_math corr_lag_elementary_math

local driftlimit_elem_reading=corr_lag_elementary_reading[7]
local driftlimit_elem_math=corr_lag_elementary_math[7]

*JR: CFR original code
*twoway  (scatter corr_lag_elementary_reading lag if inrange(lag,1,7), c(l) sort) ///
*	(scatter corr_lag_elementary_reading lag if inrange(lag,8,10), mcolor(navy)) ///
*	(scatter corr_lag_elementary_math lag if inrange(lag,0,7), c(l) sort msymbol(T) lcolor(maroon) mcolor(maroon)) ///
*	(scatter corr_lag_elementary_math lag if inrange(lag,8,10), msymbol(T) mcolor(maroon)) ///
*	(function y=`driftlimit_elem_reading', range(7 10) lcolor(navy)) ///
*	(function y=`driftlimit_elem_math', range(7 10) lcolor(maroon)), ///
*	ylab(0(0.1)0.5) ///
*	graphregion(fcolor(white)) ///
*	title("Autocorrelation Vector in Elementary School for English and Math Scores", size(medium)) ///
*	xtitle("Years Separation Between Classes") ///
*	ytitle("Correlation") ///
*	legend(order(1 "English" 3 "Math"))

*My slight modification to correspond to their formatting
twoway  (scatter corr_lag_elementary_reading lag if inrange(lag,1,7), c(l) sort) ///
	(scatter corr_lag_elementary_reading lag if inrange(lag,8,10), mcolor(navy)) ///
	(scatter corr_lag_elementary_math lag if inrange(lag,0,7), c(l) sort msymbol(T) lcolor(maroon) mcolor(maroon)) ///
	(scatter corr_lag_elementary_math lag if inrange(lag,8,10), msymbol(T) mcolor(maroon)) ///
	(function y=`driftlimit_elem_reading', range(7 10) lcolor(navy) lpattern(dash)) ///
	(function y=`driftlimit_elem_math', range(7 10) lcolor(maroon) lpattern(dash)), ///
	ylab(0(0.1)0.5, format(%3.1f) nogrid) ///
	graphregion(fcolor(white)) ///
	title("Autocorrelation Vector in Elementary School for English and Math Scores", size(medium)) ///
	xtitle("Years Between Classes") ///
	ytitle("Correlation") ///
	legend(order(1 "English" 3 "Math") region(lstyle(none)))
multi_graph_export using `figdir'/paper1/fig1a_autocovar_elem

*** Figure 1, Panel B: Middle school autocorrelation vector
*JR: local driftlimit_midd_reading=corr_lag_middle_reading[7]
*JR: local driftlimit_midd_math=corr_lag_middle_math[7]
*JR: 
*JR: twoway  (scatter corr_lag_middle_reading lag if inrange(lag,1,7), c(l) sort) ///
*JR: 	(scatter corr_lag_middle_reading lag if inrange(lag,8,10), mcolor(navy)) ///
*JR: 	(scatter corr_lag_middle_math lag if inrange(lag,0,7), c(l) sort msymbol(T) lcolor(maroon) mcolor(maroon)) ///
*JR: 	(scatter corr_lag_middle_math lag if inrange(lag,8,10), msymbol(T) mcolor(maroon)) ///
*JR: 	(function y=`driftlimit_midd_reading', range(7 10) lcolor(navy)) ///
*JR: 	(function y=`driftlimit_midd_math', range(7 10) lcolor(maroon)), ///
*JR: 	ylab(0(0.1)0.5) ///
*JR: 	graphregion(fcolor(white)) ///
*JR: 	title("Autocorrelation Vector in Middle School for English and Math Scores", size(medium)) ///
*JR: 	xtitle("Years Separation Between Classes") ///
*JR: 	ytitle("Correlation") ///
*JR: 	legend(order(1 "English" 3 "Math"))
*JR: multi_graph_export using ${figdir}/paper1/fig1b_autocovar_middle


****************
*** Figure 2 ***
****************

* see above in Table 3 code.


****************************************************
***** Figure 3: Teacher Switcher Event Studies *****
****************************************************

***** DATA SETUP FOR TEACHER SWITCHER EVENT STUDIES *****

use `cfrdat'/teacher_school_weights, clear

* Output percentages of type of switch
file open switchtype using `tabdir'/paper1/paperonly_turnover_switchtype.csv, write text replace
sum switch_grade
file write switchtype "Fraction switch grade:," (r(mean)) _n
sum switch_school
file write switchtype "Fraction switch school:," (r(mean)) _n
sum switch_state
file write switchtype "Fraction switch state:," (r(mean)) _n
file close switchtype

* Merge in VA
merge m:1 teacher year math using `cfrdat'/tfx/tfx_tym, assert(1 3) nogen

assert !missing(grade)
save `cfrdat'/teach_va_weights, replace

collapse (sum) mean_tv_ss=tv_ss [iw=teach_wt], by(sch grade year math)

*Use FULL school district data here (not just analysis sample cohorts) because we need many years for event studies
merge 1:1 sch grade year math using `cfrdat'/SCHD_sch_gr_year_collapse
keep if _merge==3
drop _merge

save `cfrdat'/sch_gr_yr_work1, replace

*STEP 2: Identify teacher switchers by grade
use `cfrdat'/teach_va_weights, clear


egen tsgm_id = group(sch teacher grade math)
tsset tsgm_id year

*Define leavers and entries by requiring that (1) teacher teaches a positive fraction of students in current year and (2) is not in the school-subject-grade for either the next 3 years or past 3 years
*Note that year of event is therefore 0 for entry (i.e. entry occurs in year 0) and +1 for exit (i.e. first year after exit is +1).  We adjust exit graphs x axis by subtracting 1 in code for figure 3b and figure 3d below.

g t_leave = f.teach_wt==.&f2.teach_wt==.&f3.teach_wt==. if year<2011 & teach_wt>0 & teach_wt<. 
g t_enter = l.teach_wt==.&l2.teach_wt==.&l3.teach_wt==. if year>1997 & teach_wt>0 & teach_wt<. 

g va_leave = tv_ss if t_leave==1
g va_enter = tv_ss if t_enter==1


*** Break entrance and departure events up by whether the teacher left/entered the district, the school, or switched from within the school
* 		note: switch_district==1 and switch_school==1 are mutually exclusive. so these groups are a full partition.

* District
g t_leave_d = f.teach_wt==.&f2.teach_wt==.&f3.teach_wt==. if year<2011 & teach_wt>0 & teach_wt<. & switch_state==1
g t_enter_d = l.teach_wt==.&l2.teach_wt==.&l3.teach_wt==. if year>1997 & teach_wt>0 & teach_wt<. & new_to_state==1

g va_leave_d = tv_ss if t_leave_d==1
g va_enter_d = tv_ss if t_enter_d==1

* School
g t_leave_s = f.teach_wt==.&f2.teach_wt==.&f3.teach_wt==. if year<2011 & teach_wt>0 & teach_wt<. & switch_school==1
g t_enter_s = l.teach_wt==.&l2.teach_wt==.&l3.teach_wt==. if year>1997 & teach_wt>0 & teach_wt<. & new_to_school==1

g va_leave_s = tv_ss if t_leave_s==1
g va_enter_s = tv_ss if t_enter_s==1

* Grade (i.e. within-school)
g t_leave_g = f.teach_wt==.&f2.teach_wt==.&f3.teach_wt==. if year<2011 & teach_wt>0 & teach_wt<. & switch_school==0 & switch_state==0
g t_enter_g = l.teach_wt==.&l2.teach_wt==.&l3.teach_wt==. if year>1997 & teach_wt>0 & teach_wt<. & new_to_school==0 & new_to_state==0

g va_leave_g = tv_ss if t_leave_g==1
g va_enter_g = tv_ss if t_enter_g==1


*Define average value_added of leavers and enterers
bys sch grade year math: egen leave_n = sum(t_leave)
bys sch grade year math: egen enter_n = sum(t_enter)
bys sch grade year math: egen leave_va = mean(va_leave)
bys sch grade year math: egen enter_va = mean(va_enter)


*** Now break up the avg value added into three component parts: district, school, grade changes.
*		note that we do not take separate means by type of change, these would not sum to the total.
*		we sum VA within type and divide by the same denominator as with the overall average
* 		we also set these VA measures to zero if no leave/entrance of the type took place but a leave/entrance of another type took place

foreach type in d s g {
	bys sch grade year math: egen leave_n_`type' = sum(t_leave_`type')
	bys sch grade year math: egen enter_n_`type' = sum(t_enter_`type')

	bys sch grade year math: egen leave_va_`type' = sum(va_leave_`type')
	replace leave_va_`type'=0 if leave_n>0 & leave_va_`type'==.
	replace leave_va_`type'=leave_va_`type'/leave_n

    bys sch grade year math: egen enter_va_`type' = sum(va_enter_`type')
	replace enter_va_`type'=0 if enter_n>0 & enter_va_`type'==.
	replace enter_va_`type'=enter_va_`type'/enter_n
}

*Collapse the dataset to the school-grade-subject-year level
bys sch grade year math: keep if _n==1

keep sch grade year math leave_n-enter_va_g has_*rookie
order sch grade year math leave* enter* has*
compress

*Merge back on the school-grade-subject-year test score data
merge 1:1 sch grade year math using `cfrdat'/sch_gr_yr_work1, keep(3) nogen

gen cohort =year-grade
egen cohort_id = group(sch cohort math)
egen grade_id = group(sch grade math)
tsset grade_id cohort


***********************************************************************************************************************************************
* REFEREE ASKS: WHEN A TEACHER SWITCHES OUT OF THEIR CURRENT SCHOOL-GRADE-SUBJECT, WHAT % OF THE TIME ARE THEY REPLACED WITH A NEW TEACHER,
* A TEACHER FROM ANOTHER SCHOOL, OR A TEACHER FROM WITHIN THE SAME SCHOOL?

gen prior_leave=l.leave_n>0 if l.leave_n<.

foreach type in g s d {
	gen enter_any_`type' = enter_n_`type'>0 & enter_n_`type'<.
}

log using `logdir'/percent_replacement_for_referee, replace
bysort prior_leave: sum enter_any_*
log close

drop enter_any_* prior_leave
***********************************************************************************************************************************************


*Require school-grade-subject cell to exist for 5 years around event (this requirement is subsumed by balanced panel below)

tsset grade_id cohort

g close = f.mean_score==.|f2.mean_score==.
g open = l2.mean_score==.|l.mean_score==.
replace leave_n = 0 if close==1|open==1
replace enter_n = 0 if close==1|open==1


foreach type in d s g {
	replace leave_n_`type' = 0 if close==1|open==1
	replace enter_n_`type' = 0 if close==1|open==1
}


g d_score = mean_score-mean_l_score

keep if grade>2



***** Define events
* 		Note that the "subset" of events based on district, school, or grade switches are not strictly a subset because we are averaging va across all entries
* 		in the general case, and only among a subset of entries in the specific cases.
* 			ex: 1 great teacher may enter the district, but 1 bad teacher enters from within the school, and the total VA does not rise above the 95th percentile.

*Merge on middle school indicator, constructed from class data
*merge m:1 sch grade year using ${datadir}/sch_middle_irsdate${IRSdate}, keep(1 3) nogen

set more off

* Create variables
g byte high_entry_event = 0
g byte low_entry_event = 0 
g byte high_exit_event = 0
g byte low_exit_event = 0 

foreach type in d s g {
	g byte high_entry_event_`type' = 0
	g byte low_entry_event_`type' = 0
	g byte high_exit_event_`type' = 0
	g byte low_exit_event_`type' = 0
}

* Define events by subject
forvalues math=0/1 {

	***TEACHER ENTRY
	quietly sum enter_va if math==`math',d
	scalar p95 = r(p95)
	scalar p5 = r(p5)

	replace high_entry_event = 1 if enter_va>p95 & math==`math' & enter_n>0 & enter_va<.
	
	replace low_entry_event = 1 if enter_va<p5 & math==`math' & enter_n>0

	foreach type in d s g {
		replace high_entry_event_`type' = 1 if enter_va_`type'>p95 & math==`math' & enter_n_`type'>0 & enter_va_`type'<.
		
		replace low_entry_event_`type' = 1 if enter_va_`type'<p5 & math==`math' & enter_n_`type'>0
	}


	***TEACHER EXIT     
	quietly sum leave_va if math==`math',d
	scalar p95 = r(p95)
	scalar p5 = r(p5)

	replace high_exit_event = 1 if leave_va>p95 & math==`math' & leave_n>0 & leave_va<.

	replace low_exit_event = 1 if leave_va<p5 & math==`math' & leave_n>0

	foreach type in d s g {
		replace high_exit_event_`type' = 1 if leave_va_`type'>p95 & math==`math' & leave_n_`type'>0 & leave_va_`type'<.

		replace low_exit_event_`type' = 1 if leave_va_`type'<p5 & math==`math' & leave_n_`type'>0
	}
}

save `cfrdat'/eventstudy_analysis, replace


****EVENT STUDY GRAPHS****
*These are subject-specific top 5% entrants (ok to include cheaters here b/c they affect contemporaneous scores as expected)
*Balanced panel, run on full school district data

use `cfrdat'/eventstudy_analysis, clear

egen sch_cohort = group(sch cohort)


*** Calculate mean change in TV for each event

	*1: High Entry
	eventstudy mean_tv_ss if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_entry_event) testvalone(0)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar high_entry_tv_change =e(coef_aft_dot)
	scalar high_entry_tv_se =e(se_aft_dot)

	*2: High Exit
	eventstudy mean_tv_ss if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_exit_event) testvalone(0)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar high_exit_tv_change = e(coef_aft_dot)
	scalar high_exit_tv_se = e(se_aft_dot)

	*3: Low Entry
	eventstudy mean_tv_ss if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_entry_event) testvalone(0)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar low_entry_tv_change = e(coef_aft_dot)
	scalar low_entry_tv_se = e(se_aft_dot)

	*4: Low Exit
	eventstudy mean_tv_ss if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_exit_event) testvalone(0)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar low_exit_tv_change =  e(coef_aft_dot)
	scalar low_exit_tv_se =  e(se_aft_dot)

 
*** Hypothesis tests

*First test hypothesis that observed change equals change forecasted from change in TV (can't reject equality)

	*1: High Entry
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(high_entry_event) testvalone(high_entry_tv_change) absorb(year) cluster(sch_cohort)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar high_entry_score_change =e(coef_aft_dot)
	scalar high_entry_score_se =e(se_aft_dot)
	scalar high_entry_score_forecast_p =e(testvalone_p)

	*2: High Exit
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(high_exit_event) testvalone(high_exit_tv_change) absorb(year) cluster(sch_cohort)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar high_exit_score_change = e(coef_aft_dot)
	scalar high_exit_score_se =e(se_aft_dot)
	scalar high_exit_score_forecast_p =e(testvalone_p)
	
	*3: Low Entry
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(low_entry_event) testvalone(low_entry_tv_change) absorb(year) cluster(sch_cohort)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar low_entry_score_change = e(coef_aft_dot)
	scalar low_entry_score_se =e(se_aft_dot)
	scalar low_entry_score_forecast_p =e(testvalone_p)
	
	*4: Low Exit
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(low_exit_event) testvalone(low_exit_tv_change) absorb(year) cluster(sch_cohort)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar low_exit_score_change =  e(coef_aft_dot)
	scalar low_exit_score_se =e(se_aft_dot)
	scalar low_exit_score_forecast_p =e(testvalone_p)
	
*Now test hypothesis that change is zero (all are highly significant)

	*1: High Entry
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(high_entry_event) testvalone(0) absorb(year) cluster(sch_cohort)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar high_entry_score_0_p =e(testvalone_p)

	*2: High Exit
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(high_exit_event) testvalone(0) absorb(year) cluster(sch_cohort)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar high_exit_score_0_p =e(testvalone_p)

	*3: Low Entry
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(low_entry_event) testvalone(0) absorb(year) cluster(sch_cohort)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar low_entry_score_0_p =e(testvalone_p)

	*4: Low Exit
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(low_exit_event) testvalone(0) absorb(year) cluster(sch_cohort)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar low_exit_score_0_p =e(testvalone_p)


*** Plot graphs: event study of current scores

	*1: High Entry
	eventstudy mean_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_entry_event)  preyrs(3) postyrs(2) balanced pickevent(stack) ///
		xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph ///
		savedata(`cfrdat'/eventstudy/fig3a_high_entry_score)
	scalar high_entry_N_events = e(N_events)
	* Output change in score between -1 and 0 for paper:
	file open dscore using `tabdir'/paper1/paperonly_fig3a_Dscore.csv, write text replace
	file write dscore "High VA Entry,Change in 'Score' from -1 to 0," (e(coef_aft_dot)) _n
	file close dscore

	*2: High Exit
	eventstudy mean_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_exit_event)  preyrs(2) postyrs(3) balanced pickevent(stack) ///
		xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph ///
		savedata(`cfrdat'/eventstudy/fig3b_high_exit_score)
	scalar high_exit_N_events = e(N_events)
	
	*3: Low Entry
	eventstudy mean_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_entry_event)  preyrs(3) postyrs(2) balanced pickevent(stack) ///
		xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph ///
		savedata(`cfrdat'/eventstudy/fig3c_low_entry_score)
	scalar low_entry_N_events = e(N_events)
	
	*4: Low Exit
	eventstudy mean_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_exit_event)  preyrs(2) postyrs(3) balanced pickevent(stack) ///
		xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph ///
		savedata(`cfrdat'/eventstudy/fig3d_low_exit_score)
	scalar low_exit_N_events = e(N_events)
	

*** Plot graphs: mean lag scores

	*1: High Entry
	eventstudy mean_l_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_entry_event) testvalone(0)  preyrs(3) postyrs(2) balanced pickevent(stack) ///
		xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph ///
		savedata(`cfrdat'/eventstudy/fig3a_high_entry_l_score)
	* Output change in lag score between -1 and 0 for paper:
	file open dscore using `tabdir'/paper1/paperonly_fig3a_Dscore.csv, write text append
	file write dscore "High VA Entry,Change in 'Score in Previous Grade' from -1 to 0," (e(coef_aft_dot)) _n
	file close dscore


	*2: High Exit
	eventstudy mean_l_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_exit_event)  testvalone(0)  preyrs(2) postyrs(3) balanced pickevent(stack) ///
		xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph ///
		savedata(`cfrdat'/eventstudy/fig3b_high_exit_l_score)

	*3: Low Entry
	eventstudy mean_l_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_entry_event) testvalone(0)  preyrs(3) postyrs(2) balanced pickevent(stack) ///
		xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph ///
		savedata(`cfrdat'/eventstudy/fig3c_low_entry_l_score)

	*4: Low Exit
	eventstudy mean_l_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_exit_event) testvalone(0)  preyrs(2) postyrs(3) balanced pickevent(stack) ///
		xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph ///
		savedata(`cfrdat'/eventstudy/fig3d_low_exit_l_score)
	
*** Check for changes in class size around entry/exit
	file open dclasssize using `tabdir'/paper1/paperonly_fig3_Dclasssiz.csv, write text replace
	file write dclasssize ",coef -1 to 0, se -1 to 0, p -1 to 0" _n

	*1: High Entry
	eventstudy mean_CLass_size if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_entry_event) testvalone(0) preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	file write dclasssize "High VA Entry," (e(coef_aft_dot)) "," (e(se_aft_dot)) "," (e(testvalone_p)) _n
	
	*2: High Exit
	eventstudy mean_CLass_size if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_exit_event) testvalone(0) preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	file write dclasssize "High VA Exit," (e(coef_aft_dot)) "," (e(se_aft_dot)) "," (e(testvalone_p)) _n
	
	*3: Low Entry
	eventstudy mean_CLass_size if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_entry_event) testvalone(0) preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	file write dclasssize "Low VA Entry," (e(coef_aft_dot)) "," (e(se_aft_dot)) "," (e(testvalone_p)) _n
	
	*4: Low Exit
	eventstudy mean_CLass_size if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_exit_event) testvalone(0) preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	file write dclasssize "Low VA Exit," (e(coef_aft_dot)) "," (e(se_aft_dot)) "," (e(testvalone_p)) _n

	file close dclasssize

***** Combine and save graphs

*** Figure 3a: High Value-Added Teacher Entry

* Load data
use `cfrdat'/eventstudy/fig3a_high_entry_score, clear
merge 1:1 event_time using `cfrdat'/eventstudy/fig3a_high_entry_l_score
gen d_score=mean_score_coeffs-mean_l_score_coeffs

* Perform shift
scalar shift_score=mean_score_coeffs[1]
scalar shift_lscore=mean_l_score_coeffs[1]

replace mean_score_coeffs=mean_score_coeffs-shift_score
replace mean_l_score_coeffs=mean_l_score_coeffs-shift_lscore

* Store numbers to be displayed as locals
local score_change=string(high_entry_score_change,"%9.3f")
local score_se=string(high_entry_score_se,"%9.3f")

local tv_change=string(high_entry_tv_change,"%9.3f")
local tv_se=string(high_entry_tv_se,"%9.3f")

if (high_entry_score_forecast_p<0.001) local score_forecast_p="< 0.001"
else local score_forecast_p="= "+string(high_entry_score_forecast_p,"%9.2f")

if (high_entry_score_0_p<0.001) local score_0_p="< 0.001"
else local score_0_p="= "+string(high_entry_score_0_p,"%9.2f")

local N_events=string(high_entry_N_events,"%9.0f")

* Graph mean/lag figure for paper
twoway  (scatter mean_score_coeffs event_time, c(l)) ///
	(scatter mean_l_score_coeffs event_time, c(l) lcolor(black) mcolor(black)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("High Value-Added Teacher Entry") ///
	xtitle("Year Relative to Entry of High Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	legend(order(1 "Score" 2 "Score in Previous Grade")) ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(10) ring(0) size(small))
multi_graph_export using `figdir'/paper1/fig3a_high_entry

* Graph diff figure for slides
twoway  (scatter d_score event_time, c(l)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("High Value-Added Teacher Entry") ///
	xtitle("Year Relative to Entry of High Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(10) ring(0) size(small))
multi_graph_export using `figdir'/paper1/slidesonly_fig3a_high_entry_D_SCORE


*** Figure 3b: High Value-Added Teacher Exit

* Load data
use `cfrdat'/eventstudy/fig3b_high_exit_score, clear
merge 1:1 event_time using `cfrdat'/eventstudy/fig3b_high_exit_l_score
gen d_score=mean_score_coeffs-mean_l_score_coeffs
replace event_time=event_time-1

* Perform shift
scalar shift_score=mean_score_coeffs[_N]
scalar shift_lscore=mean_l_score_coeffs[_N]

replace mean_score_coeffs=mean_score_coeffs-shift_score
replace mean_l_score_coeffs=mean_l_score_coeffs-shift_lscore

* Store numbers to be displayed as locals
local score_change=string(high_exit_score_change,"%9.3f")
local score_se=string(high_exit_score_se,"%9.3f")

local tv_change=string(high_exit_tv_change,"%9.3f")
local tv_se=string(high_exit_tv_se,"%9.3f")

if (high_exit_score_forecast_p<0.001) local score_forecast_p="< 0.001"
else local score_forecast_p="= "+string(high_exit_score_forecast_p,"%9.2f")

if (high_exit_score_0_p<0.001) local score_0_p="< 0.001"
else local score_0_p="= "+string(high_exit_score_0_p,"%9.2f")

local N_events=string(high_exit_N_events,"%9.0f")

* Graph mean/lag figure for paper
twoway  (scatter mean_score_coeffs event_time, c(l)) ///
	(scatter mean_l_score_coeffs event_time, c(l) lcolor(black) mcolor(black)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("High Value-Added Teacher Exit") ///
	xtitle("Year Relative to Departure of High Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	legend(order(1 "Score" 2 "Score in Previous Grade")) ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(2) ring(0) size(small))
multi_graph_export using `figdir'/paper1/fig3b_high_exit

* Graph diff figure for slides
twoway  (scatter d_score event_time, c(l)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("High Value-Added Teacher Exit") ///
	xtitle("Year Relative to Departure of High Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(2) ring(0) size(small))
multi_graph_export using `figdir'/paper1/slidesonly_fig3b_high_exit_D_SCORE


*** Figure 3c: Low Value-Added Teacher Entry

* Load data
use `cfrdat'/eventstudy/fig3c_low_entry_score, clear
merge 1:1 event_time using `cfrdat'/eventstudy/fig3c_low_entry_l_score
gen d_score=mean_score_coeffs-mean_l_score_coeffs

* Perform shift
scalar shift_score=mean_score_coeffs[1]
scalar shift_lscore=mean_l_score_coeffs[1]

replace mean_score_coeffs=mean_score_coeffs-shift_score
replace mean_l_score_coeffs=mean_l_score_coeffs-shift_lscore

* Store numbers to be displayed as locals
local score_change=string(low_entry_score_change,"%9.3f")
local score_se=string(low_entry_score_se,"%9.3f")

local tv_change=string(low_entry_tv_change,"%9.3f")
local tv_se=string(low_entry_tv_se,"%9.3f")

if (low_entry_score_forecast_p<0.001) local score_forecast_p="< 0.001"
else local score_forecast_p="= "+string(low_entry_score_forecast_p,"%9.2f")

if (low_entry_score_0_p<0.001) local score_0_p="< 0.001"
else local score_0_p="= "+string(low_entry_score_0_p,"%9.2f")

local N_events=string(low_entry_N_events,"%9.0f")

* Graph mean/lag figure for paper
twoway  (scatter mean_score_coeffs event_time, c(l)) ///
	(scatter mean_l_score_coeffs event_time, c(l) lcolor(black) mcolor(black)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("Low Value-Added Teacher Entry") ///
	xtitle("Year Relative to Entry of Low Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	legend(order(1 "Score" 2 "Score in Previous Grade")) ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(7) ring(0) size(small))
multi_graph_export using `figdir'/paper1/fig3c_low_entry

* Graph diff figure for slides
twoway  (scatter d_score event_time, c(l)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("Low Value-Added Teacher Entry") ///
	xtitle("Year Relative to Entry of Low Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(7) ring(0) size(small))
multi_graph_export using `figdir'/paper1/slidesonly_fig3c_low_entry_D_SCORE

*** Figure 3d: Low Value-Added Teacher Exit

* Load data
use `cfrdat'/eventstudy/fig3d_low_exit_score, clear
merge 1:1 event_time using `cfrdat'/eventstudy/fig3d_low_exit_l_score
gen d_score=mean_score_coeffs-mean_l_score_coeffs
replace event_time=event_time-1

* Perform shift
scalar shift_score=mean_score_coeffs[_N]
scalar shift_lscore=mean_l_score_coeffs[_N]

replace mean_score_coeffs=mean_score_coeffs-shift_score
replace mean_l_score_coeffs=mean_l_score_coeffs-shift_lscore

* Store numbers to be displayed as locals
local score_change=string(low_exit_score_change,"%9.3f")
local score_se=string(low_exit_score_se,"%9.3f")

local tv_change=string(low_exit_tv_change,"%9.3f")
local tv_se=string(low_exit_tv_se,"%9.3f")

if (low_exit_score_forecast_p<0.001) local score_forecast_p="< 0.001"
else local score_forecast_p="= "+string(low_exit_score_forecast_p,"%9.2f")

if (low_exit_score_0_p<0.001) local score_0_p="< 0.001"
else local score_0_p="= "+string(low_exit_score_0_p,"%9.2f")

local N_events=string(low_exit_N_events,"%9.0f")

* Graph mean/lag figure for paper
twoway  (scatter mean_score_coeffs event_time, c(l)) ///
	(scatter mean_l_score_coeffs event_time, c(l) lcolor(black) mcolor(black)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	ylab(-.03(.01).02) ///
	title("Low Value-Added Teacher Exit") ///
	xtitle("Year Relative to Departure of Low Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	legend(order(1 "Score" 2 "Score in Previous Grade")) ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(5) ring(0) size(small))
multi_graph_export using `figdir'/paper1/fig3d_low_exit

* Graph diff figure for slides
twoway  (scatter d_score event_time, c(l)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("Low Value-Added Teacher Exit") ///
	xtitle("Year Relative to Departure of Low Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(5) ring(0) size(small))
multi_graph_export using `figdir'/paper1/slidesonly_fig3d_low_exit_D_SCORE



********************
***** Figure 4 *****
********************

* See code in Table 4 above.

********************
***** Figure 5 *****
********************

* See code in Table 4 above.

*****************************
***** Appendix Figure 1 *****
*****************************

use `cfrdat'/analysis.dta, clear

* Demean tv by middle-math
foreach var of varlist tv {
*	forvalues middle=0/1 {
  local middle=0
		forvalues math=0/1 {
			sum `var' [w=CLass_size] if middle==`middle' & math==`math', meanonly
			replace `var'=`var'-r(mean) if middle==`middle' & math==`math'
		}
}

*** AFig 1a: Kernel density of teacher VA by subject for elementary

*List the following 2 SD's on the figure 
qui sum tv [w=CLass_size] if middle==0 & math==0
local sd_read=string(r(sd),"%9.3f")

qui sum tv [w=CLass_size] if middle==0 & math==1
local sd_math=string(r(sd),"%9.3f")

twoway  (kdensity tv [w=CLass_size] if abs(tv)<.3 & middle==0 & math==0, bwidth(.01)) ///
	(kdensity tv [w=CLass_size] if abs(tv)<.3 & middle==0 & math==1, bwidth(.01)), ///
	graphregion(fcolor(white)) ///
	xlab(-.3(.1).3) ///
	title("Empirical Distribution of Teacher VA Estimates in Elementary School", size(medium)) ///
	xtitle("Teacher Value-Added") ///
	ytitle("Density") ///
	note("SD of English = `sd_read'" "SD of Math = `sd_math'", position(2) ring(0) size(medsmall)) ///
	legend(order(1 "English" 2 "Math"))
multi_graph_export using `figdir'/paper1/afig1a

*** AFig 1b: Kernel density of teacher VA by subject for middle
*
**List the following 2 SD's on the figure 
*qui sum tv [w=CLass_size] if middle==1 & math==0
*local sd_read=string(r(sd),"%9.3f")
*
*qui sum tv [w=CLass_size] if middle==1 & math==1
*local sd_math=string(r(sd),"%9.3f")
*
*twoway  (kdensity tv [w=CLass_size] if abs(tv)<.3 & middle==1 & math==0, bwidth(.01)) ///
*	(kdensity tv [w=CLass_size] if abs(tv)<.3 & middle==1 & math==1, bwidth(.01)), ///
*	graphregion(fcolor(white)) ///
*	xlab(-.3(.1).3) ///
*	title("Empirical Distribution of Teacher VA Estimates in Middle School", size(medium)) ///
*	xtitle("Teacher Value-Added") ///
*	ytitle("Density") ///
*	note("SD of English = `sd_read'" "SD of Math = `sd_math'", position(2) ring(0) size(medsmall)) ///
*	legend(order(1 "English" 2 "Math"))
*multi_graph_export using ${figdir}/paper1/afig1b


*************************************
***** Figures not used in paper *****
*************************************

*** Kernel density of teacher quality within vs across schools

use `cfrdat'/analysis.dta, clear

* Demean tv by middle-math
forvalues middle=0/1 {
	forvalues math=0/1 {
		sum tv [w=CLass_size] if middle==`middle' & math==`math', meanonly
		replace tv=tv-r(mean) if middle==`middle' & math==`math'
	}
}

* Compute means
bys sch: egen sch_mean_tv = wtmean(tv), weight(CLass_size)
gen tv_diff_sch_mean = tv - sch_mean_tv

bys sch: egen sch_size = sum(CLass_size)
bys sch: gen one_obs_per_sch=(_n==1)


* Check computed SDs below against xtsum output.
*    The ones computed below should match except that xtsum doesn't support weights
xtset sch
xtsum tv

* Overall variance
qui sum tv [w=CLass_size]
local sd_overall=string(r(sd),"%9.3f")
di "SD overall: `sd_overall'"

* Within variance
qui sum tv_diff_sch_mean [w=CLass_size]
local sd_within=string(r(sd),"%9.3f")
di "SD within: `sd_within'"

* Between variance
sum sch_mean_tv if one_obs_per_sch==1 [w=sch_size]
local sd_between=string(r(sd),"%9.3f")
di "SD between: `sd_between'"

twoway  (kdensity sch_mean_tv if one_obs_per_sch & abs(sch_mean_tv)<.2 [w=sch_size], bwidth(.01)) ///
	(kdensity tv_diff_sch_mean [w=CLass_size] if abs(tv_diff_sch_mean)<.2, bwidth(.01)), ///
	graphregion(fcolor(white)) ///
	title("Variation in Value-Added Within vs Across Schools", size(medium)) ///
	xtitle("Teacher Value-Added") ///
	ytitle("Density") ///
	note("SD between schools = `sd_between'" "SD within schools = `sd_within'" "Total SD = `sd_overall'", position(2) ring(0) size(medsmall)) ///
	legend(order(1 "Mean School-Level VA" 2 "VA Within Schools")) ///
	saving(`figdir'/paper1/notused_withinbetweenschools.gph, replace)

*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~*~*~*~*
*~*~*~*~*~* END OF PAPER 1 *~*~*~*~*~*~*
*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~*~*~*~*
 
 if `doasproject'==1 {
	project, creates(`figdir'/paper1/fig1a_autocovar_elem.gph)
	project, creates(`tabdir'/paper1/paperonly_turnover_switchtype.csv)
	project, creates(`cfrdat'/teach_va_weights.dta)
	project, creates(`cfrdat'/sch_gr_yr_work1.dta)
	project, creates(`logdir'/percent_replacement_for_referee.smcl)
	project, creates(`cfrdat'/eventstudy_analysis.dta)
	project, creates(`cfrdat'/eventstudy/fig3a_high_entry_score.dta)
	project, creates(`tabdir'/paper1/paperonly_fig3a_Dscore.csv)
	project, creates(`cfrdat'/eventstudy/fig3b_high_exit_score.dta)
	project, creates(`cfrdat'/eventstudy/fig3c_low_entry_score.dta)
	project, creates(`cfrdat'/eventstudy/fig3d_low_exit_score.dta)
	project, creates(`cfrdat'/eventstudy/fig3a_high_entry_l_score.dta)
	project, creates(`cfrdat'/eventstudy/fig3b_high_exit_l_score.dta)
	project, creates(`cfrdat'/eventstudy/fig3c_low_entry_l_score.dta)
	project, creates(`cfrdat'/eventstudy/fig3d_low_exit_l_score.dta)
	project, creates(`tabdir'/paper1/paperonly_fig3_Dclasssiz.csv)
	project, creates(`figdir'/paper1/fig3a_high_entry.gph)
	project, creates(`figdir'/paper1/slidesonly_fig3a_high_entry_D_SCORE.gph)
	project, creates(`figdir'/paper1/fig3b_high_exit.gph)
	project, creates(`figdir'/paper1/slidesonly_fig3b_high_exit_D_SCORE.gph)
	project, creates(`figdir'/paper1/fig3c_low_entry.gph)
	project, creates(`figdir'/paper1/slidesonly_fig3c_low_entry_D_SCORE.gph)
	project, creates(`figdir'/paper1/fig3d_low_exit.gph)
	project, creates(`figdir'/paper1/slidesonly_fig3d_low_exit_D_SCORE.gph)
  project, creates(`figdir'/paper1/afig1a.gph)
	project, creates(`figdir'/paper1/notused_withinbetweenschools.gph)
}
