*Runs after validteachers.do, and prepares sample for CFR-style analysis;
*Based closely on CFR's "create_schd_work_final.do";

version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
	drop _all
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "prepcfrsamp"
	local sig "Not run as part of project!"
	
}

#delimit;
set more off;
local scratchdir "`pdir'/scratch";
local rawdat "`scratchdir'/ncdata";
local cfrdat "`scratchdir'/cfrdata";
local extras "`scratchdir'/extras";

*Start by stacking the data and assigning lagged scores;
 if `doasproject'==1 project, uses(`rawdat'/prepdata_mbuild.dta);
 use `rawdat'/prepdata_mbuild;
 rename readstd g2_read;
 rename mathstd g2_math;
 keep mastid year g2_*;
 tempfile mb;
 save `mb';
 
 if `doasproject'==1 project, uses(`rawdat'/validteachers.dta);
 use `rawdat'/validteachers;
 merge 1:1 mastid year using `mb', assert(1 3);
 gen l1_math=g2_math if test_grade==3;
 gen l1_read=g2_read if test_grade==3;
 drop g2* _merge;
 sort mastid year;
 xtset mastid year;
 by mastid: replace l1_math=L.mathstd if L.year==year-1;
 by mastid: replace l1_read=L.readstd if L.year==year-1;
 by mastid: gen l2_math=LL.mathstd;
 by mastid: gen l2_read=LL.readstd;
 by mastid: replace l2_math=L.l1_math if LL.mathstd==. & L.l1_math<.;
 by mastid: replace l2_read=L.l1_read if LL.readstd==. & L.l1_read<.;
 by mastid: gen l3_math=LLL.mathstd;
 by mastid: gen l3_read=LLL.readstd;
 by mastid: replace l3_math=LL.l1_math if l3_math==. & LL.l1_math<.;
 by mastid: replace l3_read=LL.l1_read if l3_read==. & LL.l1_read<.;
 by mastid: replace l3_math=L.l2_math if l3_math==. & L.l2_math<.;
 by mastid: replace l3_read=L.l2_read if l3_read==. & L.l2_read<.;
 by mastid: gen f1_math=F.mathstd;
 by mastid: gen f1_read=F.readstd;
 by mastid: gen f2_math=FF.mathstd;
 by mastid: gen f2_read=FF.readstd;
 by mastid: replace f2_math=F.f1_math if f2_math==.;
 by mastid: replace f2_read=F.f1_read if f2_read==.;
 by mastid: gen f3_math=FFF.mathstd;
 by mastid: gen f3_read=FFF.readstd;
 by mastid: replace f3_math=FF.f1_math if f3_math==.;
 by mastid: replace f3_read=FF.f1_read if f3_read==.;
 by mastid: replace f3_math=F.f2_math if f3_math==.;
 by mastid: replace f3_read=F.f2_read if f3_read==.;
 
  rename l1_math l_math;
  rename l1_read l_read;	
 
*Make a school number;
 egen sch=group(lea schlcode);

*keep if sch<=100;

*Indicator for grade repeaters;
*CFR: REPEAT GRADE DUMMY -- USE REGULAR GRADE VARIABLE AND TEST GRADE -- NOTE THAT IN 1991 WE HAVE TO RELY ON TEST GRADE SINCE WE HAVE NO 1990 REGULAR GRADE, AND WE HAVE TO BASE OFF OF 1 OB PER STUDENT-SUBJECT-YEAR;
  sort mastid year;
  by mastid: gen byte repeat_grade=(grade==grade[_n-1]);
  by mastid: gen byte repeat_test=(test_grade==test_grade[_n-1]) & test_grade<.;

*CFR: GENERATE VARIABLE FOR STAYING BACK NEXT YEAR;
  by mastid: gen byte future_repeat=(test_grade==test_grade[_n-1]) if test_grade<.;

*Now we can limit our sample to the appropriate years;
 *We generally have ~90% coverage for lagged scores in 1998-2007, and for G4-5 in 2008-;
 * 80% in 1997 and for 4th graders in 1996.;
  gen byte havel=(l_math<. | l_read<.);
  gen byte haves_m=(mathscal<.);
  gen byte haves_r=(readscal<.);
  gen byte havel_m=haves_m*(l_math<.);
  gen byte havel_r=haves_r*(l_read<.);
  table year grade if inlist(grade, 3, 4, 5), contents(count mastid mean haves_m mean havel_m );
  table year grade if inlist(grade, 3, 4, 5), contents(count mastid mean haves_r mean havel_r );
 *Results:
  *No lagged scores in 1995. 
  *Lagged scores only for 4th graders in 1996.
  *No lagged scores for 3rd graders in 2006 (math) or 2008 (reading).
  *Lagged scores for only 62% of 3rd graders in 2009 (both subjects).
  *No lagged scores for 3rd graders in 2010, 2011.
 *Decision: Drop 1996. 
 *          Use 3rd graders through 2008 (but below we will drop 2006 math and 2008 reading). 
 *          Other grades, go through 2011.;
  drop if grade<3 | grade>5;
  drop if year<1997;
  drop if year>2008 & grade==3;
  drop if year>2011 & grade>3;
  drop haves_m haves_r havel_m havel_r;
  
 *Old code:
 * drop if grade<3 | grade>5;
 * drop if year<1997;
 * drop if year>2007 & grade==3;

 *Some cleaning of lagged scores  -- in some years, we don't have these data for many;
  rename l_math l1_math;
  rename l_read l1_read;
  gen byte have_l1=(l1_math<. | l1_read<.);
  gen byte have_l2=(l2_math<. | l2_read<.);
  gen byte have_l3=(l3_math<. | l3_read<.);
  gen byte have_f1=(f1_math<. | f1_read<.);
  gen byte have_f2=(f2_math<. | f2_read<.);
  gen byte have_f3=(f3_math<. | f3_read<.);
  sort test_grade year mastid;
  *collapse (mean) have_?? (count) nobs=have_l1, by(test_grade year);
  *It turns out that we either have 70%+ of lead/lag scores, or nearly zero. Set a floor of 70%.;
  foreach v of varlist have_?? {;
  	bys grade year: egen fr`v'=mean(`v');
  	tab fr`v';
  };
  forvalues i=1/3 {;
  	replace l`i'_math=. if frhave_l`i'<0.7;
  	replace l`i'_read=. if frhave_l`i'<0.7;
  	replace f`i'_math=. if frhave_f`i'<0.7;
  	replace f`i'_read=. if frhave_f`i'<0.7;
  };
  drop have_?? frhave_??;
  rename l1_math l_math;
  rename l1_read l_read;	

*Create a teacher ID;
 egen long classroom=group(sch year grade teachid), missing;
 gen long teacherA=teachid if grade_valid==1 & size_valid==1 & SAR_valid==1;
 assert classroom<100000000;
 replace teacherA=900000000+classroom if teacherA==.;
 gen long teacherB=teachid if grade_valid==1 & size_valid==1;
 replace teacherB=900000000+classroom if teacherB==.;
 label var teacherA "Teacher ID (bad SAR -> singleton)";
 label var teacherB "Teacher ID (few -> singleton)";
 *FOR NOW, WE'LL USE A TEACHERA DEFINITION;
  rename teacherA teacher;
  drop teacherB;
 *There are a very small number of teachers who show up in multiple schools in the same year
 *Recode these to classroom codes also; 
  sort teacher year sch grade mastid;
  by teacher year: gen multsch=(sch[1]~=sch[_N]);
  by teacher year sch grade: gen firstobs=(_n==1);
  list teacher classroom year sch grade if multsch==1 & firstobs==1;
  replace teacher=900000000+classroom if multsch==1;
  drop multsch firstobs;
  
 drop SAR_valid grade_valid size_valid SAR_grade noSAR;
 
*Make one observation per student-year-subject;
 sort mastid year;
 expand 2;
 sort mastid year;
 by mastid year: gen math=(_n==2);
 gen score=mathstd if math==1;
 replace score=readstd if math==0;
 gen other=mathstd if math==0;
 replace other=readstd if math==1;
 gen scorescal=mathscal if math==1;
 replace scorescal=readscal if math==0;
 gen otherscal=mathscal if math==0;
 replace otherscal=readscal if math==1;
 foreach fl in l l2 l3 f1 f2 f3 {;
 	 gen `fl'_score=`fl'_math if math==1;
 	 replace `fl'_score=`fl'_read if math==0;
 	 gen `fl'_other=`fl'_read if math==1;
 	 replace `fl'_other=`fl'_math if math==0;
 };
 drop mathstd readstd mathscal readscal l_math l_read ??_math ??_read;
 drop scorescal otherscal;

*Above, we realized we dont have 2nd grade scores for 2006 math or 2008 reading.
*Now that we have separate obs for each subject, drop these.;
 drop if year==2006 & math==1 & grade==3;
 drop if year==2008 & math==0 & grade==3;
 
*Rename some variables to conform to CFR;
        rename mastid stuid;
        rename special sped;
        *rename classroom class_id;
        egen class_id=group(teacher);
        rename lunch student_mealcode;
 

* DUMMY FOR HAVING MISSING PRIOR SCORE;
        gen MPREO=l_other==.;
        replace l_other=0 if MPREO==1;

* CUBIC IN PRIOR SCORES;
        foreach vary in score other {;
                g l_`vary'2 = l_`vary'^2;
                g l_`vary'3 = l_`vary'^3;
        };

* INTERACT CUBIC IN PRIOR OWN-SUBJECT SCORE WITH INDICATOR FOR MISSING PRIOR OTHER SCORE;
        foreach vary of varlist l_score* {;
                gen MPREO`vary'=MPREO*`vary';
                };
                renpfix MPREOl MPREOPREZl;

* CREATE INTERACTIONS OF PRIOR TEST SCORES WITH GRADE LEVEL;
        char test_grade[omit] 4;
        xi i.test_grade|l_score i.test_grade|l_score2 i.test_grade|l_score3, prefix(PREZ);
        xi i.test_grade|l_other i.test_grade|l_other2 i.test_grade|l_other3, prefix(PREO);
        drop PREZtest* PREOtest*;

* FREE LUNCH INDICATOR;
        g byte lunch = (student_mealcode ==1 | student_mealcode ==2 | student_mealcode ==5);
        drop student_mealcode;
* JR ADDITION: 
* AGE VARIABLES;
        replace bdate=. if bdate>mdy(1,1,year);
        g age_current =  (mdy(6,30,year)-bdate)/365;
        g age09 =  (mdy(12,31,2009)-bdate)/365;
        replace age_current=. if age_current<4+grade;
        replace age09=. if age_current==.;
        drop bdate;
        label var age_current "Age on 6/30 of test year, in yrs";
        label var age09 "Age on 12/31/09, in yrs"; 

* ETHNICITY DUMMIES;
        char ethnicity[omit] 5;
        xi, prefix(ETHN) i.ethnicity;
        label var ETHNethnici_0 "Ethnicity: Missing/other";
        label var ETHNethnici_1 "Ethnicity: Black";
        label var ETHNethnici_2 "Ethnicity: Hispanic";
        label var ETHNethnici_3 "Ethnicity: Asian";
        label var ETHNethnici_4 "Ethnicity: Indian";

* CLASS AND COHORT (RPOOL) GROUPINGS;
        egen class = group(math sch year class_id);
        egen rpool = group(math sch year grade);

compress;

* DEFINE ONE GRADE PER CLASS WHEN WE HAVE CLASS LINKS, ELSE USE REPORTED TEST_GRADE;
* WE'RE GOING TO INTERACT WITH THIS INSTEAD OF STUDENTS' INDIVIDUAL TEST GRADE IN ORDER TO HAVE THE SAME VALUE ACROSS STUDENTS WITHIN A CLASSROOM.;
        bys class: egen modal_grade = mode(grade) if class~=., max;

* LIST OF CONTROLS--WE'LL NEXT GENERATE CLASS AND SCHOOL-YEAR OR SCHOOL-GRADE LEVEL MEANS;
        *global listcontrols ETHN* sped female age_current miss_lunch lunch limited_english repeat_grade repeat_test absences suspensions post99_sped post99_limited_eng MPREO;
        global listcontrols ETHN* sped female age_current miss_lunch lunch limited_english repeat_grade repeat_test MPREO;

* MISSINGS FOR KEY VARIABLES -- IDENTIFY;
        foreach v of varlist $listcontrols {;
        	qui count if `v'==.;
        	if r(N)>0 {;
        		gen byte MISS_`v'=(`v'==.);
            global listcontrols $listcontrols MISS_`v';
        	};
        };

* CLASS LEVEL AVERAGE OF STUDENT-LEVEL CONTROLS;
        foreach vary of varlist l_score l_other $listcontrols MPREOPREZ* {;
                if "`vary'"~="l_other" {;
                   *bys class: egen CL`vary'=wtmean(`vary'), weight(class_days_enrolled/(end-start));
                   bys class: egen CL`vary'=mean(`vary');
                   *JR addition: If the variable is missing for the whole class, set to global mean;
                    count if CL`vary'==.;
                    if r(N)>0 {;
                    	di "Assigning global mean of `vary' for classes where it is missing.";
                    	*local vtype : type `vary';
                    	su `vary', meanonly;
                    	*if "`vtype'"=="byte" {;
                    	*	replace CL`vary'=0 if CL`vary'==.;
                    	*  di "Assigning 0 to CL`vary' for " r(N) " classes.";
                    	*};
                    	*else {;
                    		replace CL`vary'=r(mean) if CL`vary'==.;
                    	*};
                    };
                    	
                };
                if "`vary'"=="l_other"{;
                   *bys class: egen CL`vary'=wtmean(cond(MPREO==1,.,`vary')), weight(class_days_enrolled/(end-start));
                   tempvar tmp_other;
                   gen `tmp_other'=l_other if MPREO==0;
                   bys class: egen CL`vary'=mean(`tmp_other');
                };
        };
        compress CLMISS_*;

* SCHOOL-YEAR-SUBJECT LEVEL AVERAGE OF STUDENT-LEVEL CHARACTERISTICS **OTHER THAN PRIOR SCORES**;
        foreach vary of varlist $listcontrols {;
           *bys sch year math: egen SY`vary'=wtmean(`vary'), weight(school_days_enrolled/(end-start));
           bys sch year math: egen SY`vary'=mean(`vary');
                   *JR addition: If the variable is missing for the whole sch-yr-math cell,
                   * set to global mean;
                    count if SY`vary'==.;
                    if r(N)>0 {;
                    	di "Assigning global mean of `vary' for school-year-math cells where it is missing.";
                    	*local vtype : type `vary';
                    	su `vary', meanonly;
                    	*if "`vtype'"=="byte" {;
                    	*	replace SY`vary'=0 if SY`vary'==.;
                    	*  di "Assigning 0 to SY`vary' for " r(N) " classes.";
                    	*};
                    	*else {;
                    		replace SY`vary'=r(mean) if SY`vary'==.;
                    	*};
                    };
           compress SY`vary';
           };
        compress SYMISS_*;

*SCHOOL-YEAR-SUBJECT LEVEL AVERAGE OF PRIOR TEST SCORES, ****WEIGHTING BY STUDENTS' DAYS IN THE SCHOOL****;
   *bys sch modal_grade math: egen SGl_score=wtmean(l_score), weight(school_days_enrolled/(end-start));
   *bys sch modal_grade math: egen SGl_other=wtmean(cond(MPREO==1,.,l_other)), weight(school_days_enrolled/(end-start));
   bys sch modal_grade math: egen SGl_score=mean(l_score);
   bys sch modal_grade math: egen SGl_other=mean(`tmp_other');
   compress SGl_score SGl_other;
  * OPTION TO CALCULATE THIS ONLY FOR STUDENTS WHO DID NOT STAY BACK THE FOLLOWING YEAR--TECHNICALLY THERE IS MECHANICAL CORRELATION WITH CURRENT SCORE;
  * bys sch modal_grade math: egen SGl_score=wtmean(cond(future_repeat==1,.,l_score)), weight(school_days_enrolled/(end-start));
  * bys sch modal_grade math: egen SGl_other=wtmean(cond(future_repeat==1,.,cond(MPREO==1,.,l_other))), weight(school_days_enrolled/(end-start));


* SQUARE AND CUBE FOR PRIOR SCORE CLASS AND SCHOOL-GRADE MEANS;
        foreach vary in l_score l_other {;
        g CL`vary'2 = CL`vary'^2;
        g CL`vary'3 = CL`vary'^3;
        g SG`vary'2 = SG`vary'^2;
        g SG`vary'3 = SG`vary'^3;
        };

* CREATE INTERACTIONS OF CLASS AVG PRIOR TEST SCORES WITH GRADE LEVEL;
        xi i.modal_grade|CLl_score i.modal_grade|CLl_score2 i.modal_grade|CLl_score3, prefix(CLPZ);
        xi i.modal_grade|CLl_other i.modal_grade|CLl_other2 i.modal_grade|CLl_other3, prefix(CLPO);
        drop CLPZmoda* CLPOmoda*;
        capture drop CLPZ*0 CLPO*0;
        capture drop CLPZ*1 CLPO*1;
        capture drop CLPZ*2 CLPO*2;

* CREATE INTERACTIONS OF SCHOOL-GRADE AVG PRIOR TEST SCORES WITH GRADE LEVEL;
        xi i.modal_grade|SGl_score i.modal_grade|SGl_score2 i.modal_grade|SGl_score3, prefix(SGPZ);
        xi i.modal_grade|SGl_other i.modal_grade|SGl_other2 i.modal_grade|SGl_other3, prefix(SGPO);
        drop SGPZmoda* SGPOmoda*;
        capture drop SGPZ*0 SGPO*0;
        capture drop SGPZ*1 SGPO*1;
        capture drop SGPZ*2 SGPO*2;

* RENAME PRIOR SCORES TO HAVE "PRE" PREFIX, CLASS PRIOR SCORES HAVE CLP AND SCHOOL GRADE PRIOR SCORES HAVE SGP;
         for any score other \ any Z O : rename l_X PREYl_X \ rename l_X2 PREYl_X2 \ rename l_X3 PREYl_X3 \ rename CLl_X CLPYl_X \ rename CLl_X2 CLPYl_X2 \ rename CLl_X3 CLPYl_X3;
         rename SGl_score SGPZl_score;
         rename SGl_score2 SGPZl_score2;
         rename SGl_score3 SGPZl_score3;
         rename SGl_other SGPOl_other;
         rename SGl_other2 SGPOl_other2;
         rename SGl_other3 SGPOl_other3;

* MISSINGS FOR KEY VARIABLES -- IMPUTE MEANS;
        foreach v of varlist $listcontrols {;
        	qui count if `v'==.;
        	if r(N)>0 {;
        		local vtype : type `v';
        		su `v', meanonly;
        		if "`vtype'"=="byte" replace `v'=0 if MISS_`v'==1;
        		else replace `v'=r(mean) if MISS_`v'==1;
        		di "Generated a missing value indicator for `v' (type `vtype').";
        	};
        };
        global listcontrols $listcontrols MISS*;

*CFR CODE TO ASSIGN EACH TEACHER TO ONE SCHOOL PER YEAR
* USE CONSIDATED INFO FROM ENROLLMENT AND SERVICE HISTORY FILES TO CHOOSE ONE SCHOOL PER TEACHER PER YEAR;
*        merge m:1 teacher sch year using $datadir/final_teacher_list_in_schd_work_schools.dta
*        drop if _m==2
*        replace teacher=. if _m==1
*        drop _merge
*JR replacement code: Check that we have just one school per teacher per year;
 sort teacher year sch stuid;
 by teacher year: assert sch[1]==sch[_N];
 

compress;
save `cfrdat'/prepcfrsamp, replace;
if `doasproject'==1 project, creates(`cfrdat'/prepcfrsamp.dta);

