*Runs after validteachers.do, and prepares sample for CFR-style analysis;
*Based closely on CFR's "create_schd_work_final.do";
* Part 3/3

version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "prepcfrsamp"
	local sig "Not run as part of project!"
	
}

#delimit;
local scratchdir "`pdir'/scratch";
local rawdat "`scratchdir'/ncdata";
local cfrdat "`scratchdir'/cfrdata";
local extras "`scratchdir'/extras";


 if `doasproject'==1 project, uses(`cfrdat'/schd_work.dta);
 if `doasproject'==1 project, uses(`rawdat'/prepdata_longrun.dta);
 


*One last dataset, not in CFR's program: Predicted scores based on parental education,
*both at individual level and at school-year-class-subject level, along with long-run
*outcomes;
 use sch year grade class_id math pared stuid score using `cfrdat'/schd_work, clear;
 gen havepared=(pared<.);
 tab year havepared;
 assert pared==. if year>=2007;
 *drop if year>=2007;
 *Simple predictions;
  gen predscore_pared=.;
  tempvar pred;
  forvalues m=0/1 {;
   	areg score i.year if math==`m', absorb(pared);
   	predict `pred', d;
   	replace predscore_pared=`pred' if math==`m';
   	drop `pred';
  };
 keep sch year grade class_id math pared stuid predscore_pared;
 tab pared, gen(d_pared);
 gen cohort = year-grade;
 compress;
 tempfile notirs;
 save `notirs';
 *Grab and code the long-run outcomes;
  merge m:1 stuid using `rawdat'/prepdata_longrun;
  tab cohort _merge, m;
 *Lots of the students in the long-run outcomes data are EOC scores 
 *from cohorts that are too early;
  drop if alg1year<2001 & indata_grads==0 & indata_gpa==0 & indata_exit==0 & _merge==2;
 *In general, we don't need merge==2 -- these are people without earlier scores;
  drop if _merge==2;
 tab cohort indata_alg1, m;
 *Have algebra 1 scores for 70%+ of students in 1992-2004 cohorts. Only 30% in 2005;
 *Drop algebra 1 outcomes for post-2005 cohorts;
  foreach v of varlist alg1* {;
    replace `v'=. if cohort>2005;
  };
  replace indata_alg1=. if cohort>2005;
  rename alg1EOC lr_alg1score;
 *Make a graduation variable from the exit data (the only one where we can see dropout);
  gen byte lr_grad=0 if exit_dropout==1;
  replace lr_grad=1 if exit_graduated==1;
  tab cohort lr_grad, m row;
   *Have data for 60%+ of 1995-2002 cohorts;
    replace lr_grad=. if cohort<1995 | cohort>2002;
 *Make a college-bound variable;
  gen lr_collbound=gpa_tocoll if indata_gpa==1;
  replace lr_collbound=grads_tocoll if indata_grads==1 & lr_collbound~=1;
  replace lr_collbound=0 if lr_grad==0;
  gen lr_coll4bound=gpa_tocoll4 if indata_gpa==1;
  replace lr_coll4bound=grads_tocoll4 if indata_grads==1 & lr_coll4bound~=1;
  replace lr_coll4bound=0 if lr_grad==0 | lr_collbound==0;
  tab cohort lr_collbound, m row;
   *Have data for 60%+ of 1997-2002 cohorts;
    replace lr_collbound=. if cohort<1997 | cohort>2002;
    replace lr_coll4bound=. if cohort<1997 | cohort>2002;
 *Can use GPA and rank as is, for the right cohorts;
  tab cohort indata_gpa, m row;
   *Have data for 55%+ of 1997,8,2000, 2001, 2002 cohorts;
    gen lr_gpa=gpa_weighted if inlist(cohort, 1997,1998,2000,2001,2002);
    gen lr_rank=gpa_rank if inlist(cohort, 1997,1998,2000,2001,2002);
 *And drop excess variables;
  keep sch year grade class_id math pared stuid predscore_pared cohort d_pared* lr_*;
 save `cfrdat'/NOTIRS_studentlevel.dta, replace;
 *And collapse to sch-gr-year level;
  foreach v of varlist lr_* {;
    gen count_`v'=1 if `v'<.;
  };
  collapse (mean) d_pared* predscore_pared lr_* (sum) count_*, by(sch year grade math);
  rename count_lr_* lr_*_count;
  save `cfrdat'/NOTIRS_sch_gr_year_collapse.dta, replace;
 *And to class level;
  use `cfrdat'/NOTIRS_studentlevel;
  foreach v of varlist lr_* {;
    gen count_`v'=1 if `v'<.;
  };
  collapse (mean) d_pared* predscore_pared lr_* (sum) count_*, by(sch year class_id math);
  rename count_lr_* lr_*_count;
  save `cfrdat'/NOTIRS_class_collapse.dta, replace;
 if `doasproject'==1 {;
 	 project, creates(`cfrdat'/NOTIRS_studentlevel.dta);
 	 project, creates(`cfrdat'/NOTIRS_sch_gr_year_collapse.dta);
 	 project, creates(`cfrdat'/NOTIRS_class_collapse.dta);
 }; 

