
*apptab_leavenout.do
*By Jesse Rothstein
*7/7/15
*
*This program re-runs the basic quasiexperiment regressions, with various
*corrections for possible "mechanical" effects
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "apptab_leavenout"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`pdir'/scratch/extension/preparequasi.dta)
 	project, uses(`pdir'/scratch/extension/movetypes_quasi.dta)
}


 use `pdir'/scratch/extension/preparequasi
 merge 1:1 sch math grade year using `pdir'/scratch/extension/movetypes_quasi, keepusing(*follow*)
*We are going to run three basic regressions, using two sets of weights. 

**Start by doing everything with CFR weights
 *Set up baseline now.
 *CFR quasiexperiment
  areg d_score_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch_cohort) a(sch_yr)
  eststo r1_tv_m0
 *Placebo test
  areg d_score_l_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch_cohort) a(sch_yr)
  eststo r2_tv_m0
 *Quasiexperiment with control
  areg d_score_tv_CLwgt dva_tv_CLwgt d_score_l_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch_cohort) a(sch_yr)
  eststo r3_tv_m0
 
 *Cluster on school
  areg d_score_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
  eststo r1_tv_m1
  areg d_score_l_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
  eststo r2_tv_m1
  areg d_score_tv_CLwgt dva_tv_CLwgt d_score_l_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
  eststo r3_tv_m1
  
 *IV with no-follow measure
  egen gm=group(grade math)
  xtset sch_yr gm
  xtivreg2 d_score_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r1_tv_m2
  xtivreg2 d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r2_tv_m2
  xtivreg2 d_score_tv_CLwgt d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r3_tv_m2

 *Using leave-n-out
  forvalues n=3/5 {
    areg d_score_tv_CLwgt dva`n'_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
    eststo r1_tv_m`n'
    areg d_score_l_tv_CLwgt dva`n'_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
    eststo r2_tv_m`n'
    areg d_score_tv_CLwgt dva`n'_tv_CLwgt d_score_l_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
    eststo r3_tv_m`n'
  }
 
 *Using leave past out
  areg d_score_tv_CLwgt dvafuture_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
  eststo r1_tv_m6
  areg d_score_l_tv_CLwgt dvafuture_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
  eststo r2_tv_m6
  areg d_score_tv_CLwgt dvafuture_tv_CLwgt d_score_l_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(sch_yr)
  eststo r3_tv_m6

 *No follower IV, with leave-3-out
  xtset sch_yr gm
  xtivreg2 d_score_tv_CLwgt (dva3_tv_CLwgt=dva3_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r1_tv_m7
  xtivreg2 d_score_l_tv_CLwgt (dva3_tv_CLwgt=dva3_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r2_tv_m7
  xtivreg2 d_score_tv_CLwgt d_score_l_tv_CLwgt (dva3_tv_CLwgt=dva3_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r3_tv_m7

 *And school-year-subject FEs
  egen smt=group(sch math year)
   areg d_score_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(smt)
  eststo r1_tv_m8
  areg d_score_l_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(smt)
  eststo r2_tv_m8
  areg d_score_tv_CLwgt dva_tv_CLwgt d_score_l_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch) a(smt)
  eststo r3_tv_m8
 
 *No-follower IV, with school-year-subject FEs
  sort smt grade
  xtset smt grade
   xtivreg2 d_score_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r1_tv_m9
   xtivreg2 d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r2_tv_m9
   xtivreg2 d_score_tv_CLwgt d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r3_tv_m9

 **Two extra columns, not to be used in this table but to mention in the text: 
 **Do the last spec separately for math and reading
   xtivreg2 d_score_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt] if math==0, cluster(sch) fe
  eststo r1_tv_m90
   xtivreg2 d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt] if math==0, cluster(sch) fe
  eststo r2_tv_m90
   xtivreg2 d_score_tv_CLwgt d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt] if math==0, cluster(sch) fe
  eststo r3_tv_m90
   xtivreg2 d_score_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt] if math==1, cluster(sch) fe
  eststo r1_tv_m91
   xtivreg2 d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt] if math==1, cluster(sch) fe
  eststo r2_tv_m91
   xtivreg2 d_score_tv_CLwgt d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_follower0_tv_CLwgt) [w=SGY_size_tv_CLwgt] if math==1, cluster(sch) fe
  eststo r3_tv_m91
 
/*
 **Two extra columns, not to be used in this table but nevertheless relevant for discussion:
 ** Do the no-follower IV, excluding followers.
 *IV with no-follow measure
  xtset sch_yr gm
  xtivreg2 d_score_tv_CLwgt (dva_tv_CLwgt=dva_nofollowers_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r1_tv_m10
  xtivreg2 d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_nofollowers_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r2_tv_m10
  xtivreg2 d_score_tv_CLwgt d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_nofollowers_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r3_tv_m10
 *No-follower IV, with school-year-subject FEs
  sort smt grade
  xtset smt grade
   xtivreg2 d_score_tv_CLwgt (dva_tv_CLwgt=dva_nofollowers_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r1_tv_m11
   xtivreg2 d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_nofollowers_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r2_tv_m11
   xtivreg2 d_score_tv_CLwgt d_score_l_tv_CLwgt (dva_tv_CLwgt=dva_nofollowers_tv_CLwgt) [w=SGY_size_tv_CLwgt], cluster(sch) fe
  eststo r3_tv_m11
*/
**Now redo with imputations

 *Set up baseline now.
 *CFR quasiexperiment
  areg d_score_all_CLwgt dva_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch_cohort) a(sch_yr)
  eststo r1_all_m0
 *Placebo test
  areg d_score_l_all_CLwgt dva_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch_cohort) a(sch_yr)
  eststo r2_all_m0
 *Quasiexperiment with control
  areg d_score_all_CLwgt dva_all_CLwgt d_score_l_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch_cohort) a(sch_yr)
  eststo r3_all_m0
 
 *Cluster on school
  areg d_score_all_CLwgt dva_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
  eststo r1_all_m1
  areg d_score_l_all_CLwgt dva_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
  eststo r2_all_m1
  areg d_score_all_CLwgt dva_all_CLwgt d_score_l_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
  eststo r3_all_m1
  
 *IV with no-follow measure
  xtset sch_yr gm
  xtivreg2 d_score_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r1_all_m2
  xtivreg2 d_score_l_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r2_all_m2
  xtivreg2 d_score_all_CLwgt d_score_l_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r3_all_m2

 *Using leave-n-out
  forvalues n=3/5 {
    areg d_score_all_CLwgt dva`n'_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
    eststo r1_all_m`n'
    areg d_score_l_all_CLwgt dva`n'_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
    eststo r2_all_m`n'
    areg d_score_all_CLwgt dva`n'_all_CLwgt d_score_l_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
    eststo r3_all_m`n'
  }
 
 *Using leave past out
  areg d_score_all_CLwgt dvafuture_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
  eststo r1_all_m6
  areg d_score_l_all_CLwgt dvafuture_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
  eststo r2_all_m6
  areg d_score_all_CLwgt dvafuture_all_CLwgt d_score_l_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(sch_yr)
  eststo r3_all_m6

 *IV with no-follow measure, leave 3 out
  xtset sch_yr gm
  xtivreg2 d_score_all_CLwgt (dva3_all_CLwgt=dva3_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r1_all_m7
  xtivreg2 d_score_l_all_CLwgt (dva3_all_CLwgt=dva3_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r2_all_m7
  xtivreg2 d_score_all_CLwgt d_score_l_all_CLwgt (dva3_all_CLwgt=dva3_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r3_all_m7

 *And school-year-subject FEs
  areg d_score_all_CLwgt dva_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(smt)
  eststo r1_all_m8
  areg d_score_l_all_CLwgt dva_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(smt)
  eststo r2_all_m8
  areg d_score_all_CLwgt dva_all_CLwgt d_score_l_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch) a(smt)
  eststo r3_all_m8
 
 *No-follower IV, with school-year-subject FEs
  sort smt grade
  xtset smt grade
   xtivreg2 d_score_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r1_all_m9
   xtivreg2 d_score_l_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r2_all_m9
   xtivreg2 d_score_all_CLwgt d_score_l_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r3_all_m9

 **Two extra columns, not to be used in this table but to mention in the text: 
 **Do the last spec separately for math and reading
   xtivreg2 d_score_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt] if math==0, cluster(sch) fe
  eststo r1_all_m90
   xtivreg2 d_score_l_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt] if math==0, cluster(sch) fe
  eststo r2_all_m90
   xtivreg2 d_score_all_CLwgt d_score_l_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt] if math==0, cluster(sch) fe
  eststo r3_all_m90
   xtivreg2 d_score_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt] if math==1, cluster(sch) fe
  eststo r1_all_m91
   xtivreg2 d_score_l_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt] if math==1, cluster(sch) fe
  eststo r2_all_m91
   xtivreg2 d_score_all_CLwgt d_score_l_all_CLwgt (dva_all_CLwgt=dva_follower0_all_CLwgt) [w=SGY_size_all_CLwgt] if math==1, cluster(sch) fe
  eststo r3_all_m91

/*
 **Two extra columns, not to be used in this table but nevertheless relevant for discussion:
 ** Do the no-follower IV, imputing school mean rather than zero for followers.
 *IV with no-follow measure
  xtset sch_yr gm
  xtivreg2 d_score_all_CLwgt (dva_all_CLwgt=dva_nofollowers_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r1_all_m10
  xtivreg2 d_score_l_all_CLwgt (dva_all_CLwgt=dva_nofollowers_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r2_all_m10
  xtivreg2 d_score_all_CLwgt d_score_l_all_CLwgt (dva_all_CLwgt=dva_nofollowers_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r3_all_m10
 *No-follower IV, with school-year-subject FEs
  sort smt grade
  xtset smt grade
   xtivreg2 d_score_all_CLwgt (dva_all_CLwgt=dva_nofollowers_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r1_all_m11
   xtivreg2 d_score_l_all_CLwgt (dva_all_CLwgt=dva_nofollowers_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r2_all_m11
   xtivreg2 d_score_all_CLwgt d_score_l_all_CLwgt (dva_all_CLwgt=dva_nofollowers_all_CLwgt) [w=SGY_size_all_CLwgt], cluster(sch) fe
  eststo r3_all_m11
*/  
  
esttab r1_tv_m*, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r2_tv_m*, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r3_tv_m*, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r1_all_m*, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r2_all_m*, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r3_all_m*, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r1_tv_m* using `thisdir'/`dofile'.txt, replace ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r2_tv_m* using `thisdir'/`dofile'.txt, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r3_tv_m* using `thisdir'/`dofile'.txt, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r1_all_m* using `thisdir'/`dofile'.txt, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r2_all_m* using `thisdir'/`dofile'.txt, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r3_all_m* using `thisdir'/`dofile'.txt, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab r1_tv_m* using `thisdir'/`dofile'.csv, replace ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars noparentheses

esttab r2_tv_m* using `thisdir'/`dofile'.csv, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars noparentheses

esttab r3_tv_m* using `thisdir'/`dofile'.csv, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars noparentheses

esttab r1_all_m* using `thisdir'/`dofile'.csv, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars noparentheses

esttab r2_all_m* using `thisdir'/`dofile'.csv, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars noparentheses

esttab r3_all_m* using `thisdir'/`dofile'.csv, append ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars noparentheses


 if `doasproject'==1 {
 	 project, creates(`thisdir'/`dofile'.csv)
 	 project, creates(`thisdir'/`dofile'.txt)
 }
