*classlevel.do
*By Jesse Rothstein
*7/2/15
*
*Makes a class-level (i.e., since we have elementary teachers,
*teacher-year-(subject-)level) data file that is then aggregated to the
*school-grade-year-subject level by preparequasi.do.
*
* Variables include:
* 1) End-of-year scores (A*)
* 2) Predicted scores (XB)
* 3) Residual scores (A)
* 4) Gain scores (A*-LA*)
* 5) Prior year scores (LA)
* 6) Teacher VA predictions (leave-one-out, leave-2-out, with and 
*    without imputations, etc.)
*
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "classlevel"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local scratch "`pdir'/scratch"
local outdir "`pdir'/scratch/extension"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
	project, uses(`cfrdat'/schd_work.dta)
	project, uses(`cfrdat'/NOTIRS_studentlevel.dta)
	project, uses(`cfrdat'/tfx/score_r.dta)
 	project, uses(`pdir'/scratch/extension/demogpredict.dta)
	project, uses(`cfrdat'/SCHD_class_year_collapse.dta)
	project, uses(`cfrdat'/teacher_school_weights.dta)
	project, uses(`cfrdat'/tfx/tfx_tym.dta)
 	project, uses(`pdir'/scratch/replication/basicreplication.dta)
}

**Assemble the student-level test score data.
  use stuid year score PREZl_score f?_score l?_score math teacher class class_id sch year grade flag_sample using `cfrdat'/schd_work
  rename PREZl_score score_l
  rename l?_score score_l?
  rename f?_score score_f?
  gen score_g=score-score_l
  isid stuid year math
  merge 1:1 stuid year math using `cfrdat'/NOTIRS_studentlevel.dta, assert(3) nogen
  rename predscore_pared score_p_pared
  tempfile students
  save `students'
  
  use stuid year math score_r using `cfrdat'/tfx/score_r
  merge 1:1 stuid year math using `scratch'/extension/demogpredict, assert(3) nogen
  merge 1:1 stuid year math using `students', assert(2 3) nogen
  gen score_p=score-score_r

**Collapse to class mean and compare to SCHD_class_year_collapse to ensure replication
**successful so far.
  collapse (mean) score score_l score_g score_f? score_l? score_p score_r score_p_pared score_p_demog (count) nobs=score , by(math sch year class_id teacher grade class)
  tempfile classlev_scores
  save `classlev_scores'

  **Check successful replication
    foreach v of varlist score grade math sch year teacher class_id nobs score_f? score_l? score_l {
    	rename `v' new_`v'
    }
    isid class
    *Merge to CFRs data set to check that variables match and to compare those that dont.
     merge 1:1 class using `cfrdat'/SCHD_class_year_collapse.dta, assert(3) nogen
     foreach v of varlist math sch year teacher class_id {
  	   compare `v' new_`v'
     }
     compare new_nobs CLass_size
     corr new_nobs CLass_size
     *Results: All are identical, but class size is off a bit. My new_nobs counts only those with non-missing
     *scores, while CLass_size counts those with missing scores also. Thus, CLass_size>=new_nobs, though
     *they are identical in 71% of cases and the difference is only 1.5 students, on average (on a base
     *of 22) in the 29% of cases where they differ.
     assert new_score==mean_score
     assert new_score_l==mean_l_score

**Now assemble the teacher-level data 
  use sch year grade math teacher class CLass_size lea teachid schlcode using `cfrdat'/SCHD_class_year_collapse, clear
  isid sch year grade math teacher
  merge 1:1 teacher year math sch grade using `cfrdat'/teacher_school_weights, keepusing(n_students teach_wt) assert(3) nogen
  assert CLass_size==n_students
  drop n_students
  merge m:1 teacher year math using `cfrdat'/tfx/tfx_tym, assert(1 3)
  rename _merge mrg
  keep teacher year math sch grade tv tv_?yr_? tv_future_? CLass_size lea teachid schlcode
  tempfile tv
  save `tv'
  
**Merge the class-level score data to the teacher-level VA data
 use `classlev_scores'
 merge m:1 sch year grade math teacher using `tv', assert(3) nogen
  *Alternative weights to use in constructing VA
   rename CLass_size CLass_size_cfr
   rename nobs CLass_size_alt
   gen tvsamp_CLass_size_cfr=CLass_size_cfr*(tv<.)
   gen tvsamp_CLass_size_alt=CLass_size_alt*(tv<.)
  *Assign zeros to any missing TV -- we use the weights to manage the sample
  *selection.
   foreach v of varlist tv tv_?yr_? tv_future_? {
   	 gen byte miss_`v'=(`v'==.)
   	 replace `v'=0 if `v'==.
   }

**Save the class-level data file
 compress
 save `outdir'/`dofile'.dta, replace
 
 if `doasproject'==1 project, creates(`outdir'/`dofile'.dta)
