*demogsorting.do
*By Jesse Rothstein
*7/12/15
*
*This program estimates regressions of demographic variables on teacher VA at the class and school levels.
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "demogsorting"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`pdir'/scratch/extension/classlevel.dta)
 	project, uses(`cfrdat'/schd_work_trim.dta)
 	project, uses(`cfrdat'/NOTIRS_studentlevel.dta)
}

 set more off
 
 *Start by making predicted versions of the long-run outcomes, using the within-teacher
 *residualization technique
  use `cfrdat'/schd_work_trim
  *isid stuid year math
  merge 1:1 stuid year math using `cfrdat'/NOTIRS_studentlevel, keepusing(lr_*)
  local VAM_controls "PREZ* PREO* MPREO* CL* SG* SY* female"
  local VAM_controls "`VAM_controls' age_current lunch miss_lunch ETHN* sped limited_english repeat_grade"
  local VAM_controls "`VAM_controls' MISS_sped MISS_limited_english MISS_age_current repeat_test YEAR* GRDE*"
  foreach v in collbound /*gpa grad coll4bound rank */ {
    gen p_lr_`v'=.
    forvalues m=0/1 {
      areg lr_`v' `VAM_controls' if math==`m', absorb(teacher)
      predict temp, xb
      replace p_lr_`v'=temp if math==`m'
      drop temp
    }
  }
  keep teacher math year p_lr_*
  collapse (mean) p_lr_*, by(teacher math year)
  keep if teacher<.
  tempfile p_longrun
  save `p_longrun'
  
 use `cfrdat'/schd_work_trim
 local controls "CL* SG* SY* YEAR* GRDE*"
 keep stuid math year teacher `controls'
 sort teacher math year stuid
 by teacher math year: keep if _n==1
 drop stuid
 
 merge 1:1 teacher math year using `p_longrun', assert(1 3) nogen
 merge 1:1 teacher math year using `pdir'/scratch/extension/classlevel, assert(2 3)
 keep if _merge==3
 drop _merge
 merge m:1 math using `cfrdat'/tfx/sd_tfx, assert(3) nogen keepusing(sd_tfx)
 gen tv_std=tv/sd_tfx

 gen CLminority=CLETHNethnici_1 + CLETHNethnici_2
 replace CLlunch=. if year<1999 | year>2006

 local vlist CLPZl_score CLlunch CLminority score_p p_lr_collbound
 foreach v in `vlist' {
 	 reg `v' tv_std [aw=CLass_size_cfr], cluster(sch)
 	 eststo c1_`v'
 	 areg `v' tv_std [aw=CLass_size_cfr], absorb(sch) cluster(sch)
 	 eststo c2_`v'
 }
 keep if e(sample)
 gen weight=CLass_size_cfr
 gen lunch_weight=CLass_size_cfr if CLlunch<.
 collapse (mean) CL* tv tv_std p_lr_collbound score_p (rawsum) weight lunch_weight [aw=CLass_size_cfr], by(sch)
 foreach v in `vlist' {
 	 cap gen `v'_weight=weight
 	 reg `v' tv_std [aw=`v'_weight], cluster(sch)
 	 eststo c3_`v'
 }
 
esttab *, cells(b(fmt(5)) se(fmt(5))) r2 obslast 
esttab * using `dofile'.txt, replace cells(b(fmt(5)) se(fmt(5))) r2 obslast 
esttab * using `dofile'.csv, replace cells(b(fmt(5)) se(fmt(5))) r2 obslast 
 
if `doasproject'==1 {
	project, creates(`thisdir'/`dofile'.txt)
	project, creates(`thisdir'/`dofile'.csv)
}
