*imputations.do
*By Jesse Rothstein
*7/6/15
*Program to impute VA for teachers who are otherwise missing 2-year measures.
*
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "imputations"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local scratch "`pdir'/scratch"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`pdir'/scratch/extension/classlevel.dta)
}

 use `pdir'/scratch/extension/classlevel.dta
 isid teacher year math sch
 *keep if score_r<. & grade<. & CLass_size_alt>0 & CLass_size_alt<.
 keep teacher year math sch grade score_r tv tv_2yr_? CLass_size_cfr CLass_size_alt miss_tv_2yr_?
 
 rename miss_tv_2yr_l missva_l
 rename miss_tv_2yr_f missva_f
 replace tv_2yr_l=. if missva_l==1
 replace tv_2yr_f=. if missva_f==1
 
 levelsof year, local(ylist)
 
 *Impute zero if missing
  gen tv_2yr_l_imp0=tv_2yr_l
  replace tv_2yr_l_imp0=0 if missva_l==1
  gen tv_2yr_f_imp0=tv_2yr_f
  replace tv_2yr_f_imp0=0 if missva_f==1
 
 *Impute mean for all teachers with missing data
  gen tv_2yr_l_impmiss=tv_2yr_l
  gen tv_2yr_f_impmiss=tv_2yr_f
  forvalues m=0/1 {
    foreach y of local ylist {
  		su score_r if missva_l==1 & (year<`y'-1 | year>`y') & math==`m' [aw=CLass_size_alt], meanonly
      replace tv_2yr_l_impmiss=r(mean) if missva_l==1 & year==`y' & math==`m'
      su score_r if missva_f==1 & (year<`y'+1 | year>`y') & math==`m' [aw=CLass_size_alt], meanonly
      replace tv_2yr_f_impmiss=r(mean) if missva_f==1 & year==`y' & math==`m'
    }
  }
  
 *Impute school average among imputed or among all teachers
  egen sm=group(sch math)
  isid sm teacher year
  sort sm teacher year
  gen schlmean_l=.
  gen schlmean_f=.
  gen schlmean_missing_l=.
  gen schlmean_missing_f=.
  foreach y of local ylist {
  	di "starting leave-2-out analysis with t=`y'"
  	gen byte samp=(year>`y' | year<`y'-1)
    *And the total number of obs per school
     by sm: egen n_s=sum(samp*CLass_size_alt)
    *And the actual mean
     by sm: egen sklmean`y'=sum(score_r*samp*CLass_size_alt)
     qui replace sklmean`y'=sklmean`y'/n_s
    *And redo using only the missings
     by sm: egen n_s_l=sum(samp*CLass_size_alt*missva_l)
     by sm: egen sklmean`y'_l=sum(samp*CLass_size_alt*missva_l*score_r)
     qui replace sklmean`y'_l=sklmean`y'_l/n_s_l
     by sm: egen n_s_f=sum(samp*CLass_size_alt*missva_f)
     by sm: egen sklmean`y'_f=sum(samp*CLass_size_alt*missva_f*score_r)
     qui replace sklmean`y'_f=sklmean`y'_f/n_s_f
    *Now fill in the relevant variables
     qui replace schlmean_l=sklmean`y' if year==`y'
     qui replace schlmean_f=sklmean`y' if year==`y'-1
     qui replace schlmean_missing_l=sklmean`y'_l if year==`y'
     qui replace schlmean_missing_f=sklmean`y'_f if year==`y'-1
    drop n_s samp sklmean`y' n_s_l n_s_f sklmean`y'_l sklmean`y'_f 
  }  
  
  gen tv_2yr_f_impskl=tv_2yr_f
  gen tv_2yr_l_impskl=tv_2yr_l
  gen tv_2yr_f_impsklmiss=tv_2yr_f
  gen tv_2yr_l_impsklmiss=tv_2yr_l
  forvalues m=0/1 {    
   reg score_r schlmean_l if math==`m' [aw=CLass_size_alt]
   predict impute_l, xb
   reg score_r schlmean_f if math==`m' [aw=CLass_size_alt]
   predict impute_f, xb
   replace tv_2yr_l_impskl=impute_l if math==`m' & missva_l==1
   replace tv_2yr_f_impskl=impute_f if math==`m' & missva_f==1
   drop impute_*
   
   reg score_r schlmean_missing_l if math==`m' & missva_l==1 [aw=CLass_size_alt]
   predict impute_l, xb
   reg score_r schlmean_missing_f if math==`m' & missva_f==1 [aw=CLass_size_alt]
   predict impute_f, xb
   replace tv_2yr_l_impsklmiss=impute_l if math==`m' & missva_l==1
   replace tv_2yr_f_impsklmiss=impute_f if math==`m' & missva_f==1
   drop impute_*
 }
 *Assign zero if there is no information at the school for use in imputation.
 foreach v of varlist tv_2yr_?_impskl* {
   replace `v'=0 if `v'==.
 }
   
 keep teacher year math sch grade tv_2yr_?_imp*
 
 save `scratch'/extension/`dofile'.dta, replace
 if `doasproject'==1 project, creates(`scratch'/extension/`dofile'.dta)
 