*movetypes.do
*by Jesse Rothstein
*July 7, 2015
*
*Identify: 
*  A) Followers -- previously taught same cohort at same school.
*  B) Decomposition by prior year status
*     1) Same school, same grade
*     2) Same school, different grade (incl. non-tested grades)
*     3) Different school, same district
*     4) Different district
*     5) Returning to system
*     6) New to system
*  C) Decomposition by next year status
*     1)-4): Same
*     5) Temporary exit from system
*     6) Permanent exit from system
*
*Note 1: Need to use teachid, not teacher, since the latter is recoded to prevent
*"bad" matches but the former represents where the teacher actually is.

version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "movetypes"
	local sig "Not run as part of project!"
}

local scratch "`pdir'/scratch"
set varabbrev off
set more off

if `doasproject'==1 {
	project, uses(`scratch'/extension/classlevel.dta)
	project, uses(`scratch'/ncdata/prepdata_SAR.dta)
}

use `scratch'/extension/classlevel
isid math teacher year
keep sch math teacher year grade lea teachid schlcode
gen cohort = year - grade
bys math teacher (year): gen firstyear=year[1]
tempfile classlev
save `classlev'


*Prepare SAR data -- we will try to merge by year, by lea-year, by lea-school-year,
*and by lea-school-grade-year, to see what we can get
use `scratch'/ncdata/prepdata_SAR
keep if teachassign_alt==1
keep lea schlcode year teachid sccgrd
destring sccgrd, gen(SAR_grade) force
*Note that "Z" is "elementary" without detail -- call it 6
replace SAR_grade=0 if sccgrd=="K"
replace SAR_grade=-1 if sccgrd=="P"
replace SAR_grade=6 if sccgrd=="Z"
*Anything above elementary will also be coded as 6.
replace SAR_grade=6 if inlist(sccgrd,"7","8","9","A","B","C","X","Y")
gen cohort=year-SAR_grade
replace SAR_grade=0 if !inlist(SAR_grade, 3, 4, 5)
rename SAR_grade grade
tempfile sar sar_0 sar_t sar_td sar_tds sar_tdsg
keep teachid year lea schlcode grade
save `sar'
 *Make one district per teacher-year-lea-school-grade
  sort teachid year lea schlcode grade
  by teachid year lea schlcode grade: keep if _n==1
  save `sar_tdsg'
 *Make one district per teacher-year-lea-school
  by teachid year lea schlcode: keep if _n==1
  drop grade
  save `sar_tds'
 *Make one district per teacher-year-lea
  by teachid year lea: keep if _n==1
  drop schlcode
  save `sar_td'
 *Make one district per teacher-year
  by teachid year: keep if _n==1
  drop lea
  save `sar_t'
 *And one per teacher 
  by teachid: gen SAR_firstyear=year[1]
  by teachid: gen SAR_lastyear=year[_N]
  keep teachid SAR_firstyear SAR_lastyear
  by teachid: keep if _n==1
  save `sar_0'
  
*Now back to the class level data. We have duplicates here, too, by teachid
*(e.g., a teacher coded with multiple grades). Need the same strategy
 tempfile cl_tdsg cl_tds cl_td cl_t cl_0
 use if teachid<. using `classlev'
 sort teachid year lea schlcode grade math
 keep teachid year lea schlcode grade teacher
 rename teacher teachercode
 by teachid year lea schlcode grade: keep if _n==1
 save `cl_tdsg'
 by teachid year lea schlcode: keep if _n==1
 save `cl_tds'
 by teachid year lea: keep if _n==1
 save `cl_td'
 by teachid year: keep if _n==1
 save `cl_t'
 by teachid: gen cls_firstyear=year[1]
 by teachid: gen cls_lastyear=year[_N]
 by teachid: keep if _n==1
 keep teachid cls_firstyear cls_lastyear
 save `cl_0'
 
*Merge the two sets of files together
 foreach level in t td tds tdsg {
 	 if "`level'"=="t" local mrgvars "teachid year"
 	 else if "`level'"=="td" local mrgvars "`mrgvars' lea"
 	 else if "`level'"=="tds" local mrgvars "`mrgvars' schlcode"
 	 else if "`level'"=="tdsg" local mrgvars "`mrgvars' grade"
 	 use `sar_`level''
 	 merge 1:1 `mrgvars' using `cl_`level''
 	 gen insar=inlist(_merge, 1, 3)
 	 gen inclass=inlist(_merge,2,3)
 	 keep `mrgvars' insar inclass teachercode
 	 tempfile mrg_`level'
 	 save `mrg_`level''
 }

*Now, at last, go back to the class data and merge to the year-before
*data to identify status
 use `classlev'
 egen tm=group(teacher math)
 sort tm sch cohort year
 by tm sch cohort: gen follower=(_n>1)
 xtset tm year
 sort tm year 
 by tm: gen permenter_l=(_n==1)
 by tm: gen tempenter_l=(_n>1) & year[_n-1]~=year-1
 by tm: gen newlea_l=(lea~=lea[_n-1])*(_n>1)*(year==year[_n-1]+1)
 by tm: gen samelea_l=(lea==lea[_n-1])*(year==year[_n-1]+1) 
 by tm: gen samesch_l=samelea_l*(sch==L.sch)
 by tm: gen samegrade_l=samesch_l*(grade==L.grade)
 egen tot=rsum(permenter_l-samelea_l)
 assert tot==1
 drop tot

 by tm: gen permexit_f=(_n==_N)
 by tm: gen tempexit_f=(_n<_N) & year[_n+1]~=year+1
 by tm: gen newlea_f=(lea~=lea[_n+1])*(_n<_N)*(year==year[_n+1]-1)
 by tm: gen samelea_f=(lea==lea[_n+1])*(year==year[_n+1]-1) 
 by tm: gen samesch_f=samelea_f*(sch==F.sch)
 by tm: gen samegrade_f=samesch_f*(grade==F.grade)
 egen tot=rsum(permexit_f-samelea_f)
 assert tot==1
 drop tot

 sort teacher math year 
 tempfile mobility
 save `mobility'
 
*Now we need to merge on to SAR to see about whether the teacher shows up previously
 use `mobility'
 rename year origyear
 gen year=origyear-1
 merge m:1 teachid year using `mrg_t', keep(1 3) nogen
 gen SAR_present_l=(insar==1)
 gen cls_present_l=(inclass==1)
 drop teachercode insar inclass 
 merge m:1 teachid year lea using `mrg_td', keep(1 3) nogen
 gen SAR_samelea_l=(insar==1)
 gen cls_samelea_l=(inclass==1)
 drop teachercode insar inclass 
 merge m:1 teachid year lea schlcode using `mrg_tds', keep(1 3) nogen
 gen SAR_samesch_l=(insar==1)
 gen cls_samesch_l=(inclass==1)
 drop teachercode insar inclass 
 merge m:1 teachid year lea schlcode grade using `mrg_tdsg', keep(1 3) nogen
 gen SAR_samegrade_l=(insar==1)
 gen cls_samegrade_l=(inclass==1)
 drop teachercode insar inclass 

 replace year=origyear+1
 merge m:1 teachid year using `mrg_t', keep(1 3) nogen
 gen SAR_present_f=(insar==1)
 gen cls_present_f=(inclass==1)
 drop teachercode insar inclass 
 merge m:1 teachid year lea using `mrg_td', keep(1 3) nogen
 gen SAR_samelea_f=(insar==1)
 gen cls_samelea_f=(inclass==1)
 drop teachercode insar inclass 
 merge m:1 teachid year lea schlcode using `mrg_tds', keep(1 3) nogen
 gen SAR_samesch_f=(insar==1)
 gen cls_samesch_f=(inclass==1)
 drop teachercode insar inclass 
 merge m:1 teachid year lea schlcode grade using `mrg_tdsg', keep(1 3) nogen
 gen SAR_samegrade_f=(insar==1)
 gen cls_samegrade_f=(inclass==1)
 drop teachercode insar inclass 

 merge m:1 teachid using `sar_0', keep(1 3) nogen
 merge m:1 teachid using `cl_0', keep(1 3) nogen

 drop year
 rename origyear year
 isid teacher math year 
 
 label define movetype 0 "Same grade, valid" 1 "Same grade, invalid" 2 "Same school" 3 "Same LEA" ///
                       4 "New LEA" 5 "Reentrant" 6 "New entrant"
 gen movetype_l=0 if samegrade_l==1
 replace movetype_l=1 if movetype_l==. & (cls_samegrade_l==1 | SAR_samegrade_l==1)
 replace movetype_l=2 if movetype_l==. & (samesch_l==1 | cls_samesch_l==1 | SAR_samesch_l==1)
 replace movetype_l=3 if movetype_l==. & (samelea_l==1 | cls_samelea_l==1 | SAR_samelea_l==1)
 replace movetype_l=4 if movetype_l==. & (newlea_l==1 | cls_present_l==1 | SAR_present_l==1)
 replace movetype_l=5 if movetype_l==. & (tempenter_l==1 | SAR_firstyear<year | cls_firstyear<year)
 replace movetype_l=6 if movetype_l==. & (permenter_l==1 | SAR_firstyear==year | cls_firstyear==year)
 gen movetype_f=0 if samegrade_f==1
 replace movetype_f=1 if movetype_f==. & (cls_samegrade_f==1 | SAR_samegrade_f==1)
 replace movetype_f=2 if movetype_f==. & (samesch_f==1 | cls_samesch_f==1 | SAR_samesch_f==1)
 replace movetype_f=3 if movetype_f==. & (samelea_f==1 | cls_samelea_f==1 | SAR_samelea_f==1)
 replace movetype_f=4 if movetype_f==. & (newlea_f==1 | cls_present_f==1 | SAR_present_f==1)
 replace movetype_f=5 if movetype_f==. & (tempexit_f==1 | SAR_lastyear>year | cls_lastyear>year)
 replace movetype_f=6 if movetype_f==. & (permexit_f==1 | SAR_lastyear==year | cls_lastyear==year)
 label values movetype_l movetype
 label values movetype_f movetype
 
  keep teacher math year movetype_? follower
  compress
  save `scratch'/extension/`dofile'.dta, replace
  if `doasproject'==1 project, creates(`scratch'/extension/`dofile'.dta)
  