
*table2.do
*By Jesse Rothstein
*7/1/15
*
*This program estimates the basic CFR regressions, using lagged scores
*for the dependent variable
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "movetypes_analysis"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`pdir'/scratch/extension/preparequasi.dta)
}


 use `pdir'/scratch/extension/preparequasi
 merge 1:1 sch math grade year using `pdir'/scratch/extension/movetypes_quasi, assert(3) nogen

*Identify samples so we can hold them fixed
 * T1, Col 1
  areg d_score_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch_cohort) a(year)
  gen samp_panelA=e(sample)
 * T1, Col 4
  areg d_score_all_CL2wgt dva_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch_cohort) a(year)
  gen samp_panelB=e(sample)


*Panel A - no imputations
 * Cols 1-2: Lagged score
  areg d_score_l_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_panelA==1, cluster(sch_cohort) a(sch_yr)
  eststo pAc1
  areg d_score_l_tv_CLwgt dva_type?_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_panelA==1, cluster(sch_cohort) a(sch_yr)
  test dva_type0_tv_CLwgt=dva_type1_tv_CLwgt=dva_type2_tv_CLwgt=dva_type3_tv_CLwgt=dva_type4_tv_CLwgt=dva_type5_tv_CLwgt=dva_type6_tv_CLwgt
  local pequal=r(p)
  testparm dva_type?_tv_CLwgt
  local p0=r(p)
  eststo pAc2, addscalars(p0 `p0' pequal `pequal')
 * Cols 3-4: end of year score
  areg d_score_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_panelA==1, cluster(sch_cohort) a(sch_yr)
  estimates store pAc3
  areg d_score_tv_CLwgt dva_type?_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_panelA==1, cluster(sch_cohort) a(sch_yr)
  test dva_type0_tv_CLwgt=dva_type1_tv_CLwgt=dva_type2_tv_CLwgt=dva_type3_tv_CLwgt=dva_type4_tv_CLwgt=dva_type5_tv_CLwgt=dva_type6_tv_CLwgt
  local pequal=r(p)
  testparm dva_type?_tv_CLwgt
  local p0=r(p)
  eststo pAc4, addscalars(p0 `p0' pequal `pequal')

*Panel B - with imputations
 * Cols 1-2: Lagged score
  areg d_score_l_all_CLwgt dva_all_CLwgt [w=SGY_size_all_CLwgt] if samp_panelB==1, cluster(sch_cohort) a(sch_yr)
  estimates store pBc1
  areg d_score_l_all_CLwgt dva_type?_all_CLwgt [w=SGY_size_all_CLwgt] if samp_panelB==1, cluster(sch_cohort) a(sch_yr)
  test dva_type0_all_CLwgt=dva_type1_all_CLwgt=dva_type2_all_CLwgt=dva_type3_all_CLwgt=dva_type4_all_CLwgt=dva_type5_all_CLwgt=dva_type6_all_CLwgt
  local pequal=r(p)
  testparm dva_type?_all_CLwgt
  local p0=r(p)
  eststo pBc2, addscalars(p0 `p0' pequal `pequal')
 * Cols 3-4: end of year score
  areg d_score_all_CLwgt dva_all_CLwgt [w=SGY_size_all_CLwgt] if samp_panelB==1, cluster(sch_cohort) a(sch_yr)
  estimates store pBc3
  areg d_score_all_CLwgt dva_type?_all_CLwgt [w=SGY_size_all_CLwgt] if samp_panelB==1, cluster(sch_cohort) a(sch_yr)
  test dva_type0_all_CLwgt=dva_type1_all_CLwgt=dva_type2_all_CLwgt=dva_type3_all_CLwgt=dva_type4_all_CLwgt=dva_type5_all_CLwgt=dva_type6_all_CLwgt
  local pequal=r(p)
  testparm dva_type?_all_CLwgt
  local p0=r(p)
  eststo pBc4, addscalars(p0 `p0' pequal `pequal')


esttab p?c?, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars scalars(p0 pequal)

esttab p?c? using `thisdir'/`dofile'.txt, replace ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars scalars(p0 pequal)

 
 if `doasproject'==1 {
 	 project, creates(`thisdir'/`dofile'.txt)
 }
