*preparequasi.do
*By Jesse Rothstein
*7/2/15
*Based on "makequasi_indvar.do" and "makequasi_depvar.do", dated 7/16/14
* but edited more recently
*
*This program aggregates a number of measures to the school-grade-year-subject
*level. Variables are:
* 1) End-of-year scores (A*)
* 2) Predicted scores (XB)
* 3) Residual scores (A)
* 4) Gain scores (A*-LA*)
* 5) Prior year scores (LA)
* 6) Teacher VA predictions (leave-one-out, leave-2-out, etc.)
*
* Classrooms are weighted using CFR's variable and using the full class
* size (including students with missing residual scores).
*
* At the end, I merge to the files created by "basicreplicationA"
* to ensure that the appropriate variables duplicate what is created by CFR's 
* version.
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "movetypes_quasi"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local scratch "`pdir'/scratch"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`pdir'/scratch/extension/classlevel.dta)
 	project, uses(`pdir'/scratch/extension/movetypes.dta)
 	project, uses(`pdir'/scratch/extension/preparequasi.dta)
}

 use `pdir'/scratch/extension/classlevel.dta, replace
 merge 1:1 teacher math year using `pdir'/scratch/extension/imputations, assert(3) nogen
 merge 1:1 teacher math year using `pdir'/scratch/extension/movetypes, assert(3) nogen
 *assert score_r==. if _merge==1
 *drop _merge
 
 *Make TV measures that distinguish different components of Delta Q
  forvalues m=0/6 {
  	gen tv_l`m'=tv_2yr_l*(movetype_l==`m')
  	gen tv_f`m'=tv_2yr_f*(movetype_f==`m')
  }
 *Make a TV measure that excludes followers
  gen tv_2yr_l_nofollowers=tv_2yr_l if follower!=1
  gen tv_2yr_f_nofollowers=tv_2yr_f if follower!=1
  gen tv_3yr_l_nofollowers=tv_3yr_l if follower!=1
  gen tv_3yr_f_nofollowers=tv_3yr_f if follower!=1
 *Make a TV measure that assigns zero to followers (to use as an instrument)
  gen tv_2yr_l_follower0=tv_2yr_l*(follower!=1)
  gen tv_2yr_f_follower0=tv_2yr_f*(follower!=1)
  gen tv_3yr_l_follower0=tv_3yr_l*(follower!=1)
  gen tv_3yr_f_follower0=tv_3yr_f*(follower!=1)
  *And yet another TV measure that uses the mean VA among all non-followers at the school as the imputation for followers.
   egen sm=group(sch math)
   areg score_r [aw=CLass_size_alt] if follower~=1, a(sm)
   predict sklmean0, d
   bys sm: egen sklmean=mean(sklmean0)
   drop sklmean0
   gen imputefollower=.
   forvalues m=0/1 {
   	 reg score_r sklmean if math==`m' [aw=CLass_size_alt]
   	 predict imputefollower`m', xb
   	 replace imputefollower=imputefollower`m' if math==`m'
   	 drop imputefollower`m'
   }
  gen tv_2yr_l_followerskl=tv_2yr_l if follower!=1
  replace tv_2yr_l_followerskl=imputefollower if follower==1
  gen tv_2yr_f_followerskl=tv_2yr_f if follower!=1
  replace tv_2yr_f_followerskl=imputefollower if follower==1
   
**We are going to aggregate to the S-G-M-Y level twice -- using CFR main weights and using all classrooms
   tempfile classdata sgym_tv sgym_all
   save `classdata'
   *First: VA classes, CLass_size 
    use `classdata'
    collapse (mean) tv_l? tv_f? tv_?yr_?_nofollowers tv_?yr_?_follower0 tv_?yr_?_followerskl [aw=tvsamp_CLass_size_cfr], by(sch grade year math)
    rename tv_2yr_?_nofollowers va_?_nofollowers_tv_CLwgt
    rename tv_3yr_?_nofollowers va3_?_nofollowers_tv_CLwgt
    rename tv_2yr_?_follower0 va_?_follower0_tv_CLwgt
    rename tv_3yr_?_follower0 va3_?_follower0_tv_CLwgt
    rename tv_2yr_?_followerskl va_?_followerskl_tv_CLwgt
    rename tv* va*_tv_CLwgt
    save `sgym_tv'

   *Second: All classes, using CFRs CLass_size
    use `classdata'
    collapse (mean) tv_l? tv_f? tv_?yr_?_nofollowers tv_?yr_?_follower0 tv_?yr_?_followerskl [aw=CLass_size_cfr], by(sch grade year math)
    rename tv_2yr_?_nofollowers va_?_nofollowers_all_CLwgt
    rename tv_3yr_?_nofollowers va3_?_nofollowers_all_CLwgt
    rename tv_2yr_?_follower0 va_?_follower0_all_CLwgt
    rename tv_3yr_?_follower0 va3_?_follower0_all_CLwgt
    rename tv_2yr_?_followerskl va_?_followerskl_all_CLwgt
    rename tv* va*_all_CLwgt
    save `sgym_all'

   *Pull them all together
    use `sgym_tv'
    merge 1:1 sch grade year math using `sgym_all'
    drop _merge

  egen sgm=group(sch grade math)
  sort sgm year
  isid sgm year
  xtset sgm year, yearly
  foreach v in all_CLwgt tv_CLwgt {
  	forvalues m=0/6 {
  		by sgm: gen dva_type`m'_`v'=va_l`m'_`v'-L.va_f`m'_`v'
  	}
  	egen dva_alltypes_`v'=rsum(dva_type?_`v')
  	gen dva_nofollowers_`v'=va_l_nofollowers_`v'-L.va_f_nofollowers_`v'
  	gen dva3_nofollowers_`v'=va3_l_nofollowers_`v'-L.va3_f_nofollowers_`v'
  	gen dva_follower0_`v'=va_l_follower0_`v'-L.va_f_follower0_`v'
  	gen dva3_follower0_`v'=va3_l_follower0_`v'-L.va3_f_follower0_`v'
  	gen dva_followerskl_`v'=va_l_followerskl_`v'-L.va_f_followerskl_`v'
  }
  drop sgm

  keep year sch math grade dva* va_??_all_CLwgt va_??_tv_CLwgt


 *Check that things aggregate right
  merge 1:1 sch grade year math using `pdir'/scratch/extension/preparequasi, assert(3) nogen keepusing(dva_tv_CLwgt dva_all_CLwgt)
  foreach v in tv all {
  	assert abs(dva_`v'_CLwgt-dva_alltypes_`v'_CLwgt)<1e-7 if !missing(dva_`v'_CLwgt) & !missing(dva_alltypes_`v'_CLwgt)
  	assert missing(dva_`v'_CLwgt) if missing(dva_alltypes_`v'_CLwgt)
  	assert missing(dva_alltypes_`v'_CLwgt) | dva_alltypes_`v'_CLwgt==0 if missing(dva_`v'_CLwgt)
  	replace dva_alltypes_`v'_CLwgt=. if missing(dva_`v'_CLwgt)
  	forvalues m=0/6 {
  		replace va_l`m'_`v'_CLwgt=. if  missing(dva_`v'_CLwgt)
  		replace va_f`m'_`v'_CLwgt=. if  missing(dva_`v'_CLwgt)
  	}
  	drop dva_`v'_CLwgt
  }

  save `pdir'/scratch/extension/`dofile'.dta, replace
  if `doasproject'==1 project, creates("`pdir'/scratch/extension/`dofile'.dta")
     
