*preparequasi.do
*By Jesse Rothstein
*7/2/15
*Based on "makequasi_indvar.do" and "makequasi_depvar.do", dated 7/16/14
* but edited more recently
*
*This program aggregates a number of measures to the school-grade-year-subject
*level. Variables are:
* 1) End-of-year scores (A*)
* 2) Predicted scores (XB)
* 3) Residual scores (A)
* 4) Gain scores (A*-LA*)
* 5) Prior year scores (LA)
* 6) Teacher VA predictions (leave-one-out, leave-2-out, etc.)
*
* Classrooms are weighted using CFR's variable and using the full class
* size (including students with missing residual scores).
*
* At the end, I merge to the files created by "basicreplicationA"
* to ensure that the appropriate variables duplicate what is created by CFR's 
* version.
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "preparequasi"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local scratch "`pdir'/scratch"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`pdir'/scratch/extension/classlevel.dta)
 	project, uses(`pdir'/scratch/extension/imputations.dta)
  project, uses(`pdir'/scratch/replication/basicreplication.dta)
  project, uses(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only.dta)
  project, uses(`cfrdat'/SCHD_sch_gr_year_collapse.dta)
}

 use `pdir'/scratch/extension/classlevel.dta, replace
 merge 1:1 sch math teacher year using `pdir'/scratch/extension/imputations, assert(3) nogen
 *assert score_r==. if _merge==1
 *drop _merge
 
   
**We are going to aggregate to the S-G-M-Y level several times using different weights
   tempfile classdata sgymA sgymB sgymC sgymD sgymE sgym
   save `classdata'
   local scorelist "score score_l score_p score_r score_g score_p_pared score_p_demog score_f1 score_f2 score_f3 score_l2 score_l3"
   local valist "tv tv_2yr_f tv_2yr_l tv_3yr_f tv_3yr_l tv_4yr_f tv_4yr_l tv_5yr_f tv_5yr_l tv_future_f tv_future_l"
   local vaimplist "tv_2yr_l_imp0 tv_2yr_l_impmiss tv_2yr_l_impskl tv_2yr_l_impsklmiss tv_2yr_f_imp0 tv_2yr_f_impmiss tv_2yr_f_impskl tv_2yr_f_impsklmiss"
   local missvalist "miss_tv miss_tv_2yr_f miss_tv_2yr_l"

   *All classes, with or without TV, using count of students with scores
    collapse (mean) `scorelist' `valist' `missvalist' `vaimplist' ///
            (rawsum) SGY_size_all_CL2wgt=CLass_size_alt [aw=CLass_size_alt], by(sch grade year math)
    rename score* score*_all_CL2wgt
    rename tv* va*_all_CL2wgt
    rename miss_* frmiss_*_all_CL2wgt
    save `sgymA'
   *Second: All classes, using CFRs CLass_size
    use `classdata'
    collapse (mean) `scorelist' `valist' `missvalist' `vaimplist' ///
            (rawsum) SGY_size_all_CLwgt=CLass_size_cfr [aw=CLass_size_cfr], by(sch grade year math)
    rename score* score*_all_CLwgt
    rename tv* va*_all_CLwgt
    rename miss_* frmiss_*_all_CLwgt
    save `sgymB'
   *Third: VA classes, alternate class size
    use `classdata'
    collapse (mean) `scorelist' `valist' `missvalist' ///
            (rawsum) SGY_size_tv_CL2wgt=tvsamp_CLass_size_alt [aw=tvsamp_CLass_size_alt], by(sch grade year math)
    rename score* score*_tv_CL2wgt
    rename tv* va*_tv_CL2wgt
    rename miss_* frmiss_*_tv_CL2wgt
    save `sgymC'
   *Fourth: VA classes, CLass_size -- should match CFR's mean_score
   *NOTE: This includes classes that have a leave-one-out VA score but are not
   *in the quasiexperiment independent variable because they don't have leave-two-
   *out VA scores. I do this to follow CFR, even though it seems inconsistent
   *with the logic of their approach.
    use `classdata'
    collapse (mean) `scorelist' `valist' `missvalist' ///
            (rawsum) SGY_size_tv_CLwgt=tvsamp_CLass_size_cfr [aw=tvsamp_CLass_size_cfr], by(sch grade year math)
    rename score* score*_tv_CLwgt
    rename tv* va*_tv_CLwgt
    rename miss_* frmiss_*_tv_CLwgt
    save `sgymD'
   *Finally: Leave-2-out VA classes, CLass_size -- this implements
   *what I thought CFR did from reading their paper, before examining
   *their code.
    use `classdata'
    gen have2_l=(tv_2yr_l<.)
    gen have2_f=(tv_2yr_f<.)
    foreach v of varlist `scorelist' `valist' `missvalist' {
    	gen l`v'=`v' if have2_l==1
    	gen f`v'=`v' if have2_f==1
    	local llist "`llist' l`v'"
    	local flist "`flist' f`v'"
    }
    gen lwgt=CLass_size_cfr*have2_l
    gen fwgt=CLass_size_cfr*have2_f
    collapse (mean) `llist' `flist'  ///
            (rawsum) SGY_size_tv2l_CLwgt=lwgt SGY_size_tv2f_CLwgt=fwgt  [aw=CLass_size_cfr], by(sch grade year math)
    rename lscore* score*_tv2l_CLwgt
    rename fscore* score*_tv2f_CLwgt
    rename ltv* va*_tv2l_CLwgt
    rename lmiss_* frmiss_*_tv2l_CLwgt
    rename ftv* va*_tv2f_CLwgt
    rename fmiss_* frmiss_*_tv2f_CLwgt
    save `sgymE'
   *Pull them all together
    use `sgymA'
    merge 1:1 sch grade year math using `sgymB'
    drop _merge
    merge 1:1 sch grade year math using `sgymC'
    drop _merge
    merge 1:1 sch grade year math using `sgymD'
    drop _merge
    merge 1:1 sch grade year math using `sgymE'
    drop _merge
    save `sgym'

  egen sgm=group(sch grade math)
  sort sgm year
  isid sgm year
  xtset sgm year, yearly
  foreach v in all_CL2wgt all_CLwgt tv_CL2wgt tv_CLwgt {
    foreach s in `scorelist' {
      by sgm: gen d_`s'_`v' = `s'_`v' - L.`s'_`v'
    }
   	by sgm: gen dva_`v'=va_2yr_l_`v'-L.va_2yr_f_`v'
   	by sgm: gen dva3_`v'=va_3yr_l_`v'-L.va_3yr_f_`v'
   	by sgm: gen dva4_`v'=va_4yr_l_`v'-L.va_4yr_f_`v'
   	by sgm: gen dva5_`v'=va_5yr_l_`v'-L.va_5yr_f_`v'
   	by sgm: gen dvafuture_`v'=va_future_l_`v'-L.va_future_f_`v'
   	by sgm: gen frmiss_dva_`v'=(va_2yr_l_`v'*SGY_size_`v' + L.va_2yr_f_`v'*L.SGY_size_`v') ///
   	                       / (SGY_size_`v' + L.SGY_size_`v')
  }
  foreach v in CL2wgt CLwgt {
  	foreach imp in 0 miss skl sklmiss {
    	by sgm: gen dva_imp`imp'_`v'=va_2yr_l_imp`imp'_all_`v'-L.va_2yr_f_imp`imp'_all_`v'
    }
  }
  
 foreach s in `scorelist' {
   by sgm: gen d_`s'_tv2_CLwgt = `s'_tv2l_CLwgt - L.`s'_tv2f_CLwgt
 }
 by sgm: gen dva_tv2_CLwgt=va_2yr_l_tv2l_CLwgt-L.va_2yr_f_tv2f_CLwgt
 by sgm: gen dva3_tv2_CLwgt=va_3yr_l_tv2l_CLwgt-L.va_3yr_f_tv2f_CLwgt
 by sgm: gen dva4_tv2_CLwgt=va_4yr_l_tv2l_CLwgt-L.va_4yr_f_tv2f_CLwgt
 by sgm: gen dva5_tv2_CLwgt=va_5yr_l_tv2l_CLwgt-L.va_5yr_f_tv2f_CLwgt
 by sgm: gen dvafuture_tv2_CLwgt=va_future_l_tv2l_CLwgt-L.va_future_f_tv2f_CLwgt
 by sgm: gen frmiss_dva_tv2_CLwgt=(va_2yr_l_tv2l_CLwgt*SGY_size_tv2l_CLwgt + L.va_2yr_f_tv2f_CLwgt*L.SGY_size_tv2f_CLwgt) ///
   	                       / (SGY_size_tv2l_CLwgt + L.SGY_size_tv2f_CLwgt)

 drop sgm

  keep year sch math grade d_score_* dva* frmiss* score_* va_* SGY_size_*

  egen sgm=group(sch grade math)
  gen cohort=year-grade
  egen sch_cohort=group(sch cohort)
  egen sch_yr=group(sch year)

  save `pdir'/scratch/extension/`dofile'.dta, replace

 *Check that the imputations worked, in the sense that two different ways of reaching the same place agree
  assert dva_all_CLwgt==dva_imp0_CLwgt
  assert dva_all_CL2wgt==dva_imp0_CL2wgt
  
 *Now check for successful replication by comparing to my replication of the CFR version
  merge 1:1 sch grade year math using `pdir'/scratch/replication/basicreplication, ///
    keepusing(sch grade year math d_mean_score d_mean_score_T5 d_pred_score_pared d_tv_sgm_1 d_tv_sgm_1_T5 SGYsize SGYsize_T5) nogen
    
  *egen sgm=group(sch grade math)
  *Check that we successfully replicated the CFR version
   *Start with their main change-in-score estimate
    assert d_score_tv_CLwgt==d_mean_score
   *Now check for their Table 5, Column 2 change-in-score estimate
    assert abs(d_score_all_CL2wgt-d_mean_score_T5)<1e-6 if d_score_all_CL2wgt<. | d_mean_score_T5<.
    assert missing(d_score_all_CL2wgt)==missing(d_mean_score_T5)
   *And the predicted score given parental education
    assert d_score_p_pared_tv_CLwgt==d_pred_score_pared
  *And the VA measures
   compare dva_tv_CLwgt d_tv_sgm_1
	 corr dva_tv_CLwgt  d_tv_sgm_1
	 assert abs(dva_tv_CLwgt -d_tv_sgm_1)<1e-6 if dva_tv_CLwgt <. & d_tv_sgm_1<.
	 assert missing(dva_tv_CLwgt )==missing(d_tv_sgm_1)
  
	 compare dva_all_CLwgt d_tv_sgm_1_T5
	 corr dva_all_CLwgt d_tv_sgm_1_T5
	 assert abs(dva_all_CLwgt-d_tv_sgm_1_T5)<1e-6 if dva_all_CLwgt<. & d_tv_sgm_1_T5<.
	 assert missing(dva_all_CLwgt)==missing(d_tv_sgm_1_T5)

   assert SGY_size_tv_CLwgt==SGYsize
   assert SGY_size_all_CLwgt==SGYsize_T5

 *And check again that I match the versions created by CFR's programs
  use sch grade year math SGYsize mean_score using `cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only, clear
  rename SGYsize SGYsize_T4
  rename mean_score mean_score_T4
  tempfile origT4
  save `origT4'
  use sch grade year math SGYsize mean_score using `cfrdat'/SCHD_sch_gr_year_collapse
  rename SGYsize SGYsize_T5
  rename mean_score mean_score_T5
  merge 1:1 sch grade year math using `origT4'
  drop _merge
  merge 1:1 sch grade year math using `pdir'/scratch/extension/`dofile'.dta
 *Compare
  assert SGY_size_tv_CLwgt==SGYsize_T4
  assert SGY_size_all_CLwgt==SGYsize_T5
  assert score_tv_CLwgt==mean_score_T4
  *Note that CFR use different class sizes for mean scores than for their weight variables
   compare score_all_CL2wgt mean_score_T5
   assert abs(score_all_CL2wgt-mean_score_T5)<1e-6 if score_all_CL2wgt<. | mean_score_T5<.
   assert missing(score_all_CL2wgt)==missing(mean_score_T5)
  
  if `doasproject'==1 project, creates("`pdir'/scratch/extension/`dofile'.dta")
     
