
*table3.do
*By Jesse Rothstein
*7/1/15
*
*This program estimates the basic CFR regressions, controlling in various
*ways for changes in student characteristics
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "jun2015_table3"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`pdir'/scratch/extension/preparequasi.dta)
}


 use `pdir'/scratch/extension/preparequasi
 
*Regressions without imputations
* Col 1 - same as T1, C2
  areg d_score_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt], cluster(sch_cohort) a(sch_yr)
  gen samp_noimpute=e(sample)
  estimates store Ac1
* Col 2 - control for lagged score
  areg d_score_tv_CLwgt dva_tv_CLwgt d_score_l_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_noimpute==1, cluster(sch_cohort) a(sch_yr)
  estimates store Ac2
* Col 3 - control for lagged and predicted scores
  *areg d_score_tv_CLwgt dva_tv_CLwgt d_score_l_tv_CLwgt d_score_p_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_noimpute==1, cluster(sch_cohort) a(sch_yr)
  *estimates store Ac3
* Col 4 - dependent variable is residuals
  areg d_score_r_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_noimpute==1, cluster(sch_cohort) a(sch_yr)
  estimates store Ac4
* Col 5 - dep var is residuals, with controls for lagged and predicted
  *areg d_score_r_tv_CLwgt dva_tv_CLwgt d_score_l_tv_CLwgt d_score_p_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_noimpute==1, cluster(sch_cohort) a(sch_yr)
  *estimates store Ac5
* Col 6 - dep var is gain score
  areg d_score_g_tv_CLwgt dva_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_noimpute==1, cluster(sch_cohort) a(sch_yr)
  estimates store Ac6
* Col 7 - dep var is gain score, with controls
  *areg d_score_g_tv_CLwgt dva_tv_CLwgt d_score_l_tv_CLwgt d_score_p_tv_CLwgt [w=SGY_size_tv_CLwgt] if samp_noimpute==1, cluster(sch_cohort) a(sch_yr)
  *estimates store Ac7

*Regressions imputing 0 if VA is missing

* Col 1 - same as T1, C2
  areg d_score_all_CL2wgt dva_all_CLwgt [w=SGY_size_all_CLwgt], cluster(sch_cohort) a(sch_yr)
  gen samp_impute=e(sample)
  estimates store Bc1
* Col 2 - control for lagged score
  areg d_score_all_CL2wgt dva_all_CLwgt d_score_l_all_CL2wgt [w=SGY_size_all_CLwgt] if samp_impute==1, cluster(sch_cohort) a(sch_yr)
  estimates store Bc2
* Col 3 - control for lagged and predicted scores
  *areg d_score_all_CL2wgt dva_all_CLwgt d_score_l_all_CL2wgt d_score_p_all_CL2wgt [w=SGY_size_all_CLwgt] if samp_impute==1, cluster(sch_cohort) a(sch_yr)
  *estimates store Bc3
* Col 4 - dependent variable is residuals
  areg d_score_r_all_CL2wgt dva_all_CLwgt [w=SGY_size_all_CLwgt] if samp_impute==1, cluster(sch_cohort) a(sch_yr)
  estimates store Bc4
* Col 5 - dep var is residuals, with controls for lagged and predicted
  *areg d_score_r_all_CL2wgt dva_all_CLwgt d_score_l_all_CL2wgt d_score_p_all_CL2wgt [w=SGY_size_all_CLwgt] if samp_impute==1, cluster(sch_cohort) a(sch_yr)
  *estimates store Bc5
* Col 6 - dep var is gain score
  areg d_score_g_all_CL2wgt dva_all_CLwgt [w=SGY_size_all_CLwgt] if samp_impute==1, cluster(sch_cohort) a(sch_yr)
  estimates store Bc6
* Col 7 - dep var is gain score, with controls
  *areg d_score_g_all_CL2wgt dva_all_CLwgt d_score_l_all_CL2wgt d_score_p_all_CL2wgt [w=SGY_size_all_CLwgt] if samp_impute==1, cluster(sch_cohort) a(sch_yr)
  *estimates store Bc7
  
esttab Ac?, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab Bc?, ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars

esttab Ac? Bc? using `thisdir'/`dofile'.txt, replace ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars
esttab Ac? Bc? using `thisdir'/`dofile'.csv, replace ///
   cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars noparentheses

 if `doasproject'==1 {
 	 project, creates(`thisdir'/`dofile'.txt)
 	 project, creates(`thisdir'/`dofile'.csv)
 }
