
*vingtileplots.do
*By Jesse Rothstein
*8/1/14
*
*This program makes bin-scatter plots of CFR's main specification,
*the falsification test, and an adjusted version of their main 
*specification.
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "vingtileplots"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/extension"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`pdir'/scratch/extension/preparequasi.dta)
 	project, relies_on(`pdir'/cfr/cfrprograms/binscatter_v5_10.ado)
}


use `pdir'/scratch/extension/preparequasi
notes drop _dta in 1/l
discard 
run `pdir'/cfr/cfrprograms/binscatter_v5_10.ado

*Run the regressions by hand, on the microdata, to get the SEs right
 areg d_score_tv_CLwgt dva_tv_CLwgt [aw=SGY_size_tv_CLwgt], absorb(sch_yr ) cl(sch_cohort)
 local a1=_b[_cons]
 local b1=_b[dva_tv_CLwgt]
 local sea1=_se[_cons]
 local seb1=_se[dva_tv_CLwgt]
 areg d_score_l_tv_CLwgt dva_tv_CLwgt [aw=SGY_size_tv_CLwgt], absorb(sch_yr ) cl(sch_cohort) 
local a2=_b[_cons]
local b2=_b[dva_tv_CLwgt]
local sea2=_se[_cons]
local seb2=_se[dva_tv_CLwgt]
gen samp2=e(sample)
 areg d_score_g_tv_CLwgt dva_tv_CLwgt [aw=SGY_size_tv_CLwgt], absorb(sch_yr ) cl(sch_cohort)
local a3=_b[_cons]
local b3=_b[dva_tv_CLwgt]
local sea3=_se[_cons]
local seb3=_se[dva_tv_CLwgt]

*Because it comes up in the text and in presentations, re-run the lag score specification without
*the first and last points
 _pctile dva_tv_CLwgt if samp2==1 [aw=SGY_size_tv_CLwgt], p(5 95)
 gen samp2_mid90=samp2*(dva_tv_CLwgt>=r(r1))*(dva_tv_CLwgt<=r(r2))
 areg d_score_l_tv_CLwgt dva_tv_CLwgt if samp2_mid90==1 [aw=SGY_size_tv_CLwgt], absorb(sch_yr ) cl(sch_cohort) 

tempname vplotsa vplotsb vplotsc

binscatter  d_score_tv_CLwgt dva_tv_CLwgt [aw=SGY_size_tv_CLwgt], absorb(sch_yr ) ///
	savedata(`dofile'_a) nodraw noaddmean

binscatter  d_score_l_tv_CLwgt dva_tv_CLwgt [aw=SGY_size_tv_CLwgt], absorb(sch_yr) ///
	savedata(`dofile'_b) nodraw noaddmean


*reg d_score_va_CLwgt d_l_score_va_CLwgt math [aw=replicweight_T4]
*predict r_d_score_va_CLwgt, r

binscatter d_score_g_tv_CLwgt dva_tv_CLwgt [aw=SGY_size_tv_CLwgt], absorb(sch_yr) ///
	savedata(`dofile'_c) nodraw noaddmean

use `dofile'_a, clear
rename __000004 y
rename __000005 x
*Parms for text to add;
 local slope : di %5.3f `b1'
 local cons  : di %5.3f `a1'
 local seslope : di %5.3f `seb1'
 local secons : di %5.3f `sea1'
 
twoway (scatter y x, mcolor(navy) lcolor(navy) ) ///
       (function `b1'*x, range(x) lcolor(navy))    ///
       (function x, range(x) lcolor(black) lpattern(shortdash)) ///
       , graphregion(fcolor(white)) legend(off) ///
         title("End of Year Scores", size(medium)) ///
         xtitle("Change in avg. teacher predicted value-added") ///
         ytitle("Change in avg. end of year score") ///
         xlabel(-0.1(0.1)0.1) ylabel(-0.1(0.1)0.1, angle(0) nogrid) ///
      	text(-0.05 0	"{&Delta} Score = {&alpha}{subscript:st} +  `slope' * {&Delta} VA" ///
      	      "                           (`seslope')" ///
         		, place(e) just(left) size(medium)) ///
         saving(`dofile'_a.gph, replace) nodraw

use `dofile'_b, clear
rename __000004 y
rename __000005 x
*Parms for text to add;
 local slope : di %5.3f `b2'
 local cons  : di %5.3f `a2'
 local seslope : di %5.3f `seb2'
 local secons : di %5.3f `sea2'
twoway (scatter y x, mcolor(navy) lcolor(navy) ) ///
       (function `b2'*x, range(x) lcolor(navy))    ///
       , yline(0, lcolor(black) lpattern(shortdash)) ///
         graphregion(fcolor(white)) legend(off) ///
         title("Prior Year Scores", size(medium)) ///
         xtitle("Change in avg. teacher predicted value-added") ///
         ytitle("Change in avg. prior year score") ///
         xlabel(-0.1(0.1)0.1) ylabel(-0.1(0.1)0.1, angle(0) nogrid)  ///
      	text(-0.05 0	"{&Delta} Score = {&alpha}{subscript:st} +  `slope' * {&Delta} VA" ///
      	      "                           (`seslope')" ///
         		, place(e) just(left) size(medium)) ///
         saving(`dofile'_b.gph, replace) nodraw
         
use `dofile'_c, clear
rename __000004 y
rename __000005 x
*Parms for text to add;
 local slope : di %5.3f `b3'
 local cons  : di %5.3f `a3'
 local seslope : di %5.3f `seb3'
 local secons : di %5.3f `sea3'
twoway (scatter y x, mcolor(navy) lcolor(navy) ) ///
       (function `b3'*x, range(x) lcolor(navy))    ///
       (function x, range(x) lcolor(black) lpattern(shortdash)) ///
       , graphregion(fcolor(white)) legend(off) ///
         title("Change in Score Growth", size(medium)) ///
         xtitle("Change in avg. teacher predicted value-added") ///
         ytitle("Change in avg. end of year score" "less change in avg. prior year score") ///
         xlabel(-0.1(0.1)0.1) ylabel(-0.1(0.1)0.1, angle(0) nogrid)  ///
      	text(-0.05 0	"{&Delta} Score = {&alpha}{subscript:st} +  `slope' * {&Delta} VA" ///
      	      "                           (`seslope')" ///
         		, place(e) just(left) size(medium)) ///
         saving(`dofile'_c.gph, replace) nodraw

graph use `dofile'_a.gph
*graph export vingtileplots_a.pdf
graph export `dofile'_a.eps, replace
graph use `dofile'_b.gph
*graph export vingtileplots_b.pdf
graph export `dofile'_b.eps, replace
graph use `dofile'_c.gph
*graph export vingtileplots_c.pdf
graph export `dofile'_c.eps, replace

if `doasproject'==1 {
	project, creates(`dofile'_a.dta)
	project, creates(`dofile'_b.dta)
	project, creates(`dofile'_c.dta)
	project, creates(`dofile'_a.gph)
	project, creates(`dofile'_b.gph)
	project, creates(`dofile'_c.gph)
	project, creates(`dofile'_a.eps)
	project, creates(`dofile'_b.eps)
	project, creates(`dofile'_c.eps)
}
