*makesamp_observational.do
*
*Make a class-level (teacher-(subject)-year-level) sample for the long-run outcome analysis.

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "makesamp_observational"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/longrun"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`cfrdat'/analysis.dta)
 	project, uses(`cfrdat'/longterm_crossclass.dta)
}

local controls CL* SG* SY* YEAR* GRDE*
set more off

*Start by residualizing long-run variables against VA controls within teachers
use `cfrdat'/analysis
 *Now do CFR-style class-level residualization;
  foreach v in grad collbound coll4bound gpa rank {
  	gen double lr_`v'_rcfr=.
  	gen double lr_`v'_rl2=.
  	forvalues m=0/1 {
  		tempvar resid`m'`v'
  		areg lr_`v' `controls' [w=lr_`v'_count] if math==`m' & tv_insample==1, absorb(teacher)
  		predict double `resid`m'`v'', dresiduals
  		replace lr_`v'_rcfr=`resid`m'`v'' if e(sample)
  		capture drop `resid`m'`v''

  		areg lr_`v' `controls' mean_l2_score [w=lr_`v'_count] if math==`m' & tv_insample==1, absorb(teacher)
  		predict double `resid`m'`v'', dresiduals
  		replace lr_`v'_rl2=`resid`m'`v'' if e(sample)
  		capture drop `resid`m'`v''
  	}
  }

*Now add back CFRs residuals and check that they align
 merge 1:1 teacher year math using `cfrdat'/longterm_crossclass, keepusing(*_r_va *_r_val2)
 drop _merge
 
 foreach v in grad collbound coll4bound gpa rank {
 	 di "Starting comparison of `v'"
 	 compare lr_`v'_rcfr lr_`v'_r_va
 	 cap assert lr_`v'_rcfr==lr_`v'_r_va
 	 if _rc!=0 {
 	 	 assert abs(lr_`v'_rcfr-lr_`v'_r_va)<1e-6 if !missing(lr_`v'_rcfr) & !missing(lr_`v'_r_va)
 	 	 assert missing(lr_`v'_rcfr)==missing(lr_`v'_r_va)
 	 }

 	 cap assert lr_`v'_rl2==lr_`v'_r_val2
 	 if _rc!=0 {
 	 	 assert abs(lr_`v'_rl2-lr_`v'_r_val2)<1e-6 if !missing(lr_`v'_rl2) & !missing(lr_`v'_r_val2)
 	 	 assert missing(lr_`v'_rl2)==missing(lr_`v'_r_val2)
 	 }

 	 di "Comparison passed for `v'"
 }

local controls "CL* SG* SY* YEAR* GRDE*"
 
 save `pdir'/scratch/longrun/`dofile'.dta, replace
 
 if `doasproject'==1 project, creates(`pdir'/scratch/longrun/`dofile'.dta)
 
