*makesamp_quasi.do
*
*Make a school-grade-year-math-level sample for the long-run quasiexperimental analysis.

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "makesamp_quasi"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/longrun"
local cfrdat "`pdir'/scratch/cfrdata"
local cfrdir "`pdir'/cfr"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
  project, uses(`cfrdat'/tfx/tfx_tym.dta)
  project, uses(`cfrdat'/tfx/sd_tfx.dta)
  project, uses(`cfrdat'/teacher_school_weights.dta)
  project, relies_on("`cfrdir'/cfrprograms/fastxtile.ado")
}
 run `cfrdir'/cfrprograms/fastxtile.ado
 
 #delimit;
 
*Load the raw sample of long-run outcomes and collapse to the school-grade-year-math level;
 use teacher year math tv_2yr_? using `cfrdat'/tfx/tfx_tym;
 merge 1:1 teacher year math using `cfrdat'/teacher_school_weights, keepusing(sch grade teach_wt n_students) assert(2 3);
 *keep if _merge==3;
 drop _merge;

		*Trim VA outliers (requires middle);
		foreach var of varlist tv_2yr_l tv_2yr_f {;
			g int percent_tv=.;
			forvalues math=0/1 {;
				fastxtile percent_tv_temp=`var' if math==`math' [w=n_students], nq(100);
				replace percent_tv=percent_tv_temp if math==`math';
				drop percent_tv_temp;
			};
			* Perform trimming;
			replace `var' = . if percent_tv>99;
			drop percent_tv;
		};
 merge m:1 math using `cfrdat'/tfx/sd_tfx, assert(3) nogen;
 replace tv_2yr_f=tv_2yr_f/sd_tfx;
 replace tv_2yr_l=tv_2yr_l/sd_tfx;
 *Make means of the TV measures;
  sort sch grade math year teacher;
  *NOTE: This is CFRs code -- it in effect keeps teachers with missing VA (including those who were trimmed),
  *setting them to zero. This is because it assumes that teach_wt adds to 1 in each cell. Teachers with
  *missing VA are excluded from the numerator but included in the denominator;
	foreach vary of varlist tv_2yr_l tv_2yr_f  {;
	   g temp = `vary'*teach_wt;
	   by sch grade math year : egen mean_`vary' = sum(temp);
	   drop temp;
	};
	* Collapse to school-grade-year level;
	by sch grade math year : keep if _n==1;
  keep sch grade math year mean_tv_2yr_? ;

	****Merge on school-grade-year collapse;
	merge 1:1 sch grade year math using `cfrdat'/NOTIRS_SCHD_sch_gr_year_collapse;
  

*Make first-difference at sgm-y level;
	egen sgm_id = group(sch grade math);
	tsset sgm_id year;
	sort sgm_id year;
	by sgm_id (year): g d_tv_sgm_1 = mean_tv_2yr_l-l.mean_tv_2yr_f;
  foreach v of varlist lr_* {;
    by sgm_id (year): gen d_`v'=`v'-L.`v';
  }; 
 by sgm_id (year): gen d_l_score=mean_l_score-L.mean_l_score;
 keep sch grade math year lr_* d_lr_* mean_tv_2yr_? d_tv_sgm_1 d_l_score;
 gen cohort=year-grade;
 egen sch_cohort=group(sch cohort);
 
 compress;
 save `pdir'/scratch/longrun/`dofile'.dta, replace;
 
 if `doasproject'==1 project, creates(`pdir'/scratch/longrun/`dofile'.dta);
 