*observationalregs.do
*
*Regress long-run outcomes on teacher VA:
* - without controls
* - with controls, using CFR method
* - with controls in multiple regression;

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "observationalregs"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/longrun"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
	project, uses(`pdir'/scratch/longrun/makesamp_observational.dta)
}

local controls "CL* SG* SY* YEAR* GRDE*"

#delimit;
estimates clear;
set more off;

*Make teacher-level controls;
 use `pdir'/scratch/longrun/makesamp_observational;
 collapse (mean) `controls' [aw=CLass_size], by(teacher math);
 foreach v of varlist `controls' {;
 	 rename `v' T_`v';
 };
 tempfile tmeans;
 save `tmeans';

use `pdir'/scratch/longrun/makesamp_observational;
merge m:1 teacher math using `tmeans';

*keep if runiform()<0.05;
d `controls';
su `controls';

 *merge m:1 math using `cfrdat'/tfx/sd_tfx, assert(3) nogen keepusing(sd_tfx);
 *table math, contents(mean sd_tfx);
 *gen tv_sd=tv/sd_tfx;
 gen score_r_sd=score_r/sd_tfx;
 *drop sd_tfx;
 
foreach v of varlist lr_grad lr_collbound lr_coll4bound lr_gpa lr_rank {;
  *No controls;
  reg `v'_rcfr tv_sd math [aw=`v'_count] if tv_insample==1, cluster(sch_cohort);
  su `v'_count if e(sample), meanonly;
	eststo `v'_c1, addscalars(Nstudents r(sum));
  
  *No controls, but with twice-lagged scores;
  reg `v'_rl2 tv_sd math [aw=`v'_count] if tv_insample==1, cluster(sch_cohort);
  su `v'_count if e(sample), meanonly;
	eststo `v'_c3, addscalars(Nstudents r(sum));
  
  *Control directly;
  reg `v'_rcfr tv_sd math `controls' [aw=`v'_count] if tv_insample==1, cluster(sch_cohort);
  su `v'_count if e(sample), meanonly;
	eststo `v'_c5, addscalars(Nstudents r(sum));
  
  *Control for teacher means;
  reg `v'_rcfr tv_sd math `controls' T_* [aw=`v'_count] if tv_insample==1, cluster(sch_cohort);
  su `v'_count if e(sample), meanonly;
	eststo `v'_c6, addscalars(Nstudents r(sum));

  *IV regression;
  ivregress 2sls `v'_rcfr math `controls' T_* (score_r_sd=tv_sd) [w=`v'_count] if tv_insample==1, cluster(sch_cohort);
  su `v'_count if e(sample), meanonly;
	eststo `v'_c7, addscalars(Nstudents r(sum));
	
  *IV first stage;
  reg score_r_sd math `controls' T_* tv_sd [w=`v'_count] if tv_insample==1, cluster(sch_cohort);
  su `v'_count if e(sample), meanonly;
	eststo `v'_first, addscalars(Nstudents r(sum));

  local vlist "`vlist' `v'";
};

  foreach v of varlist `vlist' {;
    esttab `v'_c? `v'_first, 
       cells(b(fmt(7)) se(fmt(7))) r2 obslast scalars(Nstudents) 
      keep(tv_sd math score_r_sd);
  };
esttab *_c? using `dofile'.txt, replace 
   cells(b(fmt(7)) se(fmt(7))) r2 obslast scalars(Nstudents) nodepvars
   keep(tv_sd math score_r_sd);
esttab *_c? using `dofile'.csv, replace 
   cells(b(fmt(7)) se(fmt(7))) r2 obslast scalars(Nstudents) nodepvars noparentheses
   keep(tv_sd math score_r_sd);
esttab *_first using `dofile'_firststage.txt, replace 
   cells(b(fmt(7)) se(fmt(7))) r2 obslast scalars(Nstudents) nodepvars
   keep(tv_sd math );
esttab *_first using `dofile'_firststage.csv, replace 
   cells(b(fmt(7)) se(fmt(7))) r2 obslast scalars(Nstudents) nodepvars noparentheses
   keep(tv_sd math );

if `doasproject'==1 {;
	project, creates(`dofile'.txt);
	project, creates(`dofile'_firststage.txt);
	project, creates(`dofile'.csv);
	project, creates(`dofile'_firststage.csv);
};
  
