*quasiregs.do
*
*Implement the quasi-experimental analysis of long-run impacts;

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "quasiregs"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/longrun"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
	project, uses(`pdir'/scratch/longrun/makesamp_quasi.dta)
}

use `pdir'/scratch/longrun/makesamp_quasi
egen sch_yr=group(sch year)

foreach var of varlist lr_grad lr_collbound lr_coll4bound lr_gpa lr_rank {
		
	* Col 1: Baseline
	areg d_`var' d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(year)
  estimates store m1a_`var'
  
  * Col 1B: Baseline, with control for prior year score
	areg d_`var' d_tv_sgm_1 d_l_score [w=`var'_count], cluster(sch_cohort) a(year)
  estimates store m1b_`var'
  
	* Col 2: Add sch*yr fixed effects
	areg d_`var' d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(sch_yr)
	estimates store m2a_`var'

	* Col 2B: Add sch*yr fixed effects, with control for prior year score
	areg d_`var' d_tv_sgm_1 d_l_score [w=`var'_count], cluster(sch_cohort) a(sch_yr)
	estimates store m2b_`var'

  }

*Replication
esttab m?a_*,    cells(b(fmt(7)) se(abs par fmt(7))) obslast
esttab m?a_* using `dofile'_replic.txt, replace cells(b(fmt(7)) se(abs par fmt(7))) obslast
esttab m?a_* using `dofile'_replic.csv, replace cells(b(fmt(7)) se(abs par fmt(7))) obslast noparentheses

*And the full table
esttab m1?_* m2?_*, cells(b(fmt(7)) se(abs par fmt(7))) obslast
esttab m1?_* m2?_* using `dofile'.txt, replace cells(b(fmt(7)) se(abs par fmt(7))) obslast
esttab m1?_* m2?_* using `dofile'.csv, replace cells(b(fmt(7)) se(abs par fmt(7))) obslast noparentheses

if `doasproject'==1 {
	project, creates(`thisdir'/`dofile'_replic.txt)
	project, creates(`thisdir'/`dofile'_replic.csv)
	project, creates(`thisdir'/`dofile'.txt)
	project, creates(`thisdir'/`dofile'.csv)
}
