
version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	global doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  global doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "prepdata_longrun"
	local sig "Not run as part of project!"
	
}

#delimit;
global rawgrads "~/data/nceduc/statafmt/Student/Graduates";

global rawGPA1 "~/data/nceduc/statafmt/Student/GPA";
global rawexit1 "~/data/nceduc/statafmt/Student/School Exit";
global rawEOC1 "~/data/nceduc/statafmt/Student/End of Course";
global rawGPA2 "~/data/nceduc/statafmt/Student/GPA";
global rawexit2 "~/data/nceduc/statafmt/Student/School\ Exit";
global rawEOC2 "~/data/nceduc/statafmt/Student/End\ of\ Course";
local scratchdir "`pdir'/scratch";
global outdir "`scratchdir'/ncdata";
global scratch "`scratchdir'";
clear;
set varabbrev off;
set more off;

***
* Sources:
*
*   GPA data (12th grade)
*     Covers 2005-2010, 2012-13. (Edit 9/25/15: Through 2014)
*     Coverage (of LEAs) low in earlier years.
*     Match rates 95%+ 2007-
*     Has GPA, class rank, HS completion, future plans.
*   Graduates (Graduate Data Verification System)
*     Covers 2009-2013. (Edit 9/25/15: Through 2014).
*     Covers only graduates (diploma and certificate). 
*     Has type of diploma, future plans.
*   Transfer, dropout, and graduation data.
*     Covers 2006-2013. (Edit 9/25/15: Through 2014). 
*     Includes dropouts, not just grads.
*   End-of-Course tests
*     Algebra I is taken 7th-12th grade.
*     Also have English I (grades?), Algebra II, Bio, Chem, Econ, Physics, History.
*     Covers 1997-2013
*
* Outcomes to measure:
*
* graduation
*     Shows up as a grad in Graduates data (with a diploma)
*     OR shows up in as a grad in the GPA data and is not in the graduates data at all
*     OR shows up as a grad in the transfer/dropout/graduation data and is not in the graduates data at all.
* College attendance
*     Plans college in either GPA or Graduates data.
* 4-year college attendance
* Algebra I score
*     Excludes those who don't have it.
***;



*******************************************************************************
**** READ GPA DATA ************************************************************
*******************************************************************************;

*NOTE: GPA data have sparse coverage of LEAs in 2005, expand through 2010.;
*Missing in 2011.  All records have graduation dates, so these data may exclude
*dropouts. (I will assume so.) The data have a diploma type code and a program
*type code, but:
* -I can't find a codebook for the diploma type.
* - I odn't see a simple way to code up the program type.
*I have not kept either.;
cap program drop readGPA;
program define readGPA;
  args year;
  if $doasproject==1 project, original("${rawGPA1}/gpa`year'.dta.gz");
  ! zcat ${rawGPA2}/gpa`year'.dta.gz > ${scratch}/gpa`year'.dta;
  
  use ${scratch}/gpa`year'.dta;
  
  if `year'<2014 {;
    destring bound_for_code, gen(boundfor);
    gen byte tocoll=inlist(boundfor, 1, 2, 3, 4, 5, 9, 10, 11, 12, 13) if boundfor<.;
    gen byte tocoll4=inlist(boundfor, 1,2,9,10) if boundfor<.;
    gen byte graduated=(diploma_issued_date<.);
    gen rank=1-rank_weighted/rank_number;
    replace rank=. if rank<0;
  };
  else if `year'==2014 {;
  	*Enough variables changed in 2014 to require new code;
  	gen byte tocoll4=1 if bound_for=="PUBLIC SENIOR INSTITUTIONS";
  	replace tocoll4=1 if bound_for=="PRIVATE SENIOR INSTITUTIONS";
  	replace tocoll4=1 if bound_for=="PUBLIC SENIOR INST -OUT OF NC";
  	replace tocoll4=1 if bound_for=="PRIVATE SENIOR INST -OUT OF NC";
  	replace tocoll4=0 if tocoll4==. & bound_for~="";
  	gen byte tocoll=tocoll4;
  	replace tocoll=1 if bound_for=="COMMUNITY & TECHNICAL COLLEGES";
  	replace tocoll=1 if bound_for=="PRIVATE JUNIOR COLLEGE";
  	replace tocoll=1 if bound_for=="TRADE, BUSINESS, NURSING SCHS";
  	replace tocoll=1 if bound_for=="COMM & TECH COLLEGES-OUT OF NC";
  	replace tocoll=1 if bound_for=="PRIVATE JR COLLEGE -OUT OF NC";
  	replace tocoll=1 if bound_for=="TRADE, BUS, NURS SCH-OUT OF NC";
  	tab bound_for tocoll4, m;
  	tab bound_for tocoll, m;
  	gen graddate=date(diploma_issued, "DM20Y");
  	gen byte graduated=(graddate<.);
    gen rank=1-rank_weighted/rank_number_weighted;
    replace rank=. if rank<0;
  };

  gen year=`year';
  keep if mastid<.;
  keep mastid lea schlcode tocoll tocoll4 graduated gpa_weighted rank year;
  replace gpa_weighted=. if gpa_weighted<0.7;

  ! rm ${scratch}/gpa`year'.dta;
end;

foreach y of numlist 2005(1)2010 2012 2013 2014 {;
 readGPA `y';
 tempfile gpa`y';
 save `gpa`y'';
};
use `gpa2005';
foreach y of numlist 2006(1)2010 2012 2013 2014 {;
	 append using `gpa`y'';
	};
sort mastid year;

   *We don't use the school or LEA later, so lets drop them;
    drop lea schlcode;

*Now we have some duplicates;
 duplicates report mastid;
 *Start by dropping true duplicate records;
  duplicates report;
  duplicates drop;
 
 *Now save it, and limit sample to duplicates for speed;
  sort mastid year;
  tempfile fullsamp;
  compress;
  save `fullsamp';

  sort mastid year;
  by mastid: keep if _N>1;

 *Any remaining duplicates have differences in at least one variable;
  *Set any variable with multiple values to missing;
   sort mastid year ;
   foreach v of varlist tocoll tocoll4 graduated gpa_weighted rank {;
   	 by mastid: gen d_`v'=(`v'~=`v'[1]);
   	 by mastid: gen sd_`v'=sum(d_`v');
   	 by mastid: replace `v'=. if sd_`v'[_N]~=0;
   };
   drop d_* sd_*;
  *One more duplicates drop on all vars;
   duplicates report;
   duplicates drop;
   *We are down to one obs per mastid - year, with no differences across years;
    isid mastid year;
    sort mastid year;
    foreach v of varlist _all {;
    	if "`v'"~="year" by mastid: assert `v'==`v'[1];
    };
   *And for year, lets keep the first;
    sort mastid year;
    by mastid: keep if _n==1;

 *Now append back to rest of file;
  tempfile unduplicated;
  save `unduplicated';
  use `fullsamp';
  sort mastid year;
  by mastid: keep if _N==1;
  append using `unduplicated';
  
  isid mastid;


foreach v of varlist tocoll tocoll4 graduated rank year {;
	 rename `v' gpa_`v';
	};
   
 save $outdir/prepdata_longrun_gpa, replace;
 if $doasproject==1 project, creates("${outdir}/prepdata_longrun_gpa.dta");


*******************************************************************************
**** READ GRADUATES DATA ******************************************************
*******************************************************************************;

cap program drop readgrads;
program define readgrads;
  args year;
  
  local yy=`year'-2000;
  if `yy'==9 local yy "09";
  if $doasproject==1 project, original("${rawgrads}/gradpub`yy'.dta.gz");
  ! zcat ${rawgrads}/gradpub`yy'.dta.gz > ${scratch}/gradpub`year'.dta;
  
  use ${scratch}/gradpub`year'.dta;
  gen diploma=(dc=="DIPLOMA");
  if `year'==2014 {;
  	destring bound_for_code, gen(boundfor);
    gen byte tocoll=inlist(boundfor, 1, 2, 3, 4, 5, 9, 10, 11, 12, 13) if boundfor<.;
    gen byte tocoll4=inlist(boundfor, 1,2,9,10) if boundfor<.;
  };
  else {;
    gen tocoll=0 if intention~="";
    replace tocoll=1 if strpos(intention, "CC-TC")==1 | strpos(intention, "PRIV")==1
                      | strpos(intention, "PUB")==1 | strpos(intention, "TSBSNS")==1;
    gen tocoll4=0 if intention~="";
    replace tocoll4=1 if strpos(intention, "PRIV-SI")==1 | strpos(intention, "PUB-SI")==1;
  };
  keep mastid lea schlcode diploma tocoll tocoll4;
  gen year=`year';
  keep if mastid<.;
  ! rm $scratch/gradpub`year'.dta;
end;

forvalues y=2009/2014 {;
  readgrads `y';
  tempfile grads`y';
  save `grads`y'';
};
use `grads2009';
append using `grads2010';
append using `grads2011';
append using `grads2012';
append using `grads2013';
append using `grads2014';

 *Drop lea and school code -- we dont need them;
  drop lea schlcode;
  
 *Now work more carefully on duplicates;
  compress;
  sort mastid year;
  tempfile full;
  save `full';
  
  by mastid: keep if _N>1;
  *Drop if duplicates on all vars;
  duplicates drop;
  *Within-year duplicates -- take the max;
   duplicates report mastid year;
   foreach v of varlist diploma tocoll tocoll4 {;
   	 by mastid year: gen have_`v'=(`v'==1);
   	 by mastid year: gen any_`v'=sum(have_`v');
   	 by mastid year: replace `v'=any_`v'[_N];
   	 drop have_`v' any_`v';
   };
   by mastid year: keep if _n==1;
  *Between years, take the first year where graduated;
   gsort mastid -diploma year;
   by mastid: keep if _n==1;
  tempfile undupgrads;
  save `undupgrads';
  use `full';
  by mastid: keep if _N==1;
  append using `undupgrads';
  sort mastid year;
  foreach v of varlist year diploma tocoll tocoll4 {;
  	 rename `v' grads_`v';
  	};
  gen byte grads_graduated=1;
  isid mastid;
 save $outdir/prepdata_longrun_grads, replace;
 if $doasproject==1 project, creates("${outdir}/prepdata_longrun_grads.dta");


*******************************************************************************
**** READ SCHOOL EXIT DATA ****************************************************
*******************************************************************************;

cap program drop readexit;
program define readexit;
  args year;
  
  if $doasproject==1 project, original("${rawexit1}/exit_pub`year'.dta.gz");
  ! zcat ${rawexit2}/exit_pub`year'.dta.gz > ${scratch}/exit_pub`year'.dta;
  
  use ${scratch}/exit_pub`year'.dta;
  
  rename dropout txt_drop;
  gen byte dropout=(txt_drop=="Y" | effective_exit_code=="4");
  gen byte graduated=(effective_exit_code=="9" | graduate=="Y");

  gen fileyear=`year';
  gen year=real(grad_year) if real(grad_year)<.;
  replace year=fileyear if year==.;   
  keep mastid year dropout graduated lea schlcode;
  drop if mastid==.;
  
    ! rm $scratch/exit_pub`year'.dta;

end;


forvalues y=2006/2014 {;
  readexit `y';
  tempfile exit`y';
  save `exit`y'';
};
use `exit2006';
forvalues y=2007/2014 {;
	append using `exit`y'';
};
*Drop lea and schlcode -- we dont need them;
 drop lea schlcode;
duplicates drop;
*Now, we are going to take the last observation from a student, preferring grad to dropout to neither;
 gsort mastid -graduated -dropout -year;
 isid mastid graduated dropout year;
 by mastid: keep if _n==1;
 rename graduated exit_graduated;
 rename dropout exit_dropout;
 rename year exit_gradyear;
 
save $outdir/prepdata_longrun_exit, replace;
if $doasproject==1 project, creates("${outdir}/prepdata_longrun_exit.dta");


 
*******************************************************************************
**** READ EOC ALGEBRA I DATA **************************************************
*******************************************************************************;
cap program drop readEOC;
program define readEOC;
  args year;
  
  if `year'<2000 local yy=`year'-1900;
  else if `year'<2010 {;
  	local yy=`year'-2000;
  	local yy "0`yy'";
  };
  else local yy=`year'-2000;

  if $doasproject==1 project, original("${rawEOC1}/`year'/alg1pub`yy'.dta.gz");
  ! zcat ${rawEOC2}/`year'/alg1pub`yy'.dta.gz > ${scratch}/alg1pub`year'.dta;
  
  use ${scratch}/alg1pub`year'.dta;
  keep mastid grade alg1scal;
  gen alg1year=`year';
  rename grade alg1grade;
  *Standardize the EOC scale separately by year -- scale varies;
  *In 2013, have some people under old scale;
   drop if alg1scal<226 & alg1year==2013;
   
   su alg1scal;
   gen alg1EOC=(alg1scal-r(mean))/r(sd);
   drop alg1scal;
  *Keep only the highest score per mastid/grade;
   drop if alg1EOC==.;
   sort mastid alg1grade alg1EOC;
   by mastid alg1grade: drop if _n<_N;
  
   
  ! rm $scratch/alg1pub`year'.dta;
end;

forvalues y=1997/2013 {;
	readEOC `y';
	tempfile alg1`y';
	save `alg1`y'';
};
use `alg11997';
forvalues y=1998/2013 {;
	append using `alg1`y'';
};
drop if mastid==.;
*Eliminate duplicates -- prefer grade 9, 8, 10, 7, 11, 12, 6;
*Conditional on that, take earlier years, higher scores;
 destring alg1grade, replace force;
 gen pref=1 if alg1grade==9;
 replace pref=2 if alg1grade==8;
 replace pref=3 if alg1grade==10;
 replace pref=4 if alg1grade==7;
 replace pref=5 if alg1grade==11;
 replace pref=6 if alg1grade==12;
 replace pref=7 if alg1grade==6;
 replace pref=8 if pref==.;
 gsort mastid pref alg1year -alg1EOC;
 isid mastid pref alg1year alg1EOC;
 by mastid: keep if _n==1;
 drop pref;
 
 save $outdir/prepdata_longrun_EOC, replace;
 if $doasproject==1 project, creates("${outdir}/prepdata_longrun_EOC.dta");

;
use $outdir/prepdata_longrun_grads, clear;
merge 1:1 mastid using $outdir/prepdata_longrun_gpa;
rename _merge mrg1;
merge 1:1 mastid using $outdir/prepdata_longrun_exit;
rename _merge mrg2;
merge 1:1 mastid using $outdir/prepdata_longrun_EOC;
rename _merge mrg3;
gen indata_grads=(inlist(mrg1,1,3));
gen indata_gpa=(inlist(mrg1,2,3));
gen indata_exit=(inlist(mrg2,2,3));
gen indata_alg1=(inlist(mrg3,2,3));
drop mrg?;
*rename lea lr_lea;
*rename schlcode lr_schlcode;
rename mastid stuid;


* Outcomes to measure:
*
* graduation
*     Shows up as a grad in Graduates data (with a diploma)
*     OR shows up in as a grad in the GPA data and is not in the graduates data at all
*     OR shows up as a grad in the transfer/dropout/graduation data and is not in the graduates data at all.
* College attendance
*     Plans college in either GPA or Graduates data.
* 4-year college attendance
* Algebra I score
*     Excludes those who don't have it.

compress;
save $outdir/prepdata_longrun, replace;
 if $doasproject==1 project, creates("${outdir}/prepdata_longrun.dta");

