 *Extract 2nd grade scores from MBuild files;

version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	global doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  global doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "prepdata_mbuild"
	local sig "Not run as part of project!"
	
}

#delimit;
global rawmb "~/data/nceduc/statafmt/Student/MBuild";
local scratchdir "`pdir'/scratch";
global outdir="`scratchdir'/ncdata";
global scratch "`scratchdir'";
set varabbrev off;
set more off;

if $doasproject==1 project, uses($outdir/validteachers.dta);
local fyear=1995;
local lyear=2011;

*Good for 1997-2005;
cap program drop readmbuildA;
program define readmbuildA;
   args year;
  
  if $doasproject==1 project, original("${rawmb}/mb_`year'_pub.dta.gz");
  ! zcat ${rawmb}/mb_`year'_pub.dta.gz > ${scratch}/mb_`year'_pub.dta;
  
  use mastid mthpresc rdpresc mthpstsc rdpostsc grade if grade=="03" using ${scratch}/mb_`year'_pub.dta;

  ! rm ${scratch}/mb_`year'_pub.dta;

  drop grade;
  gen year=`year';
  *Drop students with duplicate obs;
   bys mastid mthpresc mthpstsc rdpresc rdpostsc: drop if _n>1;
   bys mastid: drop if _N>1;
end;

cap program drop mbuildA;
program define mbuildA;
  forvalues y=1997/2005 {;
  	readmbuildA `y';
  	tempfile mb`y';
  	save `mb`y'';
  };
  forvalues y=2006/2009 {;
  	*Note: There are some mbuild pre-test scores in 2008-9, but not for both subjects in either year.
  	*These will be excluded later.;
  	readmbuildB `y';
  	tempfile mb`y';
  	save `mb`y'';
  };
  use `mb1997';
  forvalues y=1998/2009 {;
  	 append using `mb`y'';
  };
  *standardize scores;
   sort year mastid;
   *table year, contents(mean mthpresc sd mthpresc min mthpresc max mthpresc);
   *table year, contents(mean rdpresc sd rdpresc min rdpresc max rdpresc);
   by year : egen avgread=mean(rdpresc);
   by year : egen sdread=sd(rdpresc);
   gen readstd=(rdpresc-avgread)/sdread;
   drop avgread sdread;
   by year : egen avgmath=mean(mthpresc);
   by year : egen sdmath=sd(mthpresc);
   gen mathstd=(mthpresc-avgmath)/sdmath;
   drop avgmath sdmath;
   
  tempfile mb;
  save `mb';  

  *Now merge to base pop, keeping only students with valid G3 records and matching scores;
   use year mastid readscal mathscal test_grade student_grade if (student_grade==3 | test_grade==3) using $outdir/validteachers;
   keep if year>=1997 & year<=2009;
   merge 1:1 mastid year using `mb';
   *Check that G3 scores match in two data sets;
    gen match3=(_merge==3 & rdpostsc==readscal & mthpstsc==mathscal);
    tab _merge match3, m;
    tab year _merge, m;
    tab year match3, m;
    
   *Drop obs that just have mbuild obs;
    drop if _merge==2;
    drop _merge;
   *Drop obs that fail to match;
    drop if match3~=1;
  *Now prepare the data file and rename variables;
   keep year mastid rdpresc mthpresc readstd mathstd;
   gen byte student_grade=2;
   gen byte test_grade=2;
   rename rdpresc readscal;
   rename mthpresc mathscal;
   drop if readscal==. & mathscal==.;
   tempfile g2A;
   save `g2A';
end;

*For 2006-9;
cap program drop readmbuildB;
program define readmbuildB;
   args year;
  
  if $doasproject==1 project, original("${rawmb}/mb_`year'_pub.dta.gz");
  ! zcat ${rawmb}/mb_`year'_pub.dta.gz > ${scratch}/mb_`year'_pub.dta;
  
  use mastid mp_score rp_score rd_score ma_score grade if grade=="03" using ${scratch}/mb_`year'_pub.dta;

  ! rm ${scratch}/mb_`year'_pub.dta;

  rename mp_score mthpresc;
  rename ma_score mthpstsc;
  rename rp_score rdpresc;
  rename rd_score rdpostsc;
  foreach v of varlist mthpresc mthpstsc rdpresc rdpostsc {;
  	replace `v'="" if `v'=="NULL";
  	destring `v', replace;
  };
  drop grade;
  
  gen double year=`year';
  *Drop students with duplicate obs;
   bys mastid mthpresc mthpstsc rdpresc rdpostsc: drop if _n>1;
   bys mastid: drop if _N>1;
end;

/*
cap program drop mbuildB;
program define mbuildB;
  forvalues y=2006/2007 {;
  	readmbuildB `y';
  	tempfile mb`y';
  	save `mb`y'';
  };
  use `mb2006';
  append using `mb2007';
  tempfile mb;
  save `mb';  

  *Now merge to base pop, keeping only students with valid G3 records and matching scores;
   use year mastid readscal mathscal test_grade student_grade if (student_grade==3 | test_grade==3) using $scratch/validteachers;
   keep if year>=2006 & year<=2007;
   merge 1:1 mastid year using `mb';
   *Check that G3 scores match in two data sets;
    gen match3=(_merge==3 & rdpostsc==readscal & mthpstsc==mathscal);
    tab _merge match3, m;
    tab year _merge, m;
    tab year match3, m;
    
   *Drop obs that just have mbuild obs;
    drop if _merge==2;
    drop _merge;
   *Drop obs that fail to match;
    drop if match3~=1;
  *Now prepare the data file and rename variables;
   keep year mastid rdpresc mthpresc;
   gen byte student_grade=2;
   gen byte test_grade=2;
   rename rdpresc readscal;
   rename mthpresc mathscal;
   tempfile g2B;
   save `g2B';
end;
*/
mbuildA;
compress;
save ${outdir}/prepdata_mbuild, replace;
if $doasproject==1 project, creates("${outdir}/prepdata_mbuild.dta");

*mbuildB;
