version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "validteachers"
	local sig "Not run as part of project!"
	
}

#delimit;
global rawpers "~/data/nceduc/statafmt/Classroom/Personnel";
local scratchdir "`pdir'/scratch";
local outdir="`scratchdir'/ncdata";
set varabbrev off;
set more off;

 if `doasproject'==1 {;
 	 project, uses(`outdir'/prepdata_students.dta);
 	 project, uses(`outdir'/prepdata_SAR.dta);
 };
*First, use the student data to count students per teacher;
 use `outdir'/prepdata_students;
 gen havemath=(mathscal<.);
 gen haveread=(readscal<.);
 gen grade=student_grade;
 replace grade=test_grade if grade==.;
 gen grade3=(grade==3);
 gen grade4=(grade==4);
 gen grade5=(grade==5);
 gen student=1;
 collapse (sum) havemath haveread grade3 grade4 grade5 student, 
   by(lea schlcode year teachid);
 gen frgrade3=(grade3/student);
 gen frgrade4=(grade4/student);
 gen frgrade5=(grade5/student);
   
 gen grade=3 if frgrade3>0.66;
 replace grade=4 if frgrade4>0.66;
 replace grade=5 if frgrade5>0.66;

 keep lea schlcode year teachid student grade;
 rename student nstudents;
 rename grade test_grade;
 
 gen badteachid=(teachid<100000);
 replace badteachid=1 if teachid<. & floor(teachid/100000)==year;
 
 tempfile proctors;
 save `proctors';

*Now, extract the SAR records for all teachers who show up in the proctor data;
 merge 1:m lea schlcode year teachid using `outdir'/prepdata_SAR, keep(3);
 gen SAR_valid=(teachassign==1 & stdlevel==1);
 replace SAR_valid=SAR_valid*(inlist(subjct, "0000", "1001", "1010", "2001")+inlist(subjct, "3001", "4001", "9001", "9010", "9982", "9980"));
 replace SAR_valid=0 if test_grade==3 & sccgrd~="3" & sccgrd~="Z";
 replace SAR_valid=0 if test_grade==4 & sccgrd~="4" & sccgrd~="Z";
 replace SAR_valid=0 if test_grade==5 & sccgrd~="5" & sccgrd~="Z";
 *Come up with one obs per teacher/year/school;
  collapse (sum) SAR_valid (count) nSARs=SAR_valid, by(lea schlcode year teachid);
  *Code teachers with multiple valid SARs as valid -- not clearly right.;
  replace SAR_valid=1 if SAR_valid>1 & SAR_valid<.;
  keep lea schlcode year teachid SAR_valid;
  tempfile SAR;
  save `SAR';

*And go back to the proctor data, merge on the SAR data, and establish class size standards;
 use `proctors';
 merge 1:1 lea schlcode year teachid using `SAR', assert(1 3);
 gen byte noSAR=(_merge==1);
 replace SAR_valid=0 if noSAR==1;
 gen size_valid=(nstudents>=10 & nstudents<=31 & test_grade<.);
 rename nstudents CLass_size;
 keep lea schlcode year teachid noSAR SAR_valid test_grade size_valid CLass_size;
 rename test_grade SAR_grade;
 compress;
 tempfile teachervalid;
 save `teachervalid';

*Now go back to the student data and merge this on;
 use `outdir'/prepdata_students;
 gen grade=student_grade;
 replace grade=test_grade if grade==.;
 merge m:1 lea schlcode year teachid using `teachervalid', keep(1 3);
 replace size_valid=0 if _merge==1;
 replace SAR_valid=0 if _merge==1;
 gen byte grade_valid=(grade==SAR_grade);
 drop _merge;

*Now we need to keep only observations with one obs per mastid-year;
 sort mastid year;
 by mastid year: drop if _N>1;
  
 save `outdir'/validteachers.dta, replace;
 if `doasproject'==1 project, creates(`outdir'/validteachers.dta);
 
 