*basicreplicationA.do
*By Jesse Rothstein
*7/16/14
*
*This program uses CFR's code to estimate their basic quasi-experimental
*regressions, and saves the samples. I do this to ensure that I get the 
*same results with my code as with theirs.
***********************************************************************


version 12
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "basicreplication"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/replication"

************* LOAD CFR ADO FILES *****************************
*if `doasproject'==1 project, relies_on(`pdir'/cfr/cfrprog2_nc_setup.do)
*include `pdir'/cfr/cfrprog2_nc_setup.do
if `doasproject'==1 project, relies_on(`pdir'/cfr/cfr_analysis_final_setup.do)
include `pdir'/cfr/cfr_analysis_final_setup.do

************* OTHER FILES USED *****************************
if `doasproject'==1 {
	project, uses(`cfrdat'/tfx/tfx_tym.dta)
	project, uses(`cfrdat'/table4_teacher_school_weights_with_tv_only.dta)
	project, uses(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only.dta)
	project, uses(`cfrdat'/teacher_school_weights.dta)
	project, uses(`cfrdat'/SCHD_sch_gr_year_collapse.dta)
}

***Run CFR Table 4, columns 1-2;
prepare_quasi, tfxfile(`cfrdat'/tfx/tfx_tym) ///
	tch_sch_weights(`cfrdat'/table4_teacher_school_weights_with_tv_only) ///
	sch_gr_yr_collapse(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only) ///
	drop_empty_tv_cells

* Col 1
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
eststo c1, title("CFRI_T4_C1")

* Col 2
egen sch_yr = group(sch year)
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
eststo c2, title("CFRI_T4_C2")

* Col 3
tsset sgm_id year
g d_mean_l_other = d.mean_l_other
g d_mean_l_other2 = d_mean_l_other^2
g d_mean_l_other3 = d_mean_l_other^3
g d_mean_l_score = d.mean_l_score
g d_mean_l_score3 = d_mean_l_score^3
g d_mean_l_score2 = d_mean_l_score^2
areg d_mean_score d_tv_sgm_1 d_mean_l_score* d_mean_l_other* f.d_tv_sgm_1 l.d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
eststo c3, title("CFRI_T4_C3")

* Col 4
g d_pred_score_pared = d.pred_score_pared
*JR orig: areg d_pred_score_nocontrols d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
*JR orig: estimates store predscore
*JR orig: local coef=string(_b[d_tv_sgm_1],"%9.3f")
*JR orig: local se=string(_se[d_tv_sgm_1],"%9.3f")
areg d_pred_score_pared d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
eststo c4, title("CFRI_T4_C4")

compress
drop _merge
tempfile basesamp
save `basesamp'

***Now prepare the data for CFRs Table 5, Column 2, which includes all teachers
*even if they are missing VA
drop _all
prepare_quasi, tfxfile(`cfrdat'/tfx/tfx_tym) ///
	tch_sch_weights(`cfrdat'/teacher_school_weights) ///
	sch_gr_yr_collapse(`cfrdat'/SCHD_sch_gr_year_collapse)

*Check the regression
 areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)

 *Coverage rates for CFR T5, bottom row
  sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
  local mean_cur=r(mean)
  sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
  local mean_lag=r(mean)
  local covfr=((`mean_cur'+`mean_lag')/2)
  di "Fraction covered by teacher VA measure: " `covfr'
  

 *Coverage rates for CFR T5, bottom row, but limited to schools with >0 coverage in each year.
  bys sch grade year math: egen frcovered=mean(mean_covered_tv)
  sort sgm_id year
  sum mean_covered_tv if e(sample) & frcovered>0 & frcovered<. & l.frcovered>0 & l.frcovered<. [w=SGYsize], meanonly
  local mean_cur=r(mean)
  sum l.mean_covered_tv if e(sample) & frcovered>0 & frcovered<. & l.frcovered>0 & l.frcovered<. [w=SGYsize], meanonly
  local mean_lag=r(mean)
  local covfr2=((`mean_cur'+`mean_lag')/2)
  di "Fraction covered by teacher VA measure (at schools w positive coverage): " `covfr2'
 eststo c5, title("CFRI_T5_C2") addscalars(frcov `covfr' frcov_ifpos `covfr2')

 keep sch grade year math d_mean_score d_tv_sgm_1 SGYsize mean_covered_tv
 foreach v of varlist d_mean_score d_tv_sgm_1 SGYsize mean_covered_tv {
 	 rename `v' `v'_T5
 }
compress
tempfile c5dat
save `c5dat'
use `basesamp'
merge 1:1 sch grade year math using `c5dat'
drop _merge

  capture drop sgm
  capture drop sgm_id
  egen sgm=group(sch grade math)
  
  capture drop sch_cohort
  capture drop cohort
  gen cohort=year-grade
  egen sch_cohort=group(sch cohort)

  cap drop sch_yr  
  egen sch_yr=group(sch year)
  
  *This is a school-grade-year-math file -- drop the teacher-level variables (which are often arbitrary,
  * since CFR sometimes sort on non-unique variables and then keep the first observation).
   drop teacher grp CLass_size teach_wt tv tv_* 
   isid sch grade year math

save `pdir'/scratch/replication/`dofile'.dta, replace

  esttab c?, cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars mtitles
  esttab c? using `dofile'.txt, replace ///
         cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars mtitles
  esttab c? using `dofile'.csv, replace ///
         cells(b(fmt(5)) se(fmt(5))) r2 obslast nodepvars mtitles noparentheses

 if `doasproject'==1 {
 	 project, creates(`pdir'/scratch/replication/`dofile'.dta)
 	 project, creates(`thisdir'/`dofile'.txt)
 	 project, creates(`thisdir'/`dofile'.csv)
 }
 