
*replic_fig1a.do
*By Jesse Rothstein
*8/1/14
*
*This program makes a version of CFR-I's Figure 1A, to compare NC estiamates
*to theirs
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr1_fig1a"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/replication"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`cfrdat'/tfx/tfx_variance.csv)
}


*Replication of CFR's figure 1a

#delimit;

*First input their data;
 matrix cfrautocorrel=(1, 0.305, 0.434 \
                       2, 0.267, 0.382 \
                       3, 0.223, 0.334 \
                       4, 0.190, 0.303 \
                       5, 0.187, 0.281 \
                       6, 0.163, 0.265 \
                       7, 0.147, 0.254 \
                       8, 0.147, 0.241 \
                       9, 0.165, 0.248 \
                       10, 0.153, 0.224);
 matrix colnames cfrautocorrel=lag cfr_read cfr_math;
 drop _all;
 set obs 10;
 svmat cfrautocorrel, names(col);
 tempfile cfrlags;
 save `cfrlags';
                       



insheet using `cfrdat'/tfx/tfx_variance.csv, comma clear;
rename corr_lag_reading corr_lag_elementary_reading;
rename corr_lag_math corr_lag_elementary_math;
merge 1:1 lag using `cfrlags', assert(1 3);

sort lag;
local driftlimit_elem_reading=corr_lag_elementary_reading[7];
local driftlimit_elem_math=corr_lag_elementary_math[7];
local cfr_driftlimit_read=cfr_read[7];
local cfr_driftlimit_math=cfr_math[7];

*JR: CFR original code
*twoway  (scatter corr_lag_elementary_reading lag if inrange(lag,1,7), c(l) sort) ///
*	(scatter corr_lag_elementary_reading lag if inrange(lag,8,10), mcolor(navy)) ///
*	(scatter corr_lag_elementary_math lag if inrange(lag,0,7), c(l) sort msymbol(T) lcolor(maroon) mcolor(maroon)) ///
*	(scatter corr_lag_elementary_math lag if inrange(lag,8,10), msymbol(T) mcolor(maroon)) ///
*	(function y=`driftlimit_elem_reading', range(7 10) lcolor(navy)) ///
*	(function y=`driftlimit_elem_math', range(7 10) lcolor(maroon)), ///
*	ylab(0(0.1)0.5) ///
*	graphregion(fcolor(white)) ///
*	title("Autocorrelation Vector in Elementary School for English and Math Scores", size(medium)) ///
*	xtitle("Years Separation Between Classes") ///
*	ytitle("Correlation") ///
*	legend(order(1 "English" 3 "Math"))
;
*My version of their graph;

twoway  
  (scatter cfr_read lag if inrange(lag,1,7), msymbol(Oh) c(l) sort) 
	(scatter cfr_read lag if inrange(lag,8,10), msymbol(Oh) mcolor(navy)) 
	(scatter cfr_math lag if inrange(lag,0,7), c(l) sort msymbol(Th) lcolor(maroon) mcolor(maroon)) 
	(scatter cfr_math lag if inrange(lag,8,10), msymbol(Th) mcolor(maroon)) 
  (scatter corr_lag_elementary_reading lag if inrange(lag,1,7), msymbol(O) mcolor(navy) lcolor(navy) c(l) sort) 
	(scatter corr_lag_elementary_reading lag if inrange(lag,8,10), msymbol(O) mcolor(navy)) 
	(scatter corr_lag_elementary_math lag if inrange(lag,0,7), c(l) sort msymbol(T) lcolor(maroon) mcolor(maroon)) 
	(scatter corr_lag_elementary_math lag if inrange(lag,8,10), msymbol(T) mcolor(maroon)) 
	(function y=`driftlimit_elem_reading', range(7 10) lcolor(navy) lpattern(dash)) 
	(function y=`driftlimit_elem_math', range(7 10) lcolor(maroon) lpattern(dash))
	(function y=`cfr_driftlimit_read', range(7 10) lcolor(navy) lpattern(dash)) 
	(function y=`cfr_driftlimit_math', range(7 10) lcolor(maroon) lpattern(dash))
	, 
	ylab(0(0.1)0.5, format(%3.1f) nogrid) 
	graphregion(fcolor(white)) 
	title("Autocorrelation Vector in Elementary School for English and Math Scores", size(medium)) 
	xtitle("Years Between Classes") 
	ytitle("Correlation") 
	legend(order(1 "CFR English" 3 "CFR Math" 5 "NC English" 7 "NC Math") region(lstyle(none)))
	saving(`dofile'.gph, replace);
graph export `dofile'.eps, replace;

if `doasproject'==1 {;
	project, creates(`thisdir'/`dofile'.gph);
	project, creates(`thisdir'/`dofile'.eps);
};
