
*cfr1_table5.do
*By Jesse Rothstein
*7/16/14
*
*This program replicates and extends CFR-I's Table 5, using their code
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "cfr1_table5"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/replication"
local cfrdir "`pdir'/cfr"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 project, relies_on(`cfrdir'/cfr_analysis_final_setup.do)
include `cfrdir'/cfr_analysis_final_setup.do
if `doasproject'==1 {
	project, uses(`cfrdat'/tfx/tfx_tym.dta)
	project, uses(`cfrdat'/table4_teacher_school_weights_with_tv_only.dta)
	project, uses(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only.dta)
	project, uses(`cfrdat'/teacher_school_weights.dta) 
	project, uses(`cfrdat'/SCHD_sch_gr_year_collapse.dta)
}

***************
*** Table 5 ***
***************

prepare_quasi, tfxfile(`cfrdat'/tfx/tfx_tym) ///
	tch_sch_weights(`cfrdat'/table4_teacher_school_weights_with_tv_only) ///
	sch_gr_yr_collapse(`cfrdat'/table4_SCHD_sch_gr_year_collapse_with_tv_only) ///
	drop_empty_tv_cells ///
	entry_exit

xtset sgm_id year
sort sgm_id year
by sgm_id: gen d_mean_l_score = mean_l_score-L.mean_l_score
egen sch_yr=group(sch year)

* Double check that OLS reg matches Table 4, Col 1
set more off
xi: reg d_mean_score d_tv_sgm_1 i.year [w=SGYsize], cluster(sch_cohort)
estimates store t4c1

* Col 1: IV with teacher exiters from district or school
*gen mean_tv_2yr_f_ds = mean_tv_2yr_f_d + mean_tv_2yr_f_s
gen mean_tv_2yr_f_stateschool = mean_tv_2yr_f_state + mean_tv_2yr_f_school
set more off
*xi: ivreg2 d_mean_score i.year (d_tv_sgm_1 = l.mean_tv_2yr_f_ds) [w=SGYsize], cluster(sch_cohort) first ffirst savefirst
xi: ivreg2 d_mean_score i.year (d_tv_sgm_1 = l.mean_tv_2yr_f_stateschool) [w=SGYsize], cluster(sch_cohort) first ffirst savefirst
estimates store t5c1
gen samp1=e(sample)
sum mean_covered_tv if samp1==1 [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if samp1==1 [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
local covered_c1=((__mean_cur+__mean_lag)/2) 

*Alternate version 1 - control for lagged score.
xi: ivreg2 d_mean_score d_mean_l_score i.year (d_tv_sgm_1 = l.mean_tv_2yr_f_stateschool) [w=SGYsize], cluster(sch_cohort) first ffirst savefirst
estimates store t5c1alt1

*Alternate version 2 - control for school-year FEs (cluster on school).
  gen lmean_tv_2yr_f_stateschool=l.mean_tv_2yr_f_stateschool
  egen gm=group(grade math)
  xtset sch_yr gm
  xtivreg2 d_mean_score (d_tv_sgm_1=lmean_tv_2yr_f_stateschool) [w=SGYsize], cluster(sch) fe
  estimates store t5c1alt2

*Alternate version 3 - control for school-year FEs and lagged score (cluster on school).
  xtivreg2 d_mean_score d_mean_l_score (d_tv_sgm_1=lmean_tv_2yr_f_stateschool) [w=SGYsize], cluster(sch) fe
  estimates store t5c1alt3
  xtset sgm_id year

*Alt 4: Estimate effect on lagged score (year FEs).
 xi: ivreg2 d_mean_l_score i.year (d_tv_sgm_1 = l.mean_tv_2yr_f_stateschool) [w=SGYsize], cluster(sch_cohort) first ffirst savefirst
 estimates store t5c1alt4

*Alt 5: Estimate effect on lagged score (school-year FEs).
  xtset sch_yr gm
  xtivreg2 d_mean_l_score (d_tv_sgm_1=lmean_tv_2yr_f_stateschool) [w=SGYsize], cluster(sch) fe
  estimates store t5c1alt5
  xtset sgm_id year

* Open file to store mean_covered csv


*** Cols 2-4: Cut sample by amount of imputed data
*estimates clear
prepare_quasi, tfxfile(`cfrdat'/tfx/tfx_tym) ///
	tch_sch_weights(`cfrdat'/teacher_school_weights) ///
	sch_gr_yr_collapse(`cfrdat'/SCHD_sch_gr_year_collapse)

xtset sgm_id year
sort sgm_id year
by sgm_id: gen d_mean_l_score = mean_l_score-L.mean_l_score
egen sch_yr=group(sch year)

* Col 2: Full sample reg
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
estimates store t5c2
gen samp2=e(sample)
sum mean_covered_tv if samp2==1 [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if samp2==1 [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
local covered_c2=((__mean_cur+__mean_lag)/2) 
*Alt 1: Control for lagged score.
areg d_mean_score d_tv_sgm_1 d_mean_l_score [w=SGYsize], cluster(sch_cohort) a(year)
estimates store t5c2alt1
*Alt 2: Control for school-year FEs.
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store t5c2alt2
*Alt 3: Control for school-year FEs and lagged score.
areg d_mean_score d_tv_sgm_1 d_mean_l_score [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store t5c2alt3
*Alt 4: Estimate effect on lagged score (year FEs)
areg d_mean_l_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
estimates store t5c2alt4
*Alt 5: Estimate effect on lagged score (school-year FEs)
areg d_mean_l_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store t5c2alt5


* Col 3: Cut to sample with <25% imputed data
areg d_mean_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv>0.75 & l.mean_covered_tv>0.75, cluster(sch_cohort) a(year)
estimates store t5c3
gen samp3=e(sample)
sum mean_covered_tv if samp3==1 [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if samp3==1 [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
local covered_c3=((__mean_cur+__mean_lag)/2) 
*Alt 1: Control for lagged score.
areg d_mean_score d_tv_sgm_1 d_mean_l_score [w=SGYsize] if mean_covered_tv>0.75 & l.mean_covered_tv>0.75, cluster(sch_cohort) a(year)
estimates store t5c3alt1
*Alt 2: Control for school-year FEs
areg d_mean_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv>0.75 & l.mean_covered_tv>0.75, cluster(sch_cohort) a(sch_yr)
estimates store t5c3alt2
*Alt 3: Control for school-year FEs and lagged score
areg d_mean_score d_tv_sgm_1 d_mean_l_score [w=SGYsize] if mean_covered_tv>0.75 & l.mean_covered_tv>0.75, cluster(sch_cohort) a(sch_yr)
estimates store t5c3alt3
*Alt 4: Estimate effect on lagged score (year FEs).
areg d_mean_l_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv>0.75 & l.mean_covered_tv>0.75, cluster(sch_cohort) a(year)
estimates store t5c3alt4
*Alt 5: Estimate effect on lagged score (school-year FEs).
areg d_mean_l_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv>0.75 & l.mean_covered_tv>0.75, cluster(sch_cohort) a(sch_yr)
estimates store t5c3alt5

* Col 4: Cut to sample with no imputed data
areg d_mean_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv==1 & l.mean_covered_tv==1, cluster(sch_cohort) a(year)
estimates store t5c4
gen samp4=e(sample)
sum mean_covered_tv if samp4==1 [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if samp4==1 [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
local covered_c4=((__mean_cur+__mean_lag)/2) 
*Alt 1: Control for lagged score.
areg d_mean_score d_tv_sgm_1 d_mean_l_score [w=SGYsize] if mean_covered_tv==1 & l.mean_covered_tv==1, cluster(sch_cohort) a(year)
estimates store t5c4alt1
*Alt 2: Control for school-year FEs
areg d_mean_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv==1 & l.mean_covered_tv==1, cluster(sch_cohort) a(sch_yr)
estimates store t5c4alt2
*Alt 3: Control for school-year FEs and lagged score
areg d_mean_score d_tv_sgm_1 d_mean_l_score [w=SGYsize] if mean_covered_tv==1 & l.mean_covered_tv==1, cluster(sch_cohort) a(sch_yr)
estimates store t5c4alt3
*Alt 4: Estimate effect on lagged score (year FEs).
areg d_mean_l_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv==1 & l.mean_covered_tv==1, cluster(sch_cohort) a(year)
estimates store t5c4alt4
*Alt 5: Estimate effect on lagged score (school-year FEs).
areg d_mean_l_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv==1 & l.mean_covered_tv==1, cluster(sch_cohort) a(sch_yr)
estimates store t5c4alt5


* Output
esttab t4c1     , cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast 
esttab t5c?     , cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast 
esttab t5c?alt1 , cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast 
esttab t5c?alt2 , cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast 
esttab t5c?alt3 , cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast 
esttab t5c?alt4 , cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast 
esttab t5c?alt5 , cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast 
esttab t4c1 t5c? t5c?alt1 t5c?alt2 t5c?alt3 t5c?alt4 t5c?alt5 using `dofile'.txt, cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast replace
esttab t4c1 t5c? t5c?alt1 t5c?alt2 t5c?alt3 t5c?alt4 t5c?alt5 using `dofile'.csv, cells(b(fmt(%12.0g)) se(abs fmt(%12.0g))) obslast replace noparentheses
estimates clear

file open meancovered using `dofile'.csv, write text append
di `"file write meancovered " " _n _n "Fraction with non-missing VA,," `covered_c1' ", " `covered_c2' ", " `covered_c3' ", " `covered_c4' ", ""'
file write meancovered " " _n _n "Fraction with non-missing VA,," (`covered_c1') ", " (`covered_c2') ", " (`covered_c3') ", " (`covered_c4') ", "
file close meancovered    

if `doasproject'==1 project, creates(`dofile'.txt)
if `doasproject'==1 project, creates(`dofile'.csv)
