*Program to check sample sizes

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "paperstatistics"
	local sig "Not run as part of project!"
	
}
local scratch "`pdir'/scratch"
local cfrdat "`scratch'/cfrdata"
local extradat "`scratch'/extras"


************* OTHER FILES USED *****************************
if `doasproject'==1 {
	project, uses(`cfrdat'/schd_work.dta)
	project, uses(`cfrdat'/schd_work_trim.dta)
	project, uses(`cfrdat'/schd_work_nonsample.dta)
	project, uses(`cfrdat'/tfx/tfx_tym.dta)
  project, uses(`pdir'/scratch/extension/preparequasi.dta)
  project, relies_on(`pdir'/cfr/cfr_analysis_final_setup.do)
}
include `pdir'/cfr/cfr_analysis_final_setup.do


/******************************************************************************
* My sample consists of over <#X1#> student-year-subject observations, spread 
* across three grades (3-5), two subjects (math and reading), <#X2#> schools, 
* and 15 years (1997-2011). After excluding special education classes and those 
* with fewer than 10 students, and students with missing test scores, I am left 
* with <#X3#> observations. <#X4#>% of these are linked to <#X5#>valid teachers. 
* My original sample is a bit smaller than CFR-I's, which contains approximately 
* 18 million student-year-subject observations, but the sample size for VA 
* calculations is similar (<#X6#> vs. 7.6 million in CFR-I's sample). I have 
* non-missing leave-one-out predicted VA scores for <#X7#> teacher-year-subject 
* cells, with an average of <#X8#> students per cell. The sample for the quasi-
* experimental analysis consists of school-grade-subject-year cells with non-
* missing \Delta Q_{sgt}. I have <#X9#> such cells (when teachers with missing 
* VA predictions are excluded), as compared with 59,770 in CFR-I. 
******************************************************************************/
 /*
*X1: Number of student-year-subject observations, without exclusion of small
*    classes, special ed, or missing test scores.
*X2: Number of schools in this full sample.
*As of Oct. 5, 2015: 
* X1=8,642,968
* X2=1723
 *Start with all student data
  use `cfrdat'/schd_work
  append using `cfrdat'/schd_work_nonsample
  tab flag_sample
  assert grade>=3 & grade<=5
  codebook grade year math sch teacher, compact
  tab grade
  tab year
  tab math
  *Note: Missing 3rd graders in 2009-2011. prepcfrsamp_1.do excludes them
  * for missing lagged test scores.;
   tab year grade

*X3: Number of student-year-subject observations not in special ed classes,
*  with class size>=10, with non-missing scores.
*X4: Percent of X3 linked to valid teachers
*X5: Number of valid teachers linked.  
*X6: Sample size for VA calculations -- same as X3.
*As of Oct. 5, 2015:
* X3=7,079,301
* X4=78.57%
* X5=36,451.
 *Limit to students not in special ed classes, with class size>=10. 
  keep if flag_sample==1
  merge 1:1 stuid year math using `cfrdat'/tfx/score_r, assert(1 3)
  gen havescorer=(score_r<. & score<.)

 *Valid teachers
  gen validteacher=(teacher<500000000)
  tab havescorer
  tab havescorer validteacher, m
  tab validteacher
  tab validteacher if havescorer==1
  codebook teacher if validteacher==1 & havescorer==1

*X7: Number of teacher-year-subject cells with leave-one-out predicted VA.
*X8: Average number of students per cell.
*As of Oct. 5, 2015:
* X7=257,066
* X8=22
 *Now go to the teacher-year-subject sample
  collapse (count) nscores=score, by(teacher year math)
  merge 1:1 teacher year math using `cfrdat'/tfx/tfx_tym
  gen haveva=(tv<.)
  gen validteacher=(teacher<900000000)
  tab validteacher haveva
  su nscores if validteacher==1 & haveva==1, d

*X9: School-grade-subject-year cells with non-missing Delta Q
*As of Oct. 5, 2015:
* X9=79,466
  use `pdir'/scratch/extension/preparequasi.dta, clear
  su dva_tv_CLwgt
  su dva*
*/

/******************************************************************************
* The inclusion of teacher fixed effects in ([eq:VA_withinreg]) has little 
* impact on the results: In the North Carolina sample, the correlation between 
* A_{it}, as defined in ([eq:VA_withinreg]), and the residual from a simple OLS 
* regression of A_{it}^{*} on X_{it} without fixed effects is <#X10#> at the 
* student level and <#X11#> at the teacher-year level.  
******************************************************************************/
  use `cfrdat'/schd_work_trim.dta, clear
  drop if missing(teacher,year,class)
  *Regression with FEs
   gen resid_fe=.
   forvalues m=0/1 {
   	 tempvar pred`m'
   	 areg score ${baseline_VAM_controls} if math==`m', absorb(teacher)
   	 predict `pred`m'', xb
   	 replace resid_fe=score-`pred`m'' if math==`m'
   	 drop `pred`m''
   }
  *Regression without FEs
   gen resid_nofe=.
   forvalues m=0/1 {
   	 tempvar pred`m'
   	 reg score ${baseline_VAM_controls} if math==`m'
   	 predict `pred`m'', xb
   	 replace resid_nofe=score-`pred`m'' if math==`m'
   	 drop `pred`m''
   }
   
  corr resid_fe resid_nofe
  collapse (mean) resid_fe resid_nofe (count) nstud=resid_fe, by(teacher year sch class math)
  corr resid_fe resid_nofe
  