*summstats.do
*By Jesse Rothstein
*7/12/15
*
*This program computes basic summary statistics 
***********************************************************************

version 12
clear *
matrix drop _all
estimates clear
set varabbrev off /*JR added*/

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
  local doasproject=0
	local pdir "~/teachereffects/cfr_replic/project"
	local dofile "summstats"
	local sig "Not run as part of project!"
	
}
local thisdir "`pdir'/replication"
local cfrdat "`pdir'/scratch/cfrdata"

************* OTHER FILES USED *****************************
if `doasproject'==1 {
 	project, uses(`cfrdat'/schd_work.dta)
 	project, uses(`cfrdat'/tfx/score_r.dta)
}

use `cfrdat'/schd_work
merge 1:1 stuid year math using `cfrdat'/tfx/score_r, assert(1 3)
keep if _merge==3
drop _merge

*Variables to include:
* Class size (not student weighted)
  sort teacher year math stuid
  by teacher year math: gen oneperclass=(_n==1)
  gen classsize=CLass_size if oneperclass==1
  
*No. of subject-years per student
  sort stuid year math
  by stuid: gen oneperstud=(_n==1)
  by stuid: gen stud_nobs=_N if oneperstud==1

*Test score (SD)
*Female
*Age (years)
*Free lunch elig.
*Minority (Black/Hispanic)
  gen minority=(ETHNethnici_1+ETHNethnici_2)
*English language learner
*Special education
*Repeating grade
*Matched to parents in tax data

foreach v of varlist sped age_current limited_english {
  replace `v'=. if MISS_`v'==1
}
replace lunch=. if miss_lunch==1

su classsize stud_nobs score female age_current lunch minority sped limited_english repeat_grade

tab year sped, m
tab year limited_english, m
tab year lunch, m

su ETHN*

tempname results
foreach v of varlist classsize stud_nobs score female age_current lunch minority sped limited_english repeat_grade {
	su `v'
	matrix `results'=nullmat(`results') \ (r(mean), r(sd), r(N))
	local rnames "`rnames' `v'"
}
matrix rownames `results' = `rnames'
matrix colnames `results' = Mean SD N
esttab matrix(`results') 
esttab matrix(`results') using `dofile'.txt, replace
esttab matrix(`results') using `dofile'.csv, csv replace

if `doasproject'==1 project, creates(`thisdir'/`dofile'.txt)
if `doasproject'==1 project, creates(`thisdir'/`dofile'.csv)
       
